# coding: utf-8

"""
    Anyscale API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from anyscale_client.configuration import Configuration


class ObjectStorageConfigS3(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'region': 'str',
        'bucket': 'str',
        'path': 'str',
        'aws_access_key_id': 'str',
        'aws_secret_access_key': 'str',
        'aws_session_token': 'str'
    }

    attribute_map = {
        'region': 'region',
        'bucket': 'bucket',
        'path': 'path',
        'aws_access_key_id': 'aws_access_key_id',
        'aws_secret_access_key': 'aws_secret_access_key',
        'aws_session_token': 'aws_session_token'
    }

    def __init__(self, region=None, bucket=None, path=None, aws_access_key_id=None, aws_secret_access_key=None, aws_session_token=None, local_vars_configuration=None):  # noqa: E501
        """ObjectStorageConfigS3 - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._region = None
        self._bucket = None
        self._path = None
        self._aws_access_key_id = None
        self._aws_secret_access_key = None
        self._aws_session_token = None
        self.discriminator = None

        self.region = region
        self.bucket = bucket
        self.path = path
        self.aws_access_key_id = aws_access_key_id
        self.aws_secret_access_key = aws_secret_access_key
        self.aws_session_token = aws_session_token

    @property
    def region(self):
        """Gets the region of this ObjectStorageConfigS3.  # noqa: E501


        :return: The region of this ObjectStorageConfigS3.  # noqa: E501
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """Sets the region of this ObjectStorageConfigS3.


        :param region: The region of this ObjectStorageConfigS3.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and region is None:  # noqa: E501
            raise ValueError("Invalid value for `region`, must not be `None`")  # noqa: E501

        self._region = region

    @property
    def bucket(self):
        """Gets the bucket of this ObjectStorageConfigS3.  # noqa: E501


        :return: The bucket of this ObjectStorageConfigS3.  # noqa: E501
        :rtype: str
        """
        return self._bucket

    @bucket.setter
    def bucket(self, bucket):
        """Sets the bucket of this ObjectStorageConfigS3.


        :param bucket: The bucket of this ObjectStorageConfigS3.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and bucket is None:  # noqa: E501
            raise ValueError("Invalid value for `bucket`, must not be `None`")  # noqa: E501

        self._bucket = bucket

    @property
    def path(self):
        """Gets the path of this ObjectStorageConfigS3.  # noqa: E501


        :return: The path of this ObjectStorageConfigS3.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this ObjectStorageConfigS3.


        :param path: The path of this ObjectStorageConfigS3.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and path is None:  # noqa: E501
            raise ValueError("Invalid value for `path`, must not be `None`")  # noqa: E501

        self._path = path

    @property
    def aws_access_key_id(self):
        """Gets the aws_access_key_id of this ObjectStorageConfigS3.  # noqa: E501


        :return: The aws_access_key_id of this ObjectStorageConfigS3.  # noqa: E501
        :rtype: str
        """
        return self._aws_access_key_id

    @aws_access_key_id.setter
    def aws_access_key_id(self, aws_access_key_id):
        """Sets the aws_access_key_id of this ObjectStorageConfigS3.


        :param aws_access_key_id: The aws_access_key_id of this ObjectStorageConfigS3.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and aws_access_key_id is None:  # noqa: E501
            raise ValueError("Invalid value for `aws_access_key_id`, must not be `None`")  # noqa: E501

        self._aws_access_key_id = aws_access_key_id

    @property
    def aws_secret_access_key(self):
        """Gets the aws_secret_access_key of this ObjectStorageConfigS3.  # noqa: E501


        :return: The aws_secret_access_key of this ObjectStorageConfigS3.  # noqa: E501
        :rtype: str
        """
        return self._aws_secret_access_key

    @aws_secret_access_key.setter
    def aws_secret_access_key(self, aws_secret_access_key):
        """Sets the aws_secret_access_key of this ObjectStorageConfigS3.


        :param aws_secret_access_key: The aws_secret_access_key of this ObjectStorageConfigS3.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and aws_secret_access_key is None:  # noqa: E501
            raise ValueError("Invalid value for `aws_secret_access_key`, must not be `None`")  # noqa: E501

        self._aws_secret_access_key = aws_secret_access_key

    @property
    def aws_session_token(self):
        """Gets the aws_session_token of this ObjectStorageConfigS3.  # noqa: E501


        :return: The aws_session_token of this ObjectStorageConfigS3.  # noqa: E501
        :rtype: str
        """
        return self._aws_session_token

    @aws_session_token.setter
    def aws_session_token(self, aws_session_token):
        """Sets the aws_session_token of this ObjectStorageConfigS3.


        :param aws_session_token: The aws_session_token of this ObjectStorageConfigS3.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and aws_session_token is None:  # noqa: E501
            raise ValueError("Invalid value for `aws_session_token`, must not be `None`")  # noqa: E501

        self._aws_session_token = aws_session_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ObjectStorageConfigS3):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ObjectStorageConfigS3):
            return True

        return self.to_dict() != other.to_dict()
