# coding: utf-8

"""
    Anyscale API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from anyscale_client.configuration import Configuration


class TerminateSessionOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'workers_only': 'bool',
        'keep_min_workers': 'bool',
        'delete': 'bool',
        'take_snapshot': 'bool'
    }

    attribute_map = {
        'workers_only': 'workers_only',
        'keep_min_workers': 'keep_min_workers',
        'delete': 'delete',
        'take_snapshot': 'take_snapshot'
    }

    def __init__(self, workers_only=False, keep_min_workers=False, delete=False, take_snapshot=True, local_vars_configuration=None):  # noqa: E501
        """TerminateSessionOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._workers_only = None
        self._keep_min_workers = None
        self._delete = None
        self._take_snapshot = None
        self.discriminator = None

        if workers_only is not None:
            self.workers_only = workers_only
        if keep_min_workers is not None:
            self.keep_min_workers = keep_min_workers
        if delete is not None:
            self.delete = delete
        if take_snapshot is not None:
            self.take_snapshot = take_snapshot

    @property
    def workers_only(self):
        """Gets the workers_only of this TerminateSessionOptions.  # noqa: E501

        Only destroy the workers when terminating.  # noqa: E501

        :return: The workers_only of this TerminateSessionOptions.  # noqa: E501
        :rtype: bool
        """
        return self._workers_only

    @workers_only.setter
    def workers_only(self, workers_only):
        """Sets the workers_only of this TerminateSessionOptions.

        Only destroy the workers when terminating.  # noqa: E501

        :param workers_only: The workers_only of this TerminateSessionOptions.  # noqa: E501
        :type: bool
        """

        self._workers_only = workers_only

    @property
    def keep_min_workers(self):
        """Gets the keep_min_workers of this TerminateSessionOptions.  # noqa: E501

        Retain the minimal amount of workers specified in the config when terminating.  # noqa: E501

        :return: The keep_min_workers of this TerminateSessionOptions.  # noqa: E501
        :rtype: bool
        """
        return self._keep_min_workers

    @keep_min_workers.setter
    def keep_min_workers(self, keep_min_workers):
        """Sets the keep_min_workers of this TerminateSessionOptions.

        Retain the minimal amount of workers specified in the config when terminating.  # noqa: E501

        :param keep_min_workers: The keep_min_workers of this TerminateSessionOptions.  # noqa: E501
        :type: bool
        """

        self._keep_min_workers = keep_min_workers

    @property
    def delete(self):
        """Gets the delete of this TerminateSessionOptions.  # noqa: E501

        Delete the session after terminating.  # noqa: E501

        :return: The delete of this TerminateSessionOptions.  # noqa: E501
        :rtype: bool
        """
        return self._delete

    @delete.setter
    def delete(self, delete):
        """Sets the delete of this TerminateSessionOptions.

        Delete the session after terminating.  # noqa: E501

        :param delete: The delete of this TerminateSessionOptions.  # noqa: E501
        :type: bool
        """

        self._delete = delete

    @property
    def take_snapshot(self):
        """Gets the take_snapshot of this TerminateSessionOptions.  # noqa: E501

        Takes a snapshot to preserve the state of the session before terminating. The state will be restored the next time the session is started.  # noqa: E501

        :return: The take_snapshot of this TerminateSessionOptions.  # noqa: E501
        :rtype: bool
        """
        return self._take_snapshot

    @take_snapshot.setter
    def take_snapshot(self, take_snapshot):
        """Sets the take_snapshot of this TerminateSessionOptions.

        Takes a snapshot to preserve the state of the session before terminating. The state will be restored the next time the session is started.  # noqa: E501

        :param take_snapshot: The take_snapshot of this TerminateSessionOptions.  # noqa: E501
        :type: bool
        """

        self._take_snapshot = take_snapshot

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TerminateSessionOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TerminateSessionOptions):
            return True

        return self.to_dict() != other.to_dict()
