# coding: utf-8

"""
    Managed Ray API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class BASEIMAGESENUM(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    ANYSCALE_RAY_ML_1_10_0_PY36_GPU = "anyscale/ray-ml:1.10.0-py36-gpu"
    ANYSCALE_RAY_ML_1_10_0_PY37_GPU = "anyscale/ray-ml:1.10.0-py37-gpu"
    ANYSCALE_RAY_ML_1_10_0_PY38_GPU = "anyscale/ray-ml:1.10.0-py38-gpu"
    ANYSCALE_RAY_ML_1_10_0RC0_PY36_GPU = "anyscale/ray-ml:1.10.0rc0-py36-gpu"
    ANYSCALE_RAY_ML_1_10_0RC0_PY37_GPU = "anyscale/ray-ml:1.10.0rc0-py37-gpu"
    ANYSCALE_RAY_ML_1_10_0RC0_PY38_GPU = "anyscale/ray-ml:1.10.0rc0-py38-gpu"
    ANYSCALE_RAY_ML_1_11_0_PY36_GPU = "anyscale/ray-ml:1.11.0-py36-gpu"
    ANYSCALE_RAY_ML_1_11_0_PY37_GPU = "anyscale/ray-ml:1.11.0-py37-gpu"
    ANYSCALE_RAY_ML_1_11_0_PY38_GPU = "anyscale/ray-ml:1.11.0-py38-gpu"
    ANYSCALE_RAY_ML_1_11_1_PY36_GPU = "anyscale/ray-ml:1.11.1-py36-gpu"
    ANYSCALE_RAY_ML_1_11_1_PY37_GPU = "anyscale/ray-ml:1.11.1-py37-gpu"
    ANYSCALE_RAY_ML_1_11_1_PY38_GPU = "anyscale/ray-ml:1.11.1-py38-gpu"
    ANYSCALE_RAY_ML_1_12_0_PY36_GPU = "anyscale/ray-ml:1.12.0-py36-gpu"
    ANYSCALE_RAY_ML_1_12_0_PY37_GPU = "anyscale/ray-ml:1.12.0-py37-gpu"
    ANYSCALE_RAY_ML_1_12_0_PY38_GPU = "anyscale/ray-ml:1.12.0-py38-gpu"
    ANYSCALE_RAY_ML_1_12_1_PY36_GPU = "anyscale/ray-ml:1.12.1-py36-gpu"
    ANYSCALE_RAY_ML_1_12_1_PY37_GPU = "anyscale/ray-ml:1.12.1-py37-gpu"
    ANYSCALE_RAY_ML_1_12_1_PY38_GPU = "anyscale/ray-ml:1.12.1-py38-gpu"
    ANYSCALE_RAY_ML_1_13_0_PY36_CPU = "anyscale/ray-ml:1.13.0-py36-cpu"
    ANYSCALE_RAY_ML_1_13_0_PY36_GPU = "anyscale/ray-ml:1.13.0-py36-gpu"
    ANYSCALE_RAY_ML_1_13_0_PY37_CPU = "anyscale/ray-ml:1.13.0-py37-cpu"
    ANYSCALE_RAY_ML_1_13_0_PY37_GPU = "anyscale/ray-ml:1.13.0-py37-gpu"
    ANYSCALE_RAY_ML_1_13_0_PY38_CPU = "anyscale/ray-ml:1.13.0-py38-cpu"
    ANYSCALE_RAY_ML_1_13_0_PY38_GPU = "anyscale/ray-ml:1.13.0-py38-gpu"
    ANYSCALE_RAY_ML_1_13_0RC0_PY36_GPU = "anyscale/ray-ml:1.13.0rc0-py36-gpu"
    ANYSCALE_RAY_ML_1_13_0RC0_PY37_GPU = "anyscale/ray-ml:1.13.0rc0-py37-gpu"
    ANYSCALE_RAY_ML_1_13_0RC0_PY38_GPU = "anyscale/ray-ml:1.13.0rc0-py38-gpu"
    ANYSCALE_RAY_ML_1_7_0 = "anyscale/ray-ml:1.7.0"
    ANYSCALE_RAY_ML_1_7_0_GPU = "anyscale/ray-ml:1.7.0-gpu"
    ANYSCALE_RAY_ML_1_7_0_PY36 = "anyscale/ray-ml:1.7.0-py36"
    ANYSCALE_RAY_ML_1_7_0_PY36_GPU = "anyscale/ray-ml:1.7.0-py36-gpu"
    ANYSCALE_RAY_ML_1_7_0_PY37 = "anyscale/ray-ml:1.7.0-py37"
    ANYSCALE_RAY_ML_1_7_0_PY37_GPU = "anyscale/ray-ml:1.7.0-py37-gpu"
    ANYSCALE_RAY_ML_1_7_0_PY38 = "anyscale/ray-ml:1.7.0-py38"
    ANYSCALE_RAY_ML_1_7_0_PY38_GPU = "anyscale/ray-ml:1.7.0-py38-gpu"
    ANYSCALE_RAY_ML_1_7_0RC0 = "anyscale/ray-ml:1.7.0rc0"
    ANYSCALE_RAY_ML_1_7_0RC0_GPU = "anyscale/ray-ml:1.7.0rc0-gpu"
    ANYSCALE_RAY_ML_1_7_0RC0_PY36 = "anyscale/ray-ml:1.7.0rc0-py36"
    ANYSCALE_RAY_ML_1_7_0RC0_PY36_GPU = "anyscale/ray-ml:1.7.0rc0-py36-gpu"
    ANYSCALE_RAY_ML_1_7_0RC0_PY37 = "anyscale/ray-ml:1.7.0rc0-py37"
    ANYSCALE_RAY_ML_1_7_0RC0_PY37_GPU = "anyscale/ray-ml:1.7.0rc0-py37-gpu"
    ANYSCALE_RAY_ML_1_7_0RC0_PY38 = "anyscale/ray-ml:1.7.0rc0-py38"
    ANYSCALE_RAY_ML_1_7_0RC0_PY38_GPU = "anyscale/ray-ml:1.7.0rc0-py38-gpu"
    ANYSCALE_RAY_ML_1_7_1 = "anyscale/ray-ml:1.7.1"
    ANYSCALE_RAY_ML_1_7_1_GPU = "anyscale/ray-ml:1.7.1-gpu"
    ANYSCALE_RAY_ML_1_7_1_PY36 = "anyscale/ray-ml:1.7.1-py36"
    ANYSCALE_RAY_ML_1_7_1_PY36_GPU = "anyscale/ray-ml:1.7.1-py36-gpu"
    ANYSCALE_RAY_ML_1_7_1_PY37 = "anyscale/ray-ml:1.7.1-py37"
    ANYSCALE_RAY_ML_1_7_1_PY37_GPU = "anyscale/ray-ml:1.7.1-py37-gpu"
    ANYSCALE_RAY_ML_1_7_1_PY38 = "anyscale/ray-ml:1.7.1-py38"
    ANYSCALE_RAY_ML_1_7_1_PY38_GPU = "anyscale/ray-ml:1.7.1-py38-gpu"
    ANYSCALE_RAY_ML_1_8_0 = "anyscale/ray-ml:1.8.0"
    ANYSCALE_RAY_ML_1_8_0_GPU = "anyscale/ray-ml:1.8.0-gpu"
    ANYSCALE_RAY_ML_1_8_0_PY36 = "anyscale/ray-ml:1.8.0-py36"
    ANYSCALE_RAY_ML_1_8_0_PY36_GPU = "anyscale/ray-ml:1.8.0-py36-gpu"
    ANYSCALE_RAY_ML_1_8_0_PY37 = "anyscale/ray-ml:1.8.0-py37"
    ANYSCALE_RAY_ML_1_8_0_PY37_GPU = "anyscale/ray-ml:1.8.0-py37-gpu"
    ANYSCALE_RAY_ML_1_8_0_PY38 = "anyscale/ray-ml:1.8.0-py38"
    ANYSCALE_RAY_ML_1_8_0_PY38_GPU = "anyscale/ray-ml:1.8.0-py38-gpu"
    ANYSCALE_RAY_ML_1_9_0_PY36_GPU = "anyscale/ray-ml:1.9.0-py36-gpu"
    ANYSCALE_RAY_ML_1_9_0_PY37_GPU = "anyscale/ray-ml:1.9.0-py37-gpu"
    ANYSCALE_RAY_ML_1_9_0_PY38_GPU = "anyscale/ray-ml:1.9.0-py38-gpu"
    ANYSCALE_RAY_ML_1_9_0RC1_PY36_GPU = "anyscale/ray-ml:1.9.0rc1-py36-gpu"
    ANYSCALE_RAY_ML_1_9_0RC1_PY37_GPU = "anyscale/ray-ml:1.9.0rc1-py37-gpu"
    ANYSCALE_RAY_ML_1_9_0RC1_PY38_GPU = "anyscale/ray-ml:1.9.0rc1-py38-gpu"
    ANYSCALE_RAY_ML_1_9_0RC2_PY36_GPU = "anyscale/ray-ml:1.9.0rc2-py36-gpu"
    ANYSCALE_RAY_ML_1_9_0RC2_PY37_GPU = "anyscale/ray-ml:1.9.0rc2-py37-gpu"
    ANYSCALE_RAY_ML_1_9_0RC2_PY38_GPU = "anyscale/ray-ml:1.9.0rc2-py38-gpu"
    ANYSCALE_RAY_ML_1_9_1_PY36_GPU = "anyscale/ray-ml:1.9.1-py36-gpu"
    ANYSCALE_RAY_ML_1_9_1_PY37_GPU = "anyscale/ray-ml:1.9.1-py37-gpu"
    ANYSCALE_RAY_ML_1_9_1_PY38_GPU = "anyscale/ray-ml:1.9.1-py38-gpu"
    ANYSCALE_RAY_ML_1_9_1RC0_PY36_GPU = "anyscale/ray-ml:1.9.1rc0-py36-gpu"
    ANYSCALE_RAY_ML_1_9_1RC0_PY37_GPU = "anyscale/ray-ml:1.9.1rc0-py37-gpu"
    ANYSCALE_RAY_ML_1_9_1RC0_PY38_GPU = "anyscale/ray-ml:1.9.1rc0-py38-gpu"
    ANYSCALE_RAY_ML_1_9_2_PY36_GPU = "anyscale/ray-ml:1.9.2-py36-gpu"
    ANYSCALE_RAY_ML_1_9_2_PY37_GPU = "anyscale/ray-ml:1.9.2-py37-gpu"
    ANYSCALE_RAY_ML_1_9_2_PY38_GPU = "anyscale/ray-ml:1.9.2-py38-gpu"
    ANYSCALE_RAY_ML_2_0_0_PY36_CPU = "anyscale/ray-ml:2.0.0-py36-cpu"
    ANYSCALE_RAY_ML_2_0_0_PY36_GPU = "anyscale/ray-ml:2.0.0-py36-gpu"
    ANYSCALE_RAY_ML_2_0_0_PY37_CPU = "anyscale/ray-ml:2.0.0-py37-cpu"
    ANYSCALE_RAY_ML_2_0_0_PY37_GPU = "anyscale/ray-ml:2.0.0-py37-gpu"
    ANYSCALE_RAY_ML_2_0_0_PY38_CPU = "anyscale/ray-ml:2.0.0-py38-cpu"
    ANYSCALE_RAY_ML_2_0_0_PY38_GPU = "anyscale/ray-ml:2.0.0-py38-gpu"
    ANYSCALE_RAY_ML_2_0_0RC0_PY36_CPU = "anyscale/ray-ml:2.0.0rc0-py36-cpu"
    ANYSCALE_RAY_ML_2_0_0RC0_PY36_GPU = "anyscale/ray-ml:2.0.0rc0-py36-gpu"
    ANYSCALE_RAY_ML_2_0_0RC0_PY37_CPU = "anyscale/ray-ml:2.0.0rc0-py37-cpu"
    ANYSCALE_RAY_ML_2_0_0RC0_PY37_GPU = "anyscale/ray-ml:2.0.0rc0-py37-gpu"
    ANYSCALE_RAY_ML_2_0_0RC0_PY38_CPU = "anyscale/ray-ml:2.0.0rc0-py38-cpu"
    ANYSCALE_RAY_ML_2_0_0RC0_PY38_GPU = "anyscale/ray-ml:2.0.0rc0-py38-gpu"
    ANYSCALE_RAY_ML_2_0_0RC1_PY36_CPU = "anyscale/ray-ml:2.0.0rc1-py36-cpu"
    ANYSCALE_RAY_ML_2_0_0RC1_PY36_GPU = "anyscale/ray-ml:2.0.0rc1-py36-gpu"
    ANYSCALE_RAY_ML_2_0_0RC1_PY37_CPU = "anyscale/ray-ml:2.0.0rc1-py37-cpu"
    ANYSCALE_RAY_ML_2_0_0RC1_PY37_GPU = "anyscale/ray-ml:2.0.0rc1-py37-gpu"
    ANYSCALE_RAY_ML_2_0_0RC1_PY38_CPU = "anyscale/ray-ml:2.0.0rc1-py38-cpu"
    ANYSCALE_RAY_ML_2_0_0RC1_PY38_GPU = "anyscale/ray-ml:2.0.0rc1-py38-gpu"
    ANYSCALE_RAY_ML_2_0_1_PY36_CPU = "anyscale/ray-ml:2.0.1-py36-cpu"
    ANYSCALE_RAY_ML_2_0_1_PY36_GPU = "anyscale/ray-ml:2.0.1-py36-gpu"
    ANYSCALE_RAY_ML_2_0_1_PY37_CPU = "anyscale/ray-ml:2.0.1-py37-cpu"
    ANYSCALE_RAY_ML_2_0_1_PY37_GPU = "anyscale/ray-ml:2.0.1-py37-gpu"
    ANYSCALE_RAY_ML_2_0_1_PY38_CPU = "anyscale/ray-ml:2.0.1-py38-cpu"
    ANYSCALE_RAY_ML_2_0_1_PY38_GPU = "anyscale/ray-ml:2.0.1-py38-gpu"
    ANYSCALE_RAY_ML_2_1_0_PY36_CPU = "anyscale/ray-ml:2.1.0-py36-cpu"
    ANYSCALE_RAY_ML_2_1_0_PY36_GPU = "anyscale/ray-ml:2.1.0-py36-gpu"
    ANYSCALE_RAY_ML_2_1_0_PY37_CPU = "anyscale/ray-ml:2.1.0-py37-cpu"
    ANYSCALE_RAY_ML_2_1_0_PY37_GPU = "anyscale/ray-ml:2.1.0-py37-gpu"
    ANYSCALE_RAY_ML_2_1_0_PY38_CPU = "anyscale/ray-ml:2.1.0-py38-cpu"
    ANYSCALE_RAY_ML_2_1_0_PY38_GPU = "anyscale/ray-ml:2.1.0-py38-gpu"
    ANYSCALE_RAY_ML_2_10_0_PY310_CPU = "anyscale/ray-ml:2.10.0-py310-cpu"
    ANYSCALE_RAY_ML_2_10_0_PY310_GPU = "anyscale/ray-ml:2.10.0-py310-gpu"
    ANYSCALE_RAY_ML_2_10_0_PY38_CPU = "anyscale/ray-ml:2.10.0-py38-cpu"
    ANYSCALE_RAY_ML_2_10_0_PY38_GPU = "anyscale/ray-ml:2.10.0-py38-gpu"
    ANYSCALE_RAY_ML_2_10_0_PY39_CPU = "anyscale/ray-ml:2.10.0-py39-cpu"
    ANYSCALE_RAY_ML_2_10_0_PY39_GPU = "anyscale/ray-ml:2.10.0-py39-gpu"
    ANYSCALE_RAY_ML_2_11_0_PY310_CPU = "anyscale/ray-ml:2.11.0-py310-cpu"
    ANYSCALE_RAY_ML_2_11_0_PY310_GPU = "anyscale/ray-ml:2.11.0-py310-gpu"
    ANYSCALE_RAY_ML_2_11_0_PY311_CPU = "anyscale/ray-ml:2.11.0-py311-cpu"
    ANYSCALE_RAY_ML_2_11_0_PY311_GPU = "anyscale/ray-ml:2.11.0-py311-gpu"
    ANYSCALE_RAY_ML_2_11_0_PY39_CPU = "anyscale/ray-ml:2.11.0-py39-cpu"
    ANYSCALE_RAY_ML_2_11_0_PY39_GPU = "anyscale/ray-ml:2.11.0-py39-gpu"
    ANYSCALE_RAY_ML_2_12_0_PY310_CPU = "anyscale/ray-ml:2.12.0-py310-cpu"
    ANYSCALE_RAY_ML_2_12_0_PY310_GPU = "anyscale/ray-ml:2.12.0-py310-gpu"
    ANYSCALE_RAY_ML_2_12_0_PY311_CPU = "anyscale/ray-ml:2.12.0-py311-cpu"
    ANYSCALE_RAY_ML_2_12_0_PY311_GPU = "anyscale/ray-ml:2.12.0-py311-gpu"
    ANYSCALE_RAY_ML_2_12_0_PY39_CPU = "anyscale/ray-ml:2.12.0-py39-cpu"
    ANYSCALE_RAY_ML_2_12_0_PY39_GPU = "anyscale/ray-ml:2.12.0-py39-gpu"
    ANYSCALE_RAY_ML_2_2_0_PY310_CPU = "anyscale/ray-ml:2.2.0-py310-cpu"
    ANYSCALE_RAY_ML_2_2_0_PY310_GPU = "anyscale/ray-ml:2.2.0-py310-gpu"
    ANYSCALE_RAY_ML_2_2_0_PY37_CPU = "anyscale/ray-ml:2.2.0-py37-cpu"
    ANYSCALE_RAY_ML_2_2_0_PY37_GPU = "anyscale/ray-ml:2.2.0-py37-gpu"
    ANYSCALE_RAY_ML_2_2_0_PY38_CPU = "anyscale/ray-ml:2.2.0-py38-cpu"
    ANYSCALE_RAY_ML_2_2_0_PY38_GPU = "anyscale/ray-ml:2.2.0-py38-gpu"
    ANYSCALE_RAY_ML_2_2_0_PY39_CPU = "anyscale/ray-ml:2.2.0-py39-cpu"
    ANYSCALE_RAY_ML_2_2_0_PY39_GPU = "anyscale/ray-ml:2.2.0-py39-gpu"
    ANYSCALE_RAY_ML_2_20_0_PY310_CPU = "anyscale/ray-ml:2.20.0-py310-cpu"
    ANYSCALE_RAY_ML_2_20_0_PY310_GPU = "anyscale/ray-ml:2.20.0-py310-gpu"
    ANYSCALE_RAY_ML_2_20_0_PY311_CPU = "anyscale/ray-ml:2.20.0-py311-cpu"
    ANYSCALE_RAY_ML_2_20_0_PY311_GPU = "anyscale/ray-ml:2.20.0-py311-gpu"
    ANYSCALE_RAY_ML_2_20_0_PY39_CPU = "anyscale/ray-ml:2.20.0-py39-cpu"
    ANYSCALE_RAY_ML_2_20_0_PY39_GPU = "anyscale/ray-ml:2.20.0-py39-gpu"
    ANYSCALE_RAY_ML_2_21_0_PY310_CPU = "anyscale/ray-ml:2.21.0-py310-cpu"
    ANYSCALE_RAY_ML_2_21_0_PY310_GPU = "anyscale/ray-ml:2.21.0-py310-gpu"
    ANYSCALE_RAY_ML_2_21_0_PY311_CPU = "anyscale/ray-ml:2.21.0-py311-cpu"
    ANYSCALE_RAY_ML_2_21_0_PY311_GPU = "anyscale/ray-ml:2.21.0-py311-gpu"
    ANYSCALE_RAY_ML_2_21_0_PY39_CPU = "anyscale/ray-ml:2.21.0-py39-cpu"
    ANYSCALE_RAY_ML_2_21_0_PY39_GPU = "anyscale/ray-ml:2.21.0-py39-gpu"
    ANYSCALE_RAY_ML_2_22_0_PY310_CPU = "anyscale/ray-ml:2.22.0-py310-cpu"
    ANYSCALE_RAY_ML_2_22_0_PY310_GPU = "anyscale/ray-ml:2.22.0-py310-gpu"
    ANYSCALE_RAY_ML_2_22_0_PY311_CPU = "anyscale/ray-ml:2.22.0-py311-cpu"
    ANYSCALE_RAY_ML_2_22_0_PY311_GPU = "anyscale/ray-ml:2.22.0-py311-gpu"
    ANYSCALE_RAY_ML_2_22_0_PY39_CPU = "anyscale/ray-ml:2.22.0-py39-cpu"
    ANYSCALE_RAY_ML_2_22_0_PY39_GPU = "anyscale/ray-ml:2.22.0-py39-gpu"
    ANYSCALE_RAY_ML_2_23_0_PY310_CPU = "anyscale/ray-ml:2.23.0-py310-cpu"
    ANYSCALE_RAY_ML_2_23_0_PY310_GPU = "anyscale/ray-ml:2.23.0-py310-gpu"
    ANYSCALE_RAY_ML_2_23_0_PY311_CPU = "anyscale/ray-ml:2.23.0-py311-cpu"
    ANYSCALE_RAY_ML_2_23_0_PY311_GPU = "anyscale/ray-ml:2.23.0-py311-gpu"
    ANYSCALE_RAY_ML_2_23_0_PY39_CPU = "anyscale/ray-ml:2.23.0-py39-cpu"
    ANYSCALE_RAY_ML_2_23_0_PY39_GPU = "anyscale/ray-ml:2.23.0-py39-gpu"
    ANYSCALE_RAY_ML_2_24_0_PY310_CPU = "anyscale/ray-ml:2.24.0-py310-cpu"
    ANYSCALE_RAY_ML_2_24_0_PY310_GPU = "anyscale/ray-ml:2.24.0-py310-gpu"
    ANYSCALE_RAY_ML_2_24_0_PY311_CPU = "anyscale/ray-ml:2.24.0-py311-cpu"
    ANYSCALE_RAY_ML_2_24_0_PY311_GPU = "anyscale/ray-ml:2.24.0-py311-gpu"
    ANYSCALE_RAY_ML_2_24_0_PY39_CPU = "anyscale/ray-ml:2.24.0-py39-cpu"
    ANYSCALE_RAY_ML_2_24_0_PY39_GPU = "anyscale/ray-ml:2.24.0-py39-gpu"
    ANYSCALE_RAY_ML_2_3_0_PY310_CPU = "anyscale/ray-ml:2.3.0-py310-cpu"
    ANYSCALE_RAY_ML_2_3_0_PY310_GPU = "anyscale/ray-ml:2.3.0-py310-gpu"
    ANYSCALE_RAY_ML_2_3_0_PY37_CPU = "anyscale/ray-ml:2.3.0-py37-cpu"
    ANYSCALE_RAY_ML_2_3_0_PY37_GPU = "anyscale/ray-ml:2.3.0-py37-gpu"
    ANYSCALE_RAY_ML_2_3_0_PY38_CPU = "anyscale/ray-ml:2.3.0-py38-cpu"
    ANYSCALE_RAY_ML_2_3_0_PY38_GPU = "anyscale/ray-ml:2.3.0-py38-gpu"
    ANYSCALE_RAY_ML_2_3_0_PY39_CPU = "anyscale/ray-ml:2.3.0-py39-cpu"
    ANYSCALE_RAY_ML_2_3_0_PY39_GPU = "anyscale/ray-ml:2.3.0-py39-gpu"
    ANYSCALE_RAY_ML_2_3_1_PY310_CPU = "anyscale/ray-ml:2.3.1-py310-cpu"
    ANYSCALE_RAY_ML_2_3_1_PY310_GPU = "anyscale/ray-ml:2.3.1-py310-gpu"
    ANYSCALE_RAY_ML_2_3_1_PY37_CPU = "anyscale/ray-ml:2.3.1-py37-cpu"
    ANYSCALE_RAY_ML_2_3_1_PY37_GPU = "anyscale/ray-ml:2.3.1-py37-gpu"
    ANYSCALE_RAY_ML_2_3_1_PY38_CPU = "anyscale/ray-ml:2.3.1-py38-cpu"
    ANYSCALE_RAY_ML_2_3_1_PY38_GPU = "anyscale/ray-ml:2.3.1-py38-gpu"
    ANYSCALE_RAY_ML_2_3_1_PY39_CPU = "anyscale/ray-ml:2.3.1-py39-cpu"
    ANYSCALE_RAY_ML_2_3_1_PY39_GPU = "anyscale/ray-ml:2.3.1-py39-gpu"
    ANYSCALE_RAY_ML_2_30_0_PY310_CPU = "anyscale/ray-ml:2.30.0-py310-cpu"
    ANYSCALE_RAY_ML_2_30_0_PY310_GPU = "anyscale/ray-ml:2.30.0-py310-gpu"
    ANYSCALE_RAY_ML_2_30_0_PY311_CPU = "anyscale/ray-ml:2.30.0-py311-cpu"
    ANYSCALE_RAY_ML_2_30_0_PY311_GPU = "anyscale/ray-ml:2.30.0-py311-gpu"
    ANYSCALE_RAY_ML_2_30_0_PY39_CPU = "anyscale/ray-ml:2.30.0-py39-cpu"
    ANYSCALE_RAY_ML_2_30_0_PY39_GPU = "anyscale/ray-ml:2.30.0-py39-gpu"
    ANYSCALE_RAY_ML_2_31_0_PY310_CPU = "anyscale/ray-ml:2.31.0-py310-cpu"
    ANYSCALE_RAY_ML_2_31_0_PY310_GPU = "anyscale/ray-ml:2.31.0-py310-gpu"
    ANYSCALE_RAY_ML_2_31_0_PY311_CPU = "anyscale/ray-ml:2.31.0-py311-cpu"
    ANYSCALE_RAY_ML_2_31_0_PY311_GPU = "anyscale/ray-ml:2.31.0-py311-gpu"
    ANYSCALE_RAY_ML_2_31_0_PY39_CPU = "anyscale/ray-ml:2.31.0-py39-cpu"
    ANYSCALE_RAY_ML_2_31_0_PY39_GPU = "anyscale/ray-ml:2.31.0-py39-gpu"
    ANYSCALE_RAY_ML_2_32_0_PY310_CPU = "anyscale/ray-ml:2.32.0-py310-cpu"
    ANYSCALE_RAY_ML_2_32_0_PY310_GPU = "anyscale/ray-ml:2.32.0-py310-gpu"
    ANYSCALE_RAY_ML_2_32_0_PY311_CPU = "anyscale/ray-ml:2.32.0-py311-cpu"
    ANYSCALE_RAY_ML_2_32_0_PY311_GPU = "anyscale/ray-ml:2.32.0-py311-gpu"
    ANYSCALE_RAY_ML_2_32_0_PY39_CPU = "anyscale/ray-ml:2.32.0-py39-cpu"
    ANYSCALE_RAY_ML_2_32_0_PY39_GPU = "anyscale/ray-ml:2.32.0-py39-gpu"
    ANYSCALE_RAY_ML_2_33_0_PY310_CPU = "anyscale/ray-ml:2.33.0-py310-cpu"
    ANYSCALE_RAY_ML_2_33_0_PY310_GPU = "anyscale/ray-ml:2.33.0-py310-gpu"
    ANYSCALE_RAY_ML_2_33_0_PY311_CPU = "anyscale/ray-ml:2.33.0-py311-cpu"
    ANYSCALE_RAY_ML_2_33_0_PY311_GPU = "anyscale/ray-ml:2.33.0-py311-gpu"
    ANYSCALE_RAY_ML_2_33_0_PY39_CPU = "anyscale/ray-ml:2.33.0-py39-cpu"
    ANYSCALE_RAY_ML_2_33_0_PY39_GPU = "anyscale/ray-ml:2.33.0-py39-gpu"
    ANYSCALE_RAY_ML_2_34_0_PY310_CPU = "anyscale/ray-ml:2.34.0-py310-cpu"
    ANYSCALE_RAY_ML_2_34_0_PY310_GPU = "anyscale/ray-ml:2.34.0-py310-gpu"
    ANYSCALE_RAY_ML_2_34_0_PY311_CPU = "anyscale/ray-ml:2.34.0-py311-cpu"
    ANYSCALE_RAY_ML_2_34_0_PY311_GPU = "anyscale/ray-ml:2.34.0-py311-gpu"
    ANYSCALE_RAY_ML_2_34_0_PY39_CPU = "anyscale/ray-ml:2.34.0-py39-cpu"
    ANYSCALE_RAY_ML_2_34_0_PY39_GPU = "anyscale/ray-ml:2.34.0-py39-gpu"
    ANYSCALE_RAY_ML_2_35_0_PY310_CPU = "anyscale/ray-ml:2.35.0-py310-cpu"
    ANYSCALE_RAY_ML_2_35_0_PY310_GPU = "anyscale/ray-ml:2.35.0-py310-gpu"
    ANYSCALE_RAY_ML_2_35_0_PY311_CPU = "anyscale/ray-ml:2.35.0-py311-cpu"
    ANYSCALE_RAY_ML_2_35_0_PY311_GPU = "anyscale/ray-ml:2.35.0-py311-gpu"
    ANYSCALE_RAY_ML_2_35_0_PY39_CPU = "anyscale/ray-ml:2.35.0-py39-cpu"
    ANYSCALE_RAY_ML_2_35_0_PY39_GPU = "anyscale/ray-ml:2.35.0-py39-gpu"
    ANYSCALE_RAY_ML_2_36_0_PY310_CPU = "anyscale/ray-ml:2.36.0-py310-cpu"
    ANYSCALE_RAY_ML_2_36_0_PY310_GPU = "anyscale/ray-ml:2.36.0-py310-gpu"
    ANYSCALE_RAY_ML_2_36_0_PY311_CPU = "anyscale/ray-ml:2.36.0-py311-cpu"
    ANYSCALE_RAY_ML_2_36_0_PY311_GPU = "anyscale/ray-ml:2.36.0-py311-gpu"
    ANYSCALE_RAY_ML_2_36_0_PY39_CPU = "anyscale/ray-ml:2.36.0-py39-cpu"
    ANYSCALE_RAY_ML_2_36_0_PY39_GPU = "anyscale/ray-ml:2.36.0-py39-gpu"
    ANYSCALE_RAY_ML_2_36_1_PY310_CPU = "anyscale/ray-ml:2.36.1-py310-cpu"
    ANYSCALE_RAY_ML_2_36_1_PY310_GPU = "anyscale/ray-ml:2.36.1-py310-gpu"
    ANYSCALE_RAY_ML_2_36_1_PY311_CPU = "anyscale/ray-ml:2.36.1-py311-cpu"
    ANYSCALE_RAY_ML_2_36_1_PY311_GPU = "anyscale/ray-ml:2.36.1-py311-gpu"
    ANYSCALE_RAY_ML_2_36_1_PY39_CPU = "anyscale/ray-ml:2.36.1-py39-cpu"
    ANYSCALE_RAY_ML_2_36_1_PY39_GPU = "anyscale/ray-ml:2.36.1-py39-gpu"
    ANYSCALE_RAY_ML_2_37_0_PY310_CPU = "anyscale/ray-ml:2.37.0-py310-cpu"
    ANYSCALE_RAY_ML_2_37_0_PY310_GPU = "anyscale/ray-ml:2.37.0-py310-gpu"
    ANYSCALE_RAY_ML_2_37_0_PY311_CPU = "anyscale/ray-ml:2.37.0-py311-cpu"
    ANYSCALE_RAY_ML_2_37_0_PY311_GPU = "anyscale/ray-ml:2.37.0-py311-gpu"
    ANYSCALE_RAY_ML_2_37_0_PY39_CPU = "anyscale/ray-ml:2.37.0-py39-cpu"
    ANYSCALE_RAY_ML_2_37_0_PY39_GPU = "anyscale/ray-ml:2.37.0-py39-gpu"
    ANYSCALE_RAY_ML_2_38_0_PY310_CPU = "anyscale/ray-ml:2.38.0-py310-cpu"
    ANYSCALE_RAY_ML_2_38_0_PY310_GPU = "anyscale/ray-ml:2.38.0-py310-gpu"
    ANYSCALE_RAY_ML_2_38_0_PY311_CPU = "anyscale/ray-ml:2.38.0-py311-cpu"
    ANYSCALE_RAY_ML_2_38_0_PY311_GPU = "anyscale/ray-ml:2.38.0-py311-gpu"
    ANYSCALE_RAY_ML_2_38_0_PY39_CPU = "anyscale/ray-ml:2.38.0-py39-cpu"
    ANYSCALE_RAY_ML_2_38_0_PY39_GPU = "anyscale/ray-ml:2.38.0-py39-gpu"
    ANYSCALE_RAY_ML_2_39_0_PY310_CPU = "anyscale/ray-ml:2.39.0-py310-cpu"
    ANYSCALE_RAY_ML_2_39_0_PY310_GPU = "anyscale/ray-ml:2.39.0-py310-gpu"
    ANYSCALE_RAY_ML_2_39_0_PY311_CPU = "anyscale/ray-ml:2.39.0-py311-cpu"
    ANYSCALE_RAY_ML_2_39_0_PY311_GPU = "anyscale/ray-ml:2.39.0-py311-gpu"
    ANYSCALE_RAY_ML_2_39_0_PY39_CPU = "anyscale/ray-ml:2.39.0-py39-cpu"
    ANYSCALE_RAY_ML_2_39_0_PY39_GPU = "anyscale/ray-ml:2.39.0-py39-gpu"
    ANYSCALE_RAY_ML_2_4_0_PY310_CPU = "anyscale/ray-ml:2.4.0-py310-cpu"
    ANYSCALE_RAY_ML_2_4_0_PY310_GPU = "anyscale/ray-ml:2.4.0-py310-gpu"
    ANYSCALE_RAY_ML_2_4_0_PY37_CPU = "anyscale/ray-ml:2.4.0-py37-cpu"
    ANYSCALE_RAY_ML_2_4_0_PY37_GPU = "anyscale/ray-ml:2.4.0-py37-gpu"
    ANYSCALE_RAY_ML_2_4_0_PY38_CPU = "anyscale/ray-ml:2.4.0-py38-cpu"
    ANYSCALE_RAY_ML_2_4_0_PY38_GPU = "anyscale/ray-ml:2.4.0-py38-gpu"
    ANYSCALE_RAY_ML_2_4_0_PY39_CPU = "anyscale/ray-ml:2.4.0-py39-cpu"
    ANYSCALE_RAY_ML_2_4_0_PY39_GPU = "anyscale/ray-ml:2.4.0-py39-gpu"
    ANYSCALE_RAY_ML_2_40_0_PY310_CPU = "anyscale/ray-ml:2.40.0-py310-cpu"
    ANYSCALE_RAY_ML_2_40_0_PY310_GPU = "anyscale/ray-ml:2.40.0-py310-gpu"
    ANYSCALE_RAY_ML_2_40_0_PY311_CPU = "anyscale/ray-ml:2.40.0-py311-cpu"
    ANYSCALE_RAY_ML_2_40_0_PY311_GPU = "anyscale/ray-ml:2.40.0-py311-gpu"
    ANYSCALE_RAY_ML_2_40_0_PY39_CPU = "anyscale/ray-ml:2.40.0-py39-cpu"
    ANYSCALE_RAY_ML_2_40_0_PY39_GPU = "anyscale/ray-ml:2.40.0-py39-gpu"
    ANYSCALE_RAY_ML_2_5_0_PY310_CPU = "anyscale/ray-ml:2.5.0-py310-cpu"
    ANYSCALE_RAY_ML_2_5_0_PY310_GPU = "anyscale/ray-ml:2.5.0-py310-gpu"
    ANYSCALE_RAY_ML_2_5_0_PY37_CPU = "anyscale/ray-ml:2.5.0-py37-cpu"
    ANYSCALE_RAY_ML_2_5_0_PY37_GPU = "anyscale/ray-ml:2.5.0-py37-gpu"
    ANYSCALE_RAY_ML_2_5_0_PY38_CPU = "anyscale/ray-ml:2.5.0-py38-cpu"
    ANYSCALE_RAY_ML_2_5_0_PY38_GPU = "anyscale/ray-ml:2.5.0-py38-gpu"
    ANYSCALE_RAY_ML_2_5_0_PY39_CPU = "anyscale/ray-ml:2.5.0-py39-cpu"
    ANYSCALE_RAY_ML_2_5_0_PY39_GPU = "anyscale/ray-ml:2.5.0-py39-gpu"
    ANYSCALE_RAY_ML_2_5_1_PY310_CPU = "anyscale/ray-ml:2.5.1-py310-cpu"
    ANYSCALE_RAY_ML_2_5_1_PY310_GPU = "anyscale/ray-ml:2.5.1-py310-gpu"
    ANYSCALE_RAY_ML_2_5_1_PY37_CPU = "anyscale/ray-ml:2.5.1-py37-cpu"
    ANYSCALE_RAY_ML_2_5_1_PY37_GPU = "anyscale/ray-ml:2.5.1-py37-gpu"
    ANYSCALE_RAY_ML_2_5_1_PY38_CPU = "anyscale/ray-ml:2.5.1-py38-cpu"
    ANYSCALE_RAY_ML_2_5_1_PY38_GPU = "anyscale/ray-ml:2.5.1-py38-gpu"
    ANYSCALE_RAY_ML_2_5_1_PY39_CPU = "anyscale/ray-ml:2.5.1-py39-cpu"
    ANYSCALE_RAY_ML_2_5_1_PY39_GPU = "anyscale/ray-ml:2.5.1-py39-gpu"
    ANYSCALE_RAY_ML_2_6_0_PY310_CPU = "anyscale/ray-ml:2.6.0-py310-cpu"
    ANYSCALE_RAY_ML_2_6_0_PY310_GPU = "anyscale/ray-ml:2.6.0-py310-gpu"
    ANYSCALE_RAY_ML_2_6_0_PY38_CPU = "anyscale/ray-ml:2.6.0-py38-cpu"
    ANYSCALE_RAY_ML_2_6_0_PY38_GPU = "anyscale/ray-ml:2.6.0-py38-gpu"
    ANYSCALE_RAY_ML_2_6_0_PY39_CPU = "anyscale/ray-ml:2.6.0-py39-cpu"
    ANYSCALE_RAY_ML_2_6_0_PY39_GPU = "anyscale/ray-ml:2.6.0-py39-gpu"
    ANYSCALE_RAY_ML_2_6_1_PY310_CPU = "anyscale/ray-ml:2.6.1-py310-cpu"
    ANYSCALE_RAY_ML_2_6_1_PY310_GPU = "anyscale/ray-ml:2.6.1-py310-gpu"
    ANYSCALE_RAY_ML_2_6_1_PY38_CPU = "anyscale/ray-ml:2.6.1-py38-cpu"
    ANYSCALE_RAY_ML_2_6_1_PY38_GPU = "anyscale/ray-ml:2.6.1-py38-gpu"
    ANYSCALE_RAY_ML_2_6_1_PY39_CPU = "anyscale/ray-ml:2.6.1-py39-cpu"
    ANYSCALE_RAY_ML_2_6_1_PY39_GPU = "anyscale/ray-ml:2.6.1-py39-gpu"
    ANYSCALE_RAY_ML_2_6_2_PY310_CPU = "anyscale/ray-ml:2.6.2-py310-cpu"
    ANYSCALE_RAY_ML_2_6_2_PY310_GPU = "anyscale/ray-ml:2.6.2-py310-gpu"
    ANYSCALE_RAY_ML_2_6_2_PY38_CPU = "anyscale/ray-ml:2.6.2-py38-cpu"
    ANYSCALE_RAY_ML_2_6_2_PY38_GPU = "anyscale/ray-ml:2.6.2-py38-gpu"
    ANYSCALE_RAY_ML_2_6_2_PY39_CPU = "anyscale/ray-ml:2.6.2-py39-cpu"
    ANYSCALE_RAY_ML_2_6_2_PY39_GPU = "anyscale/ray-ml:2.6.2-py39-gpu"
    ANYSCALE_RAY_ML_2_6_3_PY310_CPU = "anyscale/ray-ml:2.6.3-py310-cpu"
    ANYSCALE_RAY_ML_2_6_3_PY310_GPU = "anyscale/ray-ml:2.6.3-py310-gpu"
    ANYSCALE_RAY_ML_2_6_3_PY38_CPU = "anyscale/ray-ml:2.6.3-py38-cpu"
    ANYSCALE_RAY_ML_2_6_3_PY38_GPU = "anyscale/ray-ml:2.6.3-py38-gpu"
    ANYSCALE_RAY_ML_2_6_3_PY39_CPU = "anyscale/ray-ml:2.6.3-py39-cpu"
    ANYSCALE_RAY_ML_2_6_3_PY39_GPU = "anyscale/ray-ml:2.6.3-py39-gpu"
    ANYSCALE_RAY_ML_2_7_0OPTIMIZED_PY310_CPU = "anyscale/ray-ml:2.7.0optimized-py310-cpu"
    ANYSCALE_RAY_ML_2_7_0OPTIMIZED_PY310_GPU = "anyscale/ray-ml:2.7.0optimized-py310-gpu"
    ANYSCALE_RAY_ML_2_7_0OPTIMIZED_PY38_CPU = "anyscale/ray-ml:2.7.0optimized-py38-cpu"
    ANYSCALE_RAY_ML_2_7_0OPTIMIZED_PY38_GPU = "anyscale/ray-ml:2.7.0optimized-py38-gpu"
    ANYSCALE_RAY_ML_2_7_0OPTIMIZED_PY39_CPU = "anyscale/ray-ml:2.7.0optimized-py39-cpu"
    ANYSCALE_RAY_ML_2_7_0OPTIMIZED_PY39_GPU = "anyscale/ray-ml:2.7.0optimized-py39-gpu"
    ANYSCALE_RAY_ML_2_7_1OPTIMIZED_PY310_CPU = "anyscale/ray-ml:2.7.1optimized-py310-cpu"
    ANYSCALE_RAY_ML_2_7_1OPTIMIZED_PY310_GPU = "anyscale/ray-ml:2.7.1optimized-py310-gpu"
    ANYSCALE_RAY_ML_2_7_1OPTIMIZED_PY38_CPU = "anyscale/ray-ml:2.7.1optimized-py38-cpu"
    ANYSCALE_RAY_ML_2_7_1OPTIMIZED_PY38_GPU = "anyscale/ray-ml:2.7.1optimized-py38-gpu"
    ANYSCALE_RAY_ML_2_7_1OPTIMIZED_PY39_CPU = "anyscale/ray-ml:2.7.1optimized-py39-cpu"
    ANYSCALE_RAY_ML_2_7_1OPTIMIZED_PY39_GPU = "anyscale/ray-ml:2.7.1optimized-py39-gpu"
    ANYSCALE_RAY_ML_2_7_2OPTIMIZED_PY310_CPU = "anyscale/ray-ml:2.7.2optimized-py310-cpu"
    ANYSCALE_RAY_ML_2_7_2OPTIMIZED_PY310_GPU = "anyscale/ray-ml:2.7.2optimized-py310-gpu"
    ANYSCALE_RAY_ML_2_7_2OPTIMIZED_PY38_CPU = "anyscale/ray-ml:2.7.2optimized-py38-cpu"
    ANYSCALE_RAY_ML_2_7_2OPTIMIZED_PY38_GPU = "anyscale/ray-ml:2.7.2optimized-py38-gpu"
    ANYSCALE_RAY_ML_2_7_2OPTIMIZED_PY39_CPU = "anyscale/ray-ml:2.7.2optimized-py39-cpu"
    ANYSCALE_RAY_ML_2_7_2OPTIMIZED_PY39_GPU = "anyscale/ray-ml:2.7.2optimized-py39-gpu"
    ANYSCALE_RAY_ML_2_8_0_PY310_CPU = "anyscale/ray-ml:2.8.0-py310-cpu"
    ANYSCALE_RAY_ML_2_8_0_PY310_GPU = "anyscale/ray-ml:2.8.0-py310-gpu"
    ANYSCALE_RAY_ML_2_8_0_PY38_CPU = "anyscale/ray-ml:2.8.0-py38-cpu"
    ANYSCALE_RAY_ML_2_8_0_PY38_GPU = "anyscale/ray-ml:2.8.0-py38-gpu"
    ANYSCALE_RAY_ML_2_8_0_PY39_CPU = "anyscale/ray-ml:2.8.0-py39-cpu"
    ANYSCALE_RAY_ML_2_8_0_PY39_GPU = "anyscale/ray-ml:2.8.0-py39-gpu"
    ANYSCALE_RAY_ML_2_8_1_PY310_CPU = "anyscale/ray-ml:2.8.1-py310-cpu"
    ANYSCALE_RAY_ML_2_8_1_PY310_GPU = "anyscale/ray-ml:2.8.1-py310-gpu"
    ANYSCALE_RAY_ML_2_8_1_PY38_CPU = "anyscale/ray-ml:2.8.1-py38-cpu"
    ANYSCALE_RAY_ML_2_8_1_PY38_GPU = "anyscale/ray-ml:2.8.1-py38-gpu"
    ANYSCALE_RAY_ML_2_8_1_PY39_CPU = "anyscale/ray-ml:2.8.1-py39-cpu"
    ANYSCALE_RAY_ML_2_8_1_PY39_GPU = "anyscale/ray-ml:2.8.1-py39-gpu"
    ANYSCALE_RAY_ML_2_9_0_PY310_CPU = "anyscale/ray-ml:2.9.0-py310-cpu"
    ANYSCALE_RAY_ML_2_9_0_PY310_GPU = "anyscale/ray-ml:2.9.0-py310-gpu"
    ANYSCALE_RAY_ML_2_9_0_PY38_CPU = "anyscale/ray-ml:2.9.0-py38-cpu"
    ANYSCALE_RAY_ML_2_9_0_PY38_GPU = "anyscale/ray-ml:2.9.0-py38-gpu"
    ANYSCALE_RAY_ML_2_9_0_PY39_CPU = "anyscale/ray-ml:2.9.0-py39-cpu"
    ANYSCALE_RAY_ML_2_9_0_PY39_GPU = "anyscale/ray-ml:2.9.0-py39-gpu"
    ANYSCALE_RAY_ML_2_9_1_PY310_CPU = "anyscale/ray-ml:2.9.1-py310-cpu"
    ANYSCALE_RAY_ML_2_9_1_PY310_GPU = "anyscale/ray-ml:2.9.1-py310-gpu"
    ANYSCALE_RAY_ML_2_9_1_PY38_CPU = "anyscale/ray-ml:2.9.1-py38-cpu"
    ANYSCALE_RAY_ML_2_9_1_PY38_GPU = "anyscale/ray-ml:2.9.1-py38-gpu"
    ANYSCALE_RAY_ML_2_9_1_PY39_CPU = "anyscale/ray-ml:2.9.1-py39-cpu"
    ANYSCALE_RAY_ML_2_9_1_PY39_GPU = "anyscale/ray-ml:2.9.1-py39-gpu"
    ANYSCALE_RAY_ML_2_9_2_PY310_CPU = "anyscale/ray-ml:2.9.2-py310-cpu"
    ANYSCALE_RAY_ML_2_9_2_PY310_GPU = "anyscale/ray-ml:2.9.2-py310-gpu"
    ANYSCALE_RAY_ML_2_9_2_PY38_CPU = "anyscale/ray-ml:2.9.2-py38-cpu"
    ANYSCALE_RAY_ML_2_9_2_PY38_GPU = "anyscale/ray-ml:2.9.2-py38-gpu"
    ANYSCALE_RAY_ML_2_9_2_PY39_CPU = "anyscale/ray-ml:2.9.2-py39-cpu"
    ANYSCALE_RAY_ML_2_9_2_PY39_GPU = "anyscale/ray-ml:2.9.2-py39-gpu"
    ANYSCALE_RAY_ML_2_9_3_PY310_CPU = "anyscale/ray-ml:2.9.3-py310-cpu"
    ANYSCALE_RAY_ML_2_9_3_PY310_GPU = "anyscale/ray-ml:2.9.3-py310-gpu"
    ANYSCALE_RAY_ML_2_9_3_PY38_CPU = "anyscale/ray-ml:2.9.3-py38-cpu"
    ANYSCALE_RAY_ML_2_9_3_PY38_GPU = "anyscale/ray-ml:2.9.3-py38-gpu"
    ANYSCALE_RAY_ML_2_9_3_PY39_CPU = "anyscale/ray-ml:2.9.3-py39-cpu"
    ANYSCALE_RAY_ML_2_9_3_PY39_GPU = "anyscale/ray-ml:2.9.3-py39-gpu"
    ANYSCALE_RAY_ML_LATEST = "anyscale/ray-ml:latest"
    ANYSCALE_RAY_ML_NIGHTLY = "anyscale/ray-ml:nightly"
    ANYSCALE_RAY_ML_NIGHTLY_GPU = "anyscale/ray-ml:nightly-gpu"
    ANYSCALE_RAY_ML_NIGHTLY_PY310_GPU = "anyscale/ray-ml:nightly-py310-gpu"
    ANYSCALE_RAY_ML_NIGHTLY_PY311_GPU = "anyscale/ray-ml:nightly-py311-gpu"
    ANYSCALE_RAY_ML_NIGHTLY_PY312_GPU = "anyscale/ray-ml:nightly-py312-gpu"
    ANYSCALE_RAY_ML_NIGHTLY_PY36_GPU = "anyscale/ray-ml:nightly-py36-gpu"
    ANYSCALE_RAY_ML_NIGHTLY_PY37_GPU = "anyscale/ray-ml:nightly-py37-gpu"
    ANYSCALE_RAY_ML_NIGHTLY_PY38_GPU = "anyscale/ray-ml:nightly-py38-gpu"
    ANYSCALE_RAY_ML_NIGHTLY_PY39_GPU = "anyscale/ray-ml:nightly-py39-gpu"
    ANYSCALE_RAY_ML_PINNED_NIGHTLY = "anyscale/ray-ml:pinned-nightly"
    ANYSCALE_RAY_ML_PINNED_NIGHTLY_GPU = "anyscale/ray-ml:pinned-nightly-gpu"
    ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY310 = "anyscale/ray-ml:pinned-nightly-py310"
    ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY310_GPU = "anyscale/ray-ml:pinned-nightly-py310-gpu"
    ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY311 = "anyscale/ray-ml:pinned-nightly-py311"
    ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY311_GPU = "anyscale/ray-ml:pinned-nightly-py311-gpu"
    ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY312 = "anyscale/ray-ml:pinned-nightly-py312"
    ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY312_GPU = "anyscale/ray-ml:pinned-nightly-py312-gpu"
    ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY36 = "anyscale/ray-ml:pinned-nightly-py36"
    ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY36_GPU = "anyscale/ray-ml:pinned-nightly-py36-gpu"
    ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY37 = "anyscale/ray-ml:pinned-nightly-py37"
    ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY37_GPU = "anyscale/ray-ml:pinned-nightly-py37-gpu"
    ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY38 = "anyscale/ray-ml:pinned-nightly-py38"
    ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY38_GPU = "anyscale/ray-ml:pinned-nightly-py38-gpu"
    ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY39 = "anyscale/ray-ml:pinned-nightly-py39"
    ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY39_GPU = "anyscale/ray-ml:pinned-nightly-py39-gpu"
    ANYSCALE_RAY_1_10_0_PY36 = "anyscale/ray:1.10.0-py36"
    ANYSCALE_RAY_1_10_0_PY36_CU101 = "anyscale/ray:1.10.0-py36-cu101"
    ANYSCALE_RAY_1_10_0_PY36_CU102 = "anyscale/ray:1.10.0-py36-cu102"
    ANYSCALE_RAY_1_10_0_PY36_CU110 = "anyscale/ray:1.10.0-py36-cu110"
    ANYSCALE_RAY_1_10_0_PY36_CU111 = "anyscale/ray:1.10.0-py36-cu111"
    ANYSCALE_RAY_1_10_0_PY36_CU112 = "anyscale/ray:1.10.0-py36-cu112"
    ANYSCALE_RAY_1_10_0_PY37 = "anyscale/ray:1.10.0-py37"
    ANYSCALE_RAY_1_10_0_PY37_CU101 = "anyscale/ray:1.10.0-py37-cu101"
    ANYSCALE_RAY_1_10_0_PY37_CU102 = "anyscale/ray:1.10.0-py37-cu102"
    ANYSCALE_RAY_1_10_0_PY37_CU110 = "anyscale/ray:1.10.0-py37-cu110"
    ANYSCALE_RAY_1_10_0_PY37_CU111 = "anyscale/ray:1.10.0-py37-cu111"
    ANYSCALE_RAY_1_10_0_PY37_CU112 = "anyscale/ray:1.10.0-py37-cu112"
    ANYSCALE_RAY_1_10_0_PY38 = "anyscale/ray:1.10.0-py38"
    ANYSCALE_RAY_1_10_0_PY38_CU101 = "anyscale/ray:1.10.0-py38-cu101"
    ANYSCALE_RAY_1_10_0_PY38_CU102 = "anyscale/ray:1.10.0-py38-cu102"
    ANYSCALE_RAY_1_10_0_PY38_CU110 = "anyscale/ray:1.10.0-py38-cu110"
    ANYSCALE_RAY_1_10_0_PY38_CU111 = "anyscale/ray:1.10.0-py38-cu111"
    ANYSCALE_RAY_1_10_0_PY38_CU112 = "anyscale/ray:1.10.0-py38-cu112"
    ANYSCALE_RAY_1_10_0_PY39 = "anyscale/ray:1.10.0-py39"
    ANYSCALE_RAY_1_10_0_PY39_CU101 = "anyscale/ray:1.10.0-py39-cu101"
    ANYSCALE_RAY_1_10_0_PY39_CU102 = "anyscale/ray:1.10.0-py39-cu102"
    ANYSCALE_RAY_1_10_0_PY39_CU110 = "anyscale/ray:1.10.0-py39-cu110"
    ANYSCALE_RAY_1_10_0_PY39_CU111 = "anyscale/ray:1.10.0-py39-cu111"
    ANYSCALE_RAY_1_10_0_PY39_CU112 = "anyscale/ray:1.10.0-py39-cu112"
    ANYSCALE_RAY_1_10_0RC0_PY36 = "anyscale/ray:1.10.0rc0-py36"
    ANYSCALE_RAY_1_10_0RC0_PY36_CU101 = "anyscale/ray:1.10.0rc0-py36-cu101"
    ANYSCALE_RAY_1_10_0RC0_PY36_CU102 = "anyscale/ray:1.10.0rc0-py36-cu102"
    ANYSCALE_RAY_1_10_0RC0_PY36_CU110 = "anyscale/ray:1.10.0rc0-py36-cu110"
    ANYSCALE_RAY_1_10_0RC0_PY36_CU111 = "anyscale/ray:1.10.0rc0-py36-cu111"
    ANYSCALE_RAY_1_10_0RC0_PY36_CU112 = "anyscale/ray:1.10.0rc0-py36-cu112"
    ANYSCALE_RAY_1_10_0RC0_PY37 = "anyscale/ray:1.10.0rc0-py37"
    ANYSCALE_RAY_1_10_0RC0_PY37_CU101 = "anyscale/ray:1.10.0rc0-py37-cu101"
    ANYSCALE_RAY_1_10_0RC0_PY37_CU102 = "anyscale/ray:1.10.0rc0-py37-cu102"
    ANYSCALE_RAY_1_10_0RC0_PY37_CU110 = "anyscale/ray:1.10.0rc0-py37-cu110"
    ANYSCALE_RAY_1_10_0RC0_PY37_CU111 = "anyscale/ray:1.10.0rc0-py37-cu111"
    ANYSCALE_RAY_1_10_0RC0_PY37_CU112 = "anyscale/ray:1.10.0rc0-py37-cu112"
    ANYSCALE_RAY_1_10_0RC0_PY38 = "anyscale/ray:1.10.0rc0-py38"
    ANYSCALE_RAY_1_10_0RC0_PY38_CU101 = "anyscale/ray:1.10.0rc0-py38-cu101"
    ANYSCALE_RAY_1_10_0RC0_PY38_CU102 = "anyscale/ray:1.10.0rc0-py38-cu102"
    ANYSCALE_RAY_1_10_0RC0_PY38_CU110 = "anyscale/ray:1.10.0rc0-py38-cu110"
    ANYSCALE_RAY_1_10_0RC0_PY38_CU111 = "anyscale/ray:1.10.0rc0-py38-cu111"
    ANYSCALE_RAY_1_10_0RC0_PY38_CU112 = "anyscale/ray:1.10.0rc0-py38-cu112"
    ANYSCALE_RAY_1_11_0_PY36 = "anyscale/ray:1.11.0-py36"
    ANYSCALE_RAY_1_11_0_PY36_CU101 = "anyscale/ray:1.11.0-py36-cu101"
    ANYSCALE_RAY_1_11_0_PY36_CU102 = "anyscale/ray:1.11.0-py36-cu102"
    ANYSCALE_RAY_1_11_0_PY36_CU110 = "anyscale/ray:1.11.0-py36-cu110"
    ANYSCALE_RAY_1_11_0_PY36_CU111 = "anyscale/ray:1.11.0-py36-cu111"
    ANYSCALE_RAY_1_11_0_PY36_CU112 = "anyscale/ray:1.11.0-py36-cu112"
    ANYSCALE_RAY_1_11_0_PY37 = "anyscale/ray:1.11.0-py37"
    ANYSCALE_RAY_1_11_0_PY37_CU101 = "anyscale/ray:1.11.0-py37-cu101"
    ANYSCALE_RAY_1_11_0_PY37_CU102 = "anyscale/ray:1.11.0-py37-cu102"
    ANYSCALE_RAY_1_11_0_PY37_CU110 = "anyscale/ray:1.11.0-py37-cu110"
    ANYSCALE_RAY_1_11_0_PY37_CU111 = "anyscale/ray:1.11.0-py37-cu111"
    ANYSCALE_RAY_1_11_0_PY37_CU112 = "anyscale/ray:1.11.0-py37-cu112"
    ANYSCALE_RAY_1_11_0_PY38 = "anyscale/ray:1.11.0-py38"
    ANYSCALE_RAY_1_11_0_PY38_CU101 = "anyscale/ray:1.11.0-py38-cu101"
    ANYSCALE_RAY_1_11_0_PY38_CU102 = "anyscale/ray:1.11.0-py38-cu102"
    ANYSCALE_RAY_1_11_0_PY38_CU110 = "anyscale/ray:1.11.0-py38-cu110"
    ANYSCALE_RAY_1_11_0_PY38_CU111 = "anyscale/ray:1.11.0-py38-cu111"
    ANYSCALE_RAY_1_11_0_PY38_CU112 = "anyscale/ray:1.11.0-py38-cu112"
    ANYSCALE_RAY_1_11_0_PY39 = "anyscale/ray:1.11.0-py39"
    ANYSCALE_RAY_1_11_0_PY39_CU101 = "anyscale/ray:1.11.0-py39-cu101"
    ANYSCALE_RAY_1_11_0_PY39_CU102 = "anyscale/ray:1.11.0-py39-cu102"
    ANYSCALE_RAY_1_11_0_PY39_CU110 = "anyscale/ray:1.11.0-py39-cu110"
    ANYSCALE_RAY_1_11_0_PY39_CU111 = "anyscale/ray:1.11.0-py39-cu111"
    ANYSCALE_RAY_1_11_0_PY39_CU112 = "anyscale/ray:1.11.0-py39-cu112"
    ANYSCALE_RAY_1_11_1_PY36 = "anyscale/ray:1.11.1-py36"
    ANYSCALE_RAY_1_11_1_PY36_CU101 = "anyscale/ray:1.11.1-py36-cu101"
    ANYSCALE_RAY_1_11_1_PY36_CU102 = "anyscale/ray:1.11.1-py36-cu102"
    ANYSCALE_RAY_1_11_1_PY36_CU110 = "anyscale/ray:1.11.1-py36-cu110"
    ANYSCALE_RAY_1_11_1_PY36_CU111 = "anyscale/ray:1.11.1-py36-cu111"
    ANYSCALE_RAY_1_11_1_PY36_CU112 = "anyscale/ray:1.11.1-py36-cu112"
    ANYSCALE_RAY_1_11_1_PY37 = "anyscale/ray:1.11.1-py37"
    ANYSCALE_RAY_1_11_1_PY37_CU101 = "anyscale/ray:1.11.1-py37-cu101"
    ANYSCALE_RAY_1_11_1_PY37_CU102 = "anyscale/ray:1.11.1-py37-cu102"
    ANYSCALE_RAY_1_11_1_PY37_CU110 = "anyscale/ray:1.11.1-py37-cu110"
    ANYSCALE_RAY_1_11_1_PY37_CU111 = "anyscale/ray:1.11.1-py37-cu111"
    ANYSCALE_RAY_1_11_1_PY37_CU112 = "anyscale/ray:1.11.1-py37-cu112"
    ANYSCALE_RAY_1_11_1_PY38 = "anyscale/ray:1.11.1-py38"
    ANYSCALE_RAY_1_11_1_PY38_CU101 = "anyscale/ray:1.11.1-py38-cu101"
    ANYSCALE_RAY_1_11_1_PY38_CU102 = "anyscale/ray:1.11.1-py38-cu102"
    ANYSCALE_RAY_1_11_1_PY38_CU110 = "anyscale/ray:1.11.1-py38-cu110"
    ANYSCALE_RAY_1_11_1_PY38_CU111 = "anyscale/ray:1.11.1-py38-cu111"
    ANYSCALE_RAY_1_11_1_PY38_CU112 = "anyscale/ray:1.11.1-py38-cu112"
    ANYSCALE_RAY_1_11_1_PY39 = "anyscale/ray:1.11.1-py39"
    ANYSCALE_RAY_1_11_1_PY39_CU101 = "anyscale/ray:1.11.1-py39-cu101"
    ANYSCALE_RAY_1_11_1_PY39_CU102 = "anyscale/ray:1.11.1-py39-cu102"
    ANYSCALE_RAY_1_11_1_PY39_CU110 = "anyscale/ray:1.11.1-py39-cu110"
    ANYSCALE_RAY_1_11_1_PY39_CU111 = "anyscale/ray:1.11.1-py39-cu111"
    ANYSCALE_RAY_1_11_1_PY39_CU112 = "anyscale/ray:1.11.1-py39-cu112"
    ANYSCALE_RAY_1_12_0_PY36 = "anyscale/ray:1.12.0-py36"
    ANYSCALE_RAY_1_12_0_PY36_CU101 = "anyscale/ray:1.12.0-py36-cu101"
    ANYSCALE_RAY_1_12_0_PY36_CU102 = "anyscale/ray:1.12.0-py36-cu102"
    ANYSCALE_RAY_1_12_0_PY36_CU110 = "anyscale/ray:1.12.0-py36-cu110"
    ANYSCALE_RAY_1_12_0_PY36_CU111 = "anyscale/ray:1.12.0-py36-cu111"
    ANYSCALE_RAY_1_12_0_PY36_CU112 = "anyscale/ray:1.12.0-py36-cu112"
    ANYSCALE_RAY_1_12_0_PY37 = "anyscale/ray:1.12.0-py37"
    ANYSCALE_RAY_1_12_0_PY37_CU101 = "anyscale/ray:1.12.0-py37-cu101"
    ANYSCALE_RAY_1_12_0_PY37_CU102 = "anyscale/ray:1.12.0-py37-cu102"
    ANYSCALE_RAY_1_12_0_PY37_CU110 = "anyscale/ray:1.12.0-py37-cu110"
    ANYSCALE_RAY_1_12_0_PY37_CU111 = "anyscale/ray:1.12.0-py37-cu111"
    ANYSCALE_RAY_1_12_0_PY37_CU112 = "anyscale/ray:1.12.0-py37-cu112"
    ANYSCALE_RAY_1_12_0_PY38 = "anyscale/ray:1.12.0-py38"
    ANYSCALE_RAY_1_12_0_PY38_CU101 = "anyscale/ray:1.12.0-py38-cu101"
    ANYSCALE_RAY_1_12_0_PY38_CU102 = "anyscale/ray:1.12.0-py38-cu102"
    ANYSCALE_RAY_1_12_0_PY38_CU110 = "anyscale/ray:1.12.0-py38-cu110"
    ANYSCALE_RAY_1_12_0_PY38_CU111 = "anyscale/ray:1.12.0-py38-cu111"
    ANYSCALE_RAY_1_12_0_PY38_CU112 = "anyscale/ray:1.12.0-py38-cu112"
    ANYSCALE_RAY_1_12_0_PY39 = "anyscale/ray:1.12.0-py39"
    ANYSCALE_RAY_1_12_0_PY39_CU101 = "anyscale/ray:1.12.0-py39-cu101"
    ANYSCALE_RAY_1_12_0_PY39_CU102 = "anyscale/ray:1.12.0-py39-cu102"
    ANYSCALE_RAY_1_12_0_PY39_CU110 = "anyscale/ray:1.12.0-py39-cu110"
    ANYSCALE_RAY_1_12_0_PY39_CU111 = "anyscale/ray:1.12.0-py39-cu111"
    ANYSCALE_RAY_1_12_0_PY39_CU112 = "anyscale/ray:1.12.0-py39-cu112"
    ANYSCALE_RAY_1_12_1_PY36 = "anyscale/ray:1.12.1-py36"
    ANYSCALE_RAY_1_12_1_PY36_CU101 = "anyscale/ray:1.12.1-py36-cu101"
    ANYSCALE_RAY_1_12_1_PY36_CU102 = "anyscale/ray:1.12.1-py36-cu102"
    ANYSCALE_RAY_1_12_1_PY36_CU110 = "anyscale/ray:1.12.1-py36-cu110"
    ANYSCALE_RAY_1_12_1_PY36_CU111 = "anyscale/ray:1.12.1-py36-cu111"
    ANYSCALE_RAY_1_12_1_PY36_CU112 = "anyscale/ray:1.12.1-py36-cu112"
    ANYSCALE_RAY_1_12_1_PY37 = "anyscale/ray:1.12.1-py37"
    ANYSCALE_RAY_1_12_1_PY37_CU101 = "anyscale/ray:1.12.1-py37-cu101"
    ANYSCALE_RAY_1_12_1_PY37_CU102 = "anyscale/ray:1.12.1-py37-cu102"
    ANYSCALE_RAY_1_12_1_PY37_CU110 = "anyscale/ray:1.12.1-py37-cu110"
    ANYSCALE_RAY_1_12_1_PY37_CU111 = "anyscale/ray:1.12.1-py37-cu111"
    ANYSCALE_RAY_1_12_1_PY37_CU112 = "anyscale/ray:1.12.1-py37-cu112"
    ANYSCALE_RAY_1_12_1_PY38 = "anyscale/ray:1.12.1-py38"
    ANYSCALE_RAY_1_12_1_PY38_CU101 = "anyscale/ray:1.12.1-py38-cu101"
    ANYSCALE_RAY_1_12_1_PY38_CU102 = "anyscale/ray:1.12.1-py38-cu102"
    ANYSCALE_RAY_1_12_1_PY38_CU110 = "anyscale/ray:1.12.1-py38-cu110"
    ANYSCALE_RAY_1_12_1_PY38_CU111 = "anyscale/ray:1.12.1-py38-cu111"
    ANYSCALE_RAY_1_12_1_PY38_CU112 = "anyscale/ray:1.12.1-py38-cu112"
    ANYSCALE_RAY_1_12_1_PY39 = "anyscale/ray:1.12.1-py39"
    ANYSCALE_RAY_1_12_1_PY39_CU101 = "anyscale/ray:1.12.1-py39-cu101"
    ANYSCALE_RAY_1_12_1_PY39_CU102 = "anyscale/ray:1.12.1-py39-cu102"
    ANYSCALE_RAY_1_12_1_PY39_CU110 = "anyscale/ray:1.12.1-py39-cu110"
    ANYSCALE_RAY_1_12_1_PY39_CU111 = "anyscale/ray:1.12.1-py39-cu111"
    ANYSCALE_RAY_1_12_1_PY39_CU112 = "anyscale/ray:1.12.1-py39-cu112"
    ANYSCALE_RAY_1_13_0_PY310 = "anyscale/ray:1.13.0-py310"
    ANYSCALE_RAY_1_13_0_PY36 = "anyscale/ray:1.13.0-py36"
    ANYSCALE_RAY_1_13_0_PY36_CU101 = "anyscale/ray:1.13.0-py36-cu101"
    ANYSCALE_RAY_1_13_0_PY36_CU102 = "anyscale/ray:1.13.0-py36-cu102"
    ANYSCALE_RAY_1_13_0_PY36_CU110 = "anyscale/ray:1.13.0-py36-cu110"
    ANYSCALE_RAY_1_13_0_PY36_CU111 = "anyscale/ray:1.13.0-py36-cu111"
    ANYSCALE_RAY_1_13_0_PY36_CU112 = "anyscale/ray:1.13.0-py36-cu112"
    ANYSCALE_RAY_1_13_0_PY37 = "anyscale/ray:1.13.0-py37"
    ANYSCALE_RAY_1_13_0_PY37_CU101 = "anyscale/ray:1.13.0-py37-cu101"
    ANYSCALE_RAY_1_13_0_PY37_CU102 = "anyscale/ray:1.13.0-py37-cu102"
    ANYSCALE_RAY_1_13_0_PY37_CU110 = "anyscale/ray:1.13.0-py37-cu110"
    ANYSCALE_RAY_1_13_0_PY37_CU111 = "anyscale/ray:1.13.0-py37-cu111"
    ANYSCALE_RAY_1_13_0_PY37_CU112 = "anyscale/ray:1.13.0-py37-cu112"
    ANYSCALE_RAY_1_13_0_PY38 = "anyscale/ray:1.13.0-py38"
    ANYSCALE_RAY_1_13_0_PY38_CU101 = "anyscale/ray:1.13.0-py38-cu101"
    ANYSCALE_RAY_1_13_0_PY38_CU102 = "anyscale/ray:1.13.0-py38-cu102"
    ANYSCALE_RAY_1_13_0_PY38_CU110 = "anyscale/ray:1.13.0-py38-cu110"
    ANYSCALE_RAY_1_13_0_PY38_CU111 = "anyscale/ray:1.13.0-py38-cu111"
    ANYSCALE_RAY_1_13_0_PY38_CU112 = "anyscale/ray:1.13.0-py38-cu112"
    ANYSCALE_RAY_1_13_0_PY39 = "anyscale/ray:1.13.0-py39"
    ANYSCALE_RAY_1_13_0_PY39_CU101 = "anyscale/ray:1.13.0-py39-cu101"
    ANYSCALE_RAY_1_13_0_PY39_CU102 = "anyscale/ray:1.13.0-py39-cu102"
    ANYSCALE_RAY_1_13_0_PY39_CU110 = "anyscale/ray:1.13.0-py39-cu110"
    ANYSCALE_RAY_1_13_0_PY39_CU111 = "anyscale/ray:1.13.0-py39-cu111"
    ANYSCALE_RAY_1_13_0_PY39_CU112 = "anyscale/ray:1.13.0-py39-cu112"
    ANYSCALE_RAY_1_13_0RC0_PY36 = "anyscale/ray:1.13.0rc0-py36"
    ANYSCALE_RAY_1_13_0RC0_PY36_CU101 = "anyscale/ray:1.13.0rc0-py36-cu101"
    ANYSCALE_RAY_1_13_0RC0_PY36_CU102 = "anyscale/ray:1.13.0rc0-py36-cu102"
    ANYSCALE_RAY_1_13_0RC0_PY36_CU110 = "anyscale/ray:1.13.0rc0-py36-cu110"
    ANYSCALE_RAY_1_13_0RC0_PY36_CU111 = "anyscale/ray:1.13.0rc0-py36-cu111"
    ANYSCALE_RAY_1_13_0RC0_PY36_CU112 = "anyscale/ray:1.13.0rc0-py36-cu112"
    ANYSCALE_RAY_1_13_0RC0_PY37 = "anyscale/ray:1.13.0rc0-py37"
    ANYSCALE_RAY_1_13_0RC0_PY37_CU101 = "anyscale/ray:1.13.0rc0-py37-cu101"
    ANYSCALE_RAY_1_13_0RC0_PY37_CU102 = "anyscale/ray:1.13.0rc0-py37-cu102"
    ANYSCALE_RAY_1_13_0RC0_PY37_CU110 = "anyscale/ray:1.13.0rc0-py37-cu110"
    ANYSCALE_RAY_1_13_0RC0_PY37_CU111 = "anyscale/ray:1.13.0rc0-py37-cu111"
    ANYSCALE_RAY_1_13_0RC0_PY37_CU112 = "anyscale/ray:1.13.0rc0-py37-cu112"
    ANYSCALE_RAY_1_13_0RC0_PY38 = "anyscale/ray:1.13.0rc0-py38"
    ANYSCALE_RAY_1_13_0RC0_PY38_CU101 = "anyscale/ray:1.13.0rc0-py38-cu101"
    ANYSCALE_RAY_1_13_0RC0_PY38_CU102 = "anyscale/ray:1.13.0rc0-py38-cu102"
    ANYSCALE_RAY_1_13_0RC0_PY38_CU110 = "anyscale/ray:1.13.0rc0-py38-cu110"
    ANYSCALE_RAY_1_13_0RC0_PY38_CU111 = "anyscale/ray:1.13.0rc0-py38-cu111"
    ANYSCALE_RAY_1_13_0RC0_PY38_CU112 = "anyscale/ray:1.13.0rc0-py38-cu112"
    ANYSCALE_RAY_1_13_0RC0_PY39 = "anyscale/ray:1.13.0rc0-py39"
    ANYSCALE_RAY_1_13_0RC0_PY39_CU101 = "anyscale/ray:1.13.0rc0-py39-cu101"
    ANYSCALE_RAY_1_13_0RC0_PY39_CU102 = "anyscale/ray:1.13.0rc0-py39-cu102"
    ANYSCALE_RAY_1_13_0RC0_PY39_CU110 = "anyscale/ray:1.13.0rc0-py39-cu110"
    ANYSCALE_RAY_1_13_0RC0_PY39_CU111 = "anyscale/ray:1.13.0rc0-py39-cu111"
    ANYSCALE_RAY_1_13_0RC0_PY39_CU112 = "anyscale/ray:1.13.0rc0-py39-cu112"
    ANYSCALE_RAY_1_7_0 = "anyscale/ray:1.7.0"
    ANYSCALE_RAY_1_7_0_GPU = "anyscale/ray:1.7.0-gpu"
    ANYSCALE_RAY_1_7_0_PY36 = "anyscale/ray:1.7.0-py36"
    ANYSCALE_RAY_1_7_0_PY36_GPU = "anyscale/ray:1.7.0-py36-gpu"
    ANYSCALE_RAY_1_7_0_PY37 = "anyscale/ray:1.7.0-py37"
    ANYSCALE_RAY_1_7_0_PY37_GPU = "anyscale/ray:1.7.0-py37-gpu"
    ANYSCALE_RAY_1_7_0_PY38 = "anyscale/ray:1.7.0-py38"
    ANYSCALE_RAY_1_7_0_PY38_GPU = "anyscale/ray:1.7.0-py38-gpu"
    ANYSCALE_RAY_1_7_0RC0 = "anyscale/ray:1.7.0rc0"
    ANYSCALE_RAY_1_7_0RC0_GPU = "anyscale/ray:1.7.0rc0-gpu"
    ANYSCALE_RAY_1_7_0RC0_PY36 = "anyscale/ray:1.7.0rc0-py36"
    ANYSCALE_RAY_1_7_0RC0_PY36_GPU = "anyscale/ray:1.7.0rc0-py36-gpu"
    ANYSCALE_RAY_1_7_0RC0_PY37 = "anyscale/ray:1.7.0rc0-py37"
    ANYSCALE_RAY_1_7_0RC0_PY37_GPU = "anyscale/ray:1.7.0rc0-py37-gpu"
    ANYSCALE_RAY_1_7_0RC0_PY38 = "anyscale/ray:1.7.0rc0-py38"
    ANYSCALE_RAY_1_7_0RC0_PY38_GPU = "anyscale/ray:1.7.0rc0-py38-gpu"
    ANYSCALE_RAY_1_7_1 = "anyscale/ray:1.7.1"
    ANYSCALE_RAY_1_7_1_GPU = "anyscale/ray:1.7.1-gpu"
    ANYSCALE_RAY_1_7_1_PY36 = "anyscale/ray:1.7.1-py36"
    ANYSCALE_RAY_1_7_1_PY36_GPU = "anyscale/ray:1.7.1-py36-gpu"
    ANYSCALE_RAY_1_7_1_PY37 = "anyscale/ray:1.7.1-py37"
    ANYSCALE_RAY_1_7_1_PY37_GPU = "anyscale/ray:1.7.1-py37-gpu"
    ANYSCALE_RAY_1_7_1_PY38 = "anyscale/ray:1.7.1-py38"
    ANYSCALE_RAY_1_7_1_PY38_GPU = "anyscale/ray:1.7.1-py38-gpu"
    ANYSCALE_RAY_1_8_0 = "anyscale/ray:1.8.0"
    ANYSCALE_RAY_1_8_0_GPU = "anyscale/ray:1.8.0-gpu"
    ANYSCALE_RAY_1_8_0_PY36 = "anyscale/ray:1.8.0-py36"
    ANYSCALE_RAY_1_8_0_PY36_GPU = "anyscale/ray:1.8.0-py36-gpu"
    ANYSCALE_RAY_1_8_0_PY37 = "anyscale/ray:1.8.0-py37"
    ANYSCALE_RAY_1_8_0_PY37_GPU = "anyscale/ray:1.8.0-py37-gpu"
    ANYSCALE_RAY_1_8_0_PY38 = "anyscale/ray:1.8.0-py38"
    ANYSCALE_RAY_1_8_0_PY38_GPU = "anyscale/ray:1.8.0-py38-gpu"
    ANYSCALE_RAY_1_9_0_PY36 = "anyscale/ray:1.9.0-py36"
    ANYSCALE_RAY_1_9_0_PY36_CU101 = "anyscale/ray:1.9.0-py36-cu101"
    ANYSCALE_RAY_1_9_0_PY36_CU102 = "anyscale/ray:1.9.0-py36-cu102"
    ANYSCALE_RAY_1_9_0_PY36_CU110 = "anyscale/ray:1.9.0-py36-cu110"
    ANYSCALE_RAY_1_9_0_PY36_CU111 = "anyscale/ray:1.9.0-py36-cu111"
    ANYSCALE_RAY_1_9_0_PY36_CU112 = "anyscale/ray:1.9.0-py36-cu112"
    ANYSCALE_RAY_1_9_0_PY37 = "anyscale/ray:1.9.0-py37"
    ANYSCALE_RAY_1_9_0_PY37_CU101 = "anyscale/ray:1.9.0-py37-cu101"
    ANYSCALE_RAY_1_9_0_PY37_CU102 = "anyscale/ray:1.9.0-py37-cu102"
    ANYSCALE_RAY_1_9_0_PY37_CU110 = "anyscale/ray:1.9.0-py37-cu110"
    ANYSCALE_RAY_1_9_0_PY37_CU111 = "anyscale/ray:1.9.0-py37-cu111"
    ANYSCALE_RAY_1_9_0_PY37_CU112 = "anyscale/ray:1.9.0-py37-cu112"
    ANYSCALE_RAY_1_9_0_PY38 = "anyscale/ray:1.9.0-py38"
    ANYSCALE_RAY_1_9_0_PY38_CU101 = "anyscale/ray:1.9.0-py38-cu101"
    ANYSCALE_RAY_1_9_0_PY38_CU102 = "anyscale/ray:1.9.0-py38-cu102"
    ANYSCALE_RAY_1_9_0_PY38_CU110 = "anyscale/ray:1.9.0-py38-cu110"
    ANYSCALE_RAY_1_9_0_PY38_CU111 = "anyscale/ray:1.9.0-py38-cu111"
    ANYSCALE_RAY_1_9_0_PY38_CU112 = "anyscale/ray:1.9.0-py38-cu112"
    ANYSCALE_RAY_1_9_0_PY39 = "anyscale/ray:1.9.0-py39"
    ANYSCALE_RAY_1_9_0_PY39_CU101 = "anyscale/ray:1.9.0-py39-cu101"
    ANYSCALE_RAY_1_9_0_PY39_CU102 = "anyscale/ray:1.9.0-py39-cu102"
    ANYSCALE_RAY_1_9_0_PY39_CU110 = "anyscale/ray:1.9.0-py39-cu110"
    ANYSCALE_RAY_1_9_0_PY39_CU111 = "anyscale/ray:1.9.0-py39-cu111"
    ANYSCALE_RAY_1_9_0_PY39_CU112 = "anyscale/ray:1.9.0-py39-cu112"
    ANYSCALE_RAY_1_9_0RC1_PY36 = "anyscale/ray:1.9.0rc1-py36"
    ANYSCALE_RAY_1_9_0RC1_PY36_CU101 = "anyscale/ray:1.9.0rc1-py36-cu101"
    ANYSCALE_RAY_1_9_0RC1_PY36_CU102 = "anyscale/ray:1.9.0rc1-py36-cu102"
    ANYSCALE_RAY_1_9_0RC1_PY36_CU110 = "anyscale/ray:1.9.0rc1-py36-cu110"
    ANYSCALE_RAY_1_9_0RC1_PY36_CU111 = "anyscale/ray:1.9.0rc1-py36-cu111"
    ANYSCALE_RAY_1_9_0RC1_PY36_CU112 = "anyscale/ray:1.9.0rc1-py36-cu112"
    ANYSCALE_RAY_1_9_0RC1_PY37 = "anyscale/ray:1.9.0rc1-py37"
    ANYSCALE_RAY_1_9_0RC1_PY37_CU101 = "anyscale/ray:1.9.0rc1-py37-cu101"
    ANYSCALE_RAY_1_9_0RC1_PY37_CU102 = "anyscale/ray:1.9.0rc1-py37-cu102"
    ANYSCALE_RAY_1_9_0RC1_PY37_CU110 = "anyscale/ray:1.9.0rc1-py37-cu110"
    ANYSCALE_RAY_1_9_0RC1_PY37_CU111 = "anyscale/ray:1.9.0rc1-py37-cu111"
    ANYSCALE_RAY_1_9_0RC1_PY37_CU112 = "anyscale/ray:1.9.0rc1-py37-cu112"
    ANYSCALE_RAY_1_9_0RC1_PY38 = "anyscale/ray:1.9.0rc1-py38"
    ANYSCALE_RAY_1_9_0RC1_PY38_CU101 = "anyscale/ray:1.9.0rc1-py38-cu101"
    ANYSCALE_RAY_1_9_0RC1_PY38_CU102 = "anyscale/ray:1.9.0rc1-py38-cu102"
    ANYSCALE_RAY_1_9_0RC1_PY38_CU110 = "anyscale/ray:1.9.0rc1-py38-cu110"
    ANYSCALE_RAY_1_9_0RC1_PY38_CU111 = "anyscale/ray:1.9.0rc1-py38-cu111"
    ANYSCALE_RAY_1_9_0RC1_PY38_CU112 = "anyscale/ray:1.9.0rc1-py38-cu112"
    ANYSCALE_RAY_1_9_0RC2_PY36 = "anyscale/ray:1.9.0rc2-py36"
    ANYSCALE_RAY_1_9_0RC2_PY36_CU101 = "anyscale/ray:1.9.0rc2-py36-cu101"
    ANYSCALE_RAY_1_9_0RC2_PY36_CU102 = "anyscale/ray:1.9.0rc2-py36-cu102"
    ANYSCALE_RAY_1_9_0RC2_PY36_CU110 = "anyscale/ray:1.9.0rc2-py36-cu110"
    ANYSCALE_RAY_1_9_0RC2_PY36_CU111 = "anyscale/ray:1.9.0rc2-py36-cu111"
    ANYSCALE_RAY_1_9_0RC2_PY36_CU112 = "anyscale/ray:1.9.0rc2-py36-cu112"
    ANYSCALE_RAY_1_9_0RC2_PY37 = "anyscale/ray:1.9.0rc2-py37"
    ANYSCALE_RAY_1_9_0RC2_PY37_CU101 = "anyscale/ray:1.9.0rc2-py37-cu101"
    ANYSCALE_RAY_1_9_0RC2_PY37_CU102 = "anyscale/ray:1.9.0rc2-py37-cu102"
    ANYSCALE_RAY_1_9_0RC2_PY37_CU110 = "anyscale/ray:1.9.0rc2-py37-cu110"
    ANYSCALE_RAY_1_9_0RC2_PY37_CU111 = "anyscale/ray:1.9.0rc2-py37-cu111"
    ANYSCALE_RAY_1_9_0RC2_PY37_CU112 = "anyscale/ray:1.9.0rc2-py37-cu112"
    ANYSCALE_RAY_1_9_0RC2_PY38 = "anyscale/ray:1.9.0rc2-py38"
    ANYSCALE_RAY_1_9_0RC2_PY38_CU101 = "anyscale/ray:1.9.0rc2-py38-cu101"
    ANYSCALE_RAY_1_9_0RC2_PY38_CU102 = "anyscale/ray:1.9.0rc2-py38-cu102"
    ANYSCALE_RAY_1_9_0RC2_PY38_CU110 = "anyscale/ray:1.9.0rc2-py38-cu110"
    ANYSCALE_RAY_1_9_0RC2_PY38_CU111 = "anyscale/ray:1.9.0rc2-py38-cu111"
    ANYSCALE_RAY_1_9_0RC2_PY38_CU112 = "anyscale/ray:1.9.0rc2-py38-cu112"
    ANYSCALE_RAY_1_9_1_PY36 = "anyscale/ray:1.9.1-py36"
    ANYSCALE_RAY_1_9_1_PY36_CU101 = "anyscale/ray:1.9.1-py36-cu101"
    ANYSCALE_RAY_1_9_1_PY36_CU102 = "anyscale/ray:1.9.1-py36-cu102"
    ANYSCALE_RAY_1_9_1_PY36_CU110 = "anyscale/ray:1.9.1-py36-cu110"
    ANYSCALE_RAY_1_9_1_PY36_CU111 = "anyscale/ray:1.9.1-py36-cu111"
    ANYSCALE_RAY_1_9_1_PY36_CU112 = "anyscale/ray:1.9.1-py36-cu112"
    ANYSCALE_RAY_1_9_1_PY37 = "anyscale/ray:1.9.1-py37"
    ANYSCALE_RAY_1_9_1_PY37_CU101 = "anyscale/ray:1.9.1-py37-cu101"
    ANYSCALE_RAY_1_9_1_PY37_CU102 = "anyscale/ray:1.9.1-py37-cu102"
    ANYSCALE_RAY_1_9_1_PY37_CU110 = "anyscale/ray:1.9.1-py37-cu110"
    ANYSCALE_RAY_1_9_1_PY37_CU111 = "anyscale/ray:1.9.1-py37-cu111"
    ANYSCALE_RAY_1_9_1_PY37_CU112 = "anyscale/ray:1.9.1-py37-cu112"
    ANYSCALE_RAY_1_9_1_PY38 = "anyscale/ray:1.9.1-py38"
    ANYSCALE_RAY_1_9_1_PY38_CU101 = "anyscale/ray:1.9.1-py38-cu101"
    ANYSCALE_RAY_1_9_1_PY38_CU102 = "anyscale/ray:1.9.1-py38-cu102"
    ANYSCALE_RAY_1_9_1_PY38_CU110 = "anyscale/ray:1.9.1-py38-cu110"
    ANYSCALE_RAY_1_9_1_PY38_CU111 = "anyscale/ray:1.9.1-py38-cu111"
    ANYSCALE_RAY_1_9_1_PY38_CU112 = "anyscale/ray:1.9.1-py38-cu112"
    ANYSCALE_RAY_1_9_1_PY39 = "anyscale/ray:1.9.1-py39"
    ANYSCALE_RAY_1_9_1_PY39_CU101 = "anyscale/ray:1.9.1-py39-cu101"
    ANYSCALE_RAY_1_9_1_PY39_CU102 = "anyscale/ray:1.9.1-py39-cu102"
    ANYSCALE_RAY_1_9_1_PY39_CU110 = "anyscale/ray:1.9.1-py39-cu110"
    ANYSCALE_RAY_1_9_1_PY39_CU111 = "anyscale/ray:1.9.1-py39-cu111"
    ANYSCALE_RAY_1_9_1_PY39_CU112 = "anyscale/ray:1.9.1-py39-cu112"
    ANYSCALE_RAY_1_9_1RC0_PY36 = "anyscale/ray:1.9.1rc0-py36"
    ANYSCALE_RAY_1_9_1RC0_PY36_CU101 = "anyscale/ray:1.9.1rc0-py36-cu101"
    ANYSCALE_RAY_1_9_1RC0_PY36_CU102 = "anyscale/ray:1.9.1rc0-py36-cu102"
    ANYSCALE_RAY_1_9_1RC0_PY36_CU110 = "anyscale/ray:1.9.1rc0-py36-cu110"
    ANYSCALE_RAY_1_9_1RC0_PY36_CU111 = "anyscale/ray:1.9.1rc0-py36-cu111"
    ANYSCALE_RAY_1_9_1RC0_PY36_CU112 = "anyscale/ray:1.9.1rc0-py36-cu112"
    ANYSCALE_RAY_1_9_1RC0_PY37 = "anyscale/ray:1.9.1rc0-py37"
    ANYSCALE_RAY_1_9_1RC0_PY37_CU101 = "anyscale/ray:1.9.1rc0-py37-cu101"
    ANYSCALE_RAY_1_9_1RC0_PY37_CU102 = "anyscale/ray:1.9.1rc0-py37-cu102"
    ANYSCALE_RAY_1_9_1RC0_PY37_CU110 = "anyscale/ray:1.9.1rc0-py37-cu110"
    ANYSCALE_RAY_1_9_1RC0_PY37_CU111 = "anyscale/ray:1.9.1rc0-py37-cu111"
    ANYSCALE_RAY_1_9_1RC0_PY37_CU112 = "anyscale/ray:1.9.1rc0-py37-cu112"
    ANYSCALE_RAY_1_9_1RC0_PY38 = "anyscale/ray:1.9.1rc0-py38"
    ANYSCALE_RAY_1_9_1RC0_PY38_CU101 = "anyscale/ray:1.9.1rc0-py38-cu101"
    ANYSCALE_RAY_1_9_1RC0_PY38_CU102 = "anyscale/ray:1.9.1rc0-py38-cu102"
    ANYSCALE_RAY_1_9_1RC0_PY38_CU110 = "anyscale/ray:1.9.1rc0-py38-cu110"
    ANYSCALE_RAY_1_9_1RC0_PY38_CU111 = "anyscale/ray:1.9.1rc0-py38-cu111"
    ANYSCALE_RAY_1_9_1RC0_PY38_CU112 = "anyscale/ray:1.9.1rc0-py38-cu112"
    ANYSCALE_RAY_1_9_2_PY36 = "anyscale/ray:1.9.2-py36"
    ANYSCALE_RAY_1_9_2_PY36_CU101 = "anyscale/ray:1.9.2-py36-cu101"
    ANYSCALE_RAY_1_9_2_PY36_CU102 = "anyscale/ray:1.9.2-py36-cu102"
    ANYSCALE_RAY_1_9_2_PY36_CU110 = "anyscale/ray:1.9.2-py36-cu110"
    ANYSCALE_RAY_1_9_2_PY36_CU111 = "anyscale/ray:1.9.2-py36-cu111"
    ANYSCALE_RAY_1_9_2_PY36_CU112 = "anyscale/ray:1.9.2-py36-cu112"
    ANYSCALE_RAY_1_9_2_PY37 = "anyscale/ray:1.9.2-py37"
    ANYSCALE_RAY_1_9_2_PY37_CU101 = "anyscale/ray:1.9.2-py37-cu101"
    ANYSCALE_RAY_1_9_2_PY37_CU102 = "anyscale/ray:1.9.2-py37-cu102"
    ANYSCALE_RAY_1_9_2_PY37_CU110 = "anyscale/ray:1.9.2-py37-cu110"
    ANYSCALE_RAY_1_9_2_PY37_CU111 = "anyscale/ray:1.9.2-py37-cu111"
    ANYSCALE_RAY_1_9_2_PY37_CU112 = "anyscale/ray:1.9.2-py37-cu112"
    ANYSCALE_RAY_1_9_2_PY38 = "anyscale/ray:1.9.2-py38"
    ANYSCALE_RAY_1_9_2_PY38_CU101 = "anyscale/ray:1.9.2-py38-cu101"
    ANYSCALE_RAY_1_9_2_PY38_CU102 = "anyscale/ray:1.9.2-py38-cu102"
    ANYSCALE_RAY_1_9_2_PY38_CU110 = "anyscale/ray:1.9.2-py38-cu110"
    ANYSCALE_RAY_1_9_2_PY38_CU111 = "anyscale/ray:1.9.2-py38-cu111"
    ANYSCALE_RAY_1_9_2_PY38_CU112 = "anyscale/ray:1.9.2-py38-cu112"
    ANYSCALE_RAY_1_9_2_PY39 = "anyscale/ray:1.9.2-py39"
    ANYSCALE_RAY_1_9_2_PY39_CU101 = "anyscale/ray:1.9.2-py39-cu101"
    ANYSCALE_RAY_1_9_2_PY39_CU102 = "anyscale/ray:1.9.2-py39-cu102"
    ANYSCALE_RAY_1_9_2_PY39_CU110 = "anyscale/ray:1.9.2-py39-cu110"
    ANYSCALE_RAY_1_9_2_PY39_CU111 = "anyscale/ray:1.9.2-py39-cu111"
    ANYSCALE_RAY_1_9_2_PY39_CU112 = "anyscale/ray:1.9.2-py39-cu112"
    ANYSCALE_RAY_2_0_0_PY310 = "anyscale/ray:2.0.0-py310"
    ANYSCALE_RAY_2_0_0_PY36 = "anyscale/ray:2.0.0-py36"
    ANYSCALE_RAY_2_0_0_PY36_CU101 = "anyscale/ray:2.0.0-py36-cu101"
    ANYSCALE_RAY_2_0_0_PY36_CU102 = "anyscale/ray:2.0.0-py36-cu102"
    ANYSCALE_RAY_2_0_0_PY36_CU110 = "anyscale/ray:2.0.0-py36-cu110"
    ANYSCALE_RAY_2_0_0_PY36_CU111 = "anyscale/ray:2.0.0-py36-cu111"
    ANYSCALE_RAY_2_0_0_PY36_CU112 = "anyscale/ray:2.0.0-py36-cu112"
    ANYSCALE_RAY_2_0_0_PY36_CU113 = "anyscale/ray:2.0.0-py36-cu113"
    ANYSCALE_RAY_2_0_0_PY37 = "anyscale/ray:2.0.0-py37"
    ANYSCALE_RAY_2_0_0_PY37_CU101 = "anyscale/ray:2.0.0-py37-cu101"
    ANYSCALE_RAY_2_0_0_PY37_CU102 = "anyscale/ray:2.0.0-py37-cu102"
    ANYSCALE_RAY_2_0_0_PY37_CU110 = "anyscale/ray:2.0.0-py37-cu110"
    ANYSCALE_RAY_2_0_0_PY37_CU111 = "anyscale/ray:2.0.0-py37-cu111"
    ANYSCALE_RAY_2_0_0_PY37_CU112 = "anyscale/ray:2.0.0-py37-cu112"
    ANYSCALE_RAY_2_0_0_PY37_CU113 = "anyscale/ray:2.0.0-py37-cu113"
    ANYSCALE_RAY_2_0_0_PY38 = "anyscale/ray:2.0.0-py38"
    ANYSCALE_RAY_2_0_0_PY38_CU101 = "anyscale/ray:2.0.0-py38-cu101"
    ANYSCALE_RAY_2_0_0_PY38_CU102 = "anyscale/ray:2.0.0-py38-cu102"
    ANYSCALE_RAY_2_0_0_PY38_CU110 = "anyscale/ray:2.0.0-py38-cu110"
    ANYSCALE_RAY_2_0_0_PY38_CU111 = "anyscale/ray:2.0.0-py38-cu111"
    ANYSCALE_RAY_2_0_0_PY38_CU112 = "anyscale/ray:2.0.0-py38-cu112"
    ANYSCALE_RAY_2_0_0_PY38_CU113 = "anyscale/ray:2.0.0-py38-cu113"
    ANYSCALE_RAY_2_0_0_PY39 = "anyscale/ray:2.0.0-py39"
    ANYSCALE_RAY_2_0_0_PY39_CU101 = "anyscale/ray:2.0.0-py39-cu101"
    ANYSCALE_RAY_2_0_0_PY39_CU102 = "anyscale/ray:2.0.0-py39-cu102"
    ANYSCALE_RAY_2_0_0_PY39_CU110 = "anyscale/ray:2.0.0-py39-cu110"
    ANYSCALE_RAY_2_0_0_PY39_CU111 = "anyscale/ray:2.0.0-py39-cu111"
    ANYSCALE_RAY_2_0_0_PY39_CU112 = "anyscale/ray:2.0.0-py39-cu112"
    ANYSCALE_RAY_2_0_0_PY39_CU113 = "anyscale/ray:2.0.0-py39-cu113"
    ANYSCALE_RAY_2_0_0RC0_PY310 = "anyscale/ray:2.0.0rc0-py310"
    ANYSCALE_RAY_2_0_0RC0_PY36 = "anyscale/ray:2.0.0rc0-py36"
    ANYSCALE_RAY_2_0_0RC0_PY36_CU101 = "anyscale/ray:2.0.0rc0-py36-cu101"
    ANYSCALE_RAY_2_0_0RC0_PY36_CU102 = "anyscale/ray:2.0.0rc0-py36-cu102"
    ANYSCALE_RAY_2_0_0RC0_PY36_CU110 = "anyscale/ray:2.0.0rc0-py36-cu110"
    ANYSCALE_RAY_2_0_0RC0_PY36_CU111 = "anyscale/ray:2.0.0rc0-py36-cu111"
    ANYSCALE_RAY_2_0_0RC0_PY36_CU112 = "anyscale/ray:2.0.0rc0-py36-cu112"
    ANYSCALE_RAY_2_0_0RC0_PY37 = "anyscale/ray:2.0.0rc0-py37"
    ANYSCALE_RAY_2_0_0RC0_PY37_CU101 = "anyscale/ray:2.0.0rc0-py37-cu101"
    ANYSCALE_RAY_2_0_0RC0_PY37_CU102 = "anyscale/ray:2.0.0rc0-py37-cu102"
    ANYSCALE_RAY_2_0_0RC0_PY37_CU110 = "anyscale/ray:2.0.0rc0-py37-cu110"
    ANYSCALE_RAY_2_0_0RC0_PY37_CU111 = "anyscale/ray:2.0.0rc0-py37-cu111"
    ANYSCALE_RAY_2_0_0RC0_PY37_CU112 = "anyscale/ray:2.0.0rc0-py37-cu112"
    ANYSCALE_RAY_2_0_0RC0_PY38 = "anyscale/ray:2.0.0rc0-py38"
    ANYSCALE_RAY_2_0_0RC0_PY38_CU101 = "anyscale/ray:2.0.0rc0-py38-cu101"
    ANYSCALE_RAY_2_0_0RC0_PY38_CU102 = "anyscale/ray:2.0.0rc0-py38-cu102"
    ANYSCALE_RAY_2_0_0RC0_PY38_CU110 = "anyscale/ray:2.0.0rc0-py38-cu110"
    ANYSCALE_RAY_2_0_0RC0_PY38_CU111 = "anyscale/ray:2.0.0rc0-py38-cu111"
    ANYSCALE_RAY_2_0_0RC0_PY38_CU112 = "anyscale/ray:2.0.0rc0-py38-cu112"
    ANYSCALE_RAY_2_0_0RC0_PY39 = "anyscale/ray:2.0.0rc0-py39"
    ANYSCALE_RAY_2_0_0RC0_PY39_CU101 = "anyscale/ray:2.0.0rc0-py39-cu101"
    ANYSCALE_RAY_2_0_0RC0_PY39_CU102 = "anyscale/ray:2.0.0rc0-py39-cu102"
    ANYSCALE_RAY_2_0_0RC0_PY39_CU110 = "anyscale/ray:2.0.0rc0-py39-cu110"
    ANYSCALE_RAY_2_0_0RC0_PY39_CU111 = "anyscale/ray:2.0.0rc0-py39-cu111"
    ANYSCALE_RAY_2_0_0RC0_PY39_CU112 = "anyscale/ray:2.0.0rc0-py39-cu112"
    ANYSCALE_RAY_2_0_0RC1_PY310 = "anyscale/ray:2.0.0rc1-py310"
    ANYSCALE_RAY_2_0_0RC1_PY36 = "anyscale/ray:2.0.0rc1-py36"
    ANYSCALE_RAY_2_0_0RC1_PY36_CU101 = "anyscale/ray:2.0.0rc1-py36-cu101"
    ANYSCALE_RAY_2_0_0RC1_PY36_CU102 = "anyscale/ray:2.0.0rc1-py36-cu102"
    ANYSCALE_RAY_2_0_0RC1_PY36_CU110 = "anyscale/ray:2.0.0rc1-py36-cu110"
    ANYSCALE_RAY_2_0_0RC1_PY36_CU111 = "anyscale/ray:2.0.0rc1-py36-cu111"
    ANYSCALE_RAY_2_0_0RC1_PY36_CU112 = "anyscale/ray:2.0.0rc1-py36-cu112"
    ANYSCALE_RAY_2_0_0RC1_PY37 = "anyscale/ray:2.0.0rc1-py37"
    ANYSCALE_RAY_2_0_0RC1_PY37_CU101 = "anyscale/ray:2.0.0rc1-py37-cu101"
    ANYSCALE_RAY_2_0_0RC1_PY37_CU102 = "anyscale/ray:2.0.0rc1-py37-cu102"
    ANYSCALE_RAY_2_0_0RC1_PY37_CU110 = "anyscale/ray:2.0.0rc1-py37-cu110"
    ANYSCALE_RAY_2_0_0RC1_PY37_CU111 = "anyscale/ray:2.0.0rc1-py37-cu111"
    ANYSCALE_RAY_2_0_0RC1_PY37_CU112 = "anyscale/ray:2.0.0rc1-py37-cu112"
    ANYSCALE_RAY_2_0_0RC1_PY38 = "anyscale/ray:2.0.0rc1-py38"
    ANYSCALE_RAY_2_0_0RC1_PY38_CU101 = "anyscale/ray:2.0.0rc1-py38-cu101"
    ANYSCALE_RAY_2_0_0RC1_PY38_CU102 = "anyscale/ray:2.0.0rc1-py38-cu102"
    ANYSCALE_RAY_2_0_0RC1_PY38_CU110 = "anyscale/ray:2.0.0rc1-py38-cu110"
    ANYSCALE_RAY_2_0_0RC1_PY38_CU111 = "anyscale/ray:2.0.0rc1-py38-cu111"
    ANYSCALE_RAY_2_0_0RC1_PY38_CU112 = "anyscale/ray:2.0.0rc1-py38-cu112"
    ANYSCALE_RAY_2_0_0RC1_PY39 = "anyscale/ray:2.0.0rc1-py39"
    ANYSCALE_RAY_2_0_0RC1_PY39_CU101 = "anyscale/ray:2.0.0rc1-py39-cu101"
    ANYSCALE_RAY_2_0_0RC1_PY39_CU102 = "anyscale/ray:2.0.0rc1-py39-cu102"
    ANYSCALE_RAY_2_0_0RC1_PY39_CU110 = "anyscale/ray:2.0.0rc1-py39-cu110"
    ANYSCALE_RAY_2_0_0RC1_PY39_CU111 = "anyscale/ray:2.0.0rc1-py39-cu111"
    ANYSCALE_RAY_2_0_0RC1_PY39_CU112 = "anyscale/ray:2.0.0rc1-py39-cu112"
    ANYSCALE_RAY_2_0_1_PY310 = "anyscale/ray:2.0.1-py310"
    ANYSCALE_RAY_2_0_1_PY36 = "anyscale/ray:2.0.1-py36"
    ANYSCALE_RAY_2_0_1_PY36_CU101 = "anyscale/ray:2.0.1-py36-cu101"
    ANYSCALE_RAY_2_0_1_PY36_CU102 = "anyscale/ray:2.0.1-py36-cu102"
    ANYSCALE_RAY_2_0_1_PY36_CU110 = "anyscale/ray:2.0.1-py36-cu110"
    ANYSCALE_RAY_2_0_1_PY36_CU111 = "anyscale/ray:2.0.1-py36-cu111"
    ANYSCALE_RAY_2_0_1_PY36_CU112 = "anyscale/ray:2.0.1-py36-cu112"
    ANYSCALE_RAY_2_0_1_PY36_CU113 = "anyscale/ray:2.0.1-py36-cu113"
    ANYSCALE_RAY_2_0_1_PY36_CU116 = "anyscale/ray:2.0.1-py36-cu116"
    ANYSCALE_RAY_2_0_1_PY37 = "anyscale/ray:2.0.1-py37"
    ANYSCALE_RAY_2_0_1_PY37_CU101 = "anyscale/ray:2.0.1-py37-cu101"
    ANYSCALE_RAY_2_0_1_PY37_CU102 = "anyscale/ray:2.0.1-py37-cu102"
    ANYSCALE_RAY_2_0_1_PY37_CU110 = "anyscale/ray:2.0.1-py37-cu110"
    ANYSCALE_RAY_2_0_1_PY37_CU111 = "anyscale/ray:2.0.1-py37-cu111"
    ANYSCALE_RAY_2_0_1_PY37_CU112 = "anyscale/ray:2.0.1-py37-cu112"
    ANYSCALE_RAY_2_0_1_PY37_CU113 = "anyscale/ray:2.0.1-py37-cu113"
    ANYSCALE_RAY_2_0_1_PY37_CU116 = "anyscale/ray:2.0.1-py37-cu116"
    ANYSCALE_RAY_2_0_1_PY38 = "anyscale/ray:2.0.1-py38"
    ANYSCALE_RAY_2_0_1_PY38_CU101 = "anyscale/ray:2.0.1-py38-cu101"
    ANYSCALE_RAY_2_0_1_PY38_CU102 = "anyscale/ray:2.0.1-py38-cu102"
    ANYSCALE_RAY_2_0_1_PY38_CU110 = "anyscale/ray:2.0.1-py38-cu110"
    ANYSCALE_RAY_2_0_1_PY38_CU111 = "anyscale/ray:2.0.1-py38-cu111"
    ANYSCALE_RAY_2_0_1_PY38_CU112 = "anyscale/ray:2.0.1-py38-cu112"
    ANYSCALE_RAY_2_0_1_PY38_CU113 = "anyscale/ray:2.0.1-py38-cu113"
    ANYSCALE_RAY_2_0_1_PY38_CU116 = "anyscale/ray:2.0.1-py38-cu116"
    ANYSCALE_RAY_2_0_1_PY39 = "anyscale/ray:2.0.1-py39"
    ANYSCALE_RAY_2_0_1_PY39_CU101 = "anyscale/ray:2.0.1-py39-cu101"
    ANYSCALE_RAY_2_0_1_PY39_CU102 = "anyscale/ray:2.0.1-py39-cu102"
    ANYSCALE_RAY_2_0_1_PY39_CU110 = "anyscale/ray:2.0.1-py39-cu110"
    ANYSCALE_RAY_2_0_1_PY39_CU111 = "anyscale/ray:2.0.1-py39-cu111"
    ANYSCALE_RAY_2_0_1_PY39_CU112 = "anyscale/ray:2.0.1-py39-cu112"
    ANYSCALE_RAY_2_0_1_PY39_CU113 = "anyscale/ray:2.0.1-py39-cu113"
    ANYSCALE_RAY_2_0_1_PY39_CU116 = "anyscale/ray:2.0.1-py39-cu116"
    ANYSCALE_RAY_2_1_0_PY310 = "anyscale/ray:2.1.0-py310"
    ANYSCALE_RAY_2_1_0_PY310_CU101 = "anyscale/ray:2.1.0-py310-cu101"
    ANYSCALE_RAY_2_1_0_PY310_CU102 = "anyscale/ray:2.1.0-py310-cu102"
    ANYSCALE_RAY_2_1_0_PY310_CU110 = "anyscale/ray:2.1.0-py310-cu110"
    ANYSCALE_RAY_2_1_0_PY310_CU111 = "anyscale/ray:2.1.0-py310-cu111"
    ANYSCALE_RAY_2_1_0_PY310_CU112 = "anyscale/ray:2.1.0-py310-cu112"
    ANYSCALE_RAY_2_1_0_PY310_CU113 = "anyscale/ray:2.1.0-py310-cu113"
    ANYSCALE_RAY_2_1_0_PY310_CU116 = "anyscale/ray:2.1.0-py310-cu116"
    ANYSCALE_RAY_2_1_0_PY36 = "anyscale/ray:2.1.0-py36"
    ANYSCALE_RAY_2_1_0_PY36_CU101 = "anyscale/ray:2.1.0-py36-cu101"
    ANYSCALE_RAY_2_1_0_PY36_CU102 = "anyscale/ray:2.1.0-py36-cu102"
    ANYSCALE_RAY_2_1_0_PY36_CU110 = "anyscale/ray:2.1.0-py36-cu110"
    ANYSCALE_RAY_2_1_0_PY36_CU111 = "anyscale/ray:2.1.0-py36-cu111"
    ANYSCALE_RAY_2_1_0_PY36_CU112 = "anyscale/ray:2.1.0-py36-cu112"
    ANYSCALE_RAY_2_1_0_PY36_CU113 = "anyscale/ray:2.1.0-py36-cu113"
    ANYSCALE_RAY_2_1_0_PY36_CU116 = "anyscale/ray:2.1.0-py36-cu116"
    ANYSCALE_RAY_2_1_0_PY37 = "anyscale/ray:2.1.0-py37"
    ANYSCALE_RAY_2_1_0_PY37_CU101 = "anyscale/ray:2.1.0-py37-cu101"
    ANYSCALE_RAY_2_1_0_PY37_CU102 = "anyscale/ray:2.1.0-py37-cu102"
    ANYSCALE_RAY_2_1_0_PY37_CU110 = "anyscale/ray:2.1.0-py37-cu110"
    ANYSCALE_RAY_2_1_0_PY37_CU111 = "anyscale/ray:2.1.0-py37-cu111"
    ANYSCALE_RAY_2_1_0_PY37_CU112 = "anyscale/ray:2.1.0-py37-cu112"
    ANYSCALE_RAY_2_1_0_PY37_CU113 = "anyscale/ray:2.1.0-py37-cu113"
    ANYSCALE_RAY_2_1_0_PY37_CU116 = "anyscale/ray:2.1.0-py37-cu116"
    ANYSCALE_RAY_2_1_0_PY38 = "anyscale/ray:2.1.0-py38"
    ANYSCALE_RAY_2_1_0_PY38_CU101 = "anyscale/ray:2.1.0-py38-cu101"
    ANYSCALE_RAY_2_1_0_PY38_CU102 = "anyscale/ray:2.1.0-py38-cu102"
    ANYSCALE_RAY_2_1_0_PY38_CU110 = "anyscale/ray:2.1.0-py38-cu110"
    ANYSCALE_RAY_2_1_0_PY38_CU111 = "anyscale/ray:2.1.0-py38-cu111"
    ANYSCALE_RAY_2_1_0_PY38_CU112 = "anyscale/ray:2.1.0-py38-cu112"
    ANYSCALE_RAY_2_1_0_PY38_CU113 = "anyscale/ray:2.1.0-py38-cu113"
    ANYSCALE_RAY_2_1_0_PY38_CU116 = "anyscale/ray:2.1.0-py38-cu116"
    ANYSCALE_RAY_2_1_0_PY39 = "anyscale/ray:2.1.0-py39"
    ANYSCALE_RAY_2_1_0_PY39_CU101 = "anyscale/ray:2.1.0-py39-cu101"
    ANYSCALE_RAY_2_1_0_PY39_CU102 = "anyscale/ray:2.1.0-py39-cu102"
    ANYSCALE_RAY_2_1_0_PY39_CU110 = "anyscale/ray:2.1.0-py39-cu110"
    ANYSCALE_RAY_2_1_0_PY39_CU111 = "anyscale/ray:2.1.0-py39-cu111"
    ANYSCALE_RAY_2_1_0_PY39_CU112 = "anyscale/ray:2.1.0-py39-cu112"
    ANYSCALE_RAY_2_1_0_PY39_CU113 = "anyscale/ray:2.1.0-py39-cu113"
    ANYSCALE_RAY_2_1_0_PY39_CU116 = "anyscale/ray:2.1.0-py39-cu116"
    ANYSCALE_RAY_2_10_0_PY310 = "anyscale/ray:2.10.0-py310"
    ANYSCALE_RAY_2_10_0_PY310_CU115 = "anyscale/ray:2.10.0-py310-cu115"
    ANYSCALE_RAY_2_10_0_PY310_CU116 = "anyscale/ray:2.10.0-py310-cu116"
    ANYSCALE_RAY_2_10_0_PY310_CU117 = "anyscale/ray:2.10.0-py310-cu117"
    ANYSCALE_RAY_2_10_0_PY310_CU118 = "anyscale/ray:2.10.0-py310-cu118"
    ANYSCALE_RAY_2_10_0_PY310_CU121 = "anyscale/ray:2.10.0-py310-cu121"
    ANYSCALE_RAY_2_10_0_PY311 = "anyscale/ray:2.10.0-py311"
    ANYSCALE_RAY_2_10_0_PY311_CU115 = "anyscale/ray:2.10.0-py311-cu115"
    ANYSCALE_RAY_2_10_0_PY311_CU116 = "anyscale/ray:2.10.0-py311-cu116"
    ANYSCALE_RAY_2_10_0_PY311_CU117 = "anyscale/ray:2.10.0-py311-cu117"
    ANYSCALE_RAY_2_10_0_PY311_CU118 = "anyscale/ray:2.10.0-py311-cu118"
    ANYSCALE_RAY_2_10_0_PY311_CU121 = "anyscale/ray:2.10.0-py311-cu121"
    ANYSCALE_RAY_2_10_0_PY38 = "anyscale/ray:2.10.0-py38"
    ANYSCALE_RAY_2_10_0_PY38_CU115 = "anyscale/ray:2.10.0-py38-cu115"
    ANYSCALE_RAY_2_10_0_PY38_CU116 = "anyscale/ray:2.10.0-py38-cu116"
    ANYSCALE_RAY_2_10_0_PY38_CU117 = "anyscale/ray:2.10.0-py38-cu117"
    ANYSCALE_RAY_2_10_0_PY38_CU118 = "anyscale/ray:2.10.0-py38-cu118"
    ANYSCALE_RAY_2_10_0_PY38_CU121 = "anyscale/ray:2.10.0-py38-cu121"
    ANYSCALE_RAY_2_10_0_PY39 = "anyscale/ray:2.10.0-py39"
    ANYSCALE_RAY_2_10_0_PY39_CU115 = "anyscale/ray:2.10.0-py39-cu115"
    ANYSCALE_RAY_2_10_0_PY39_CU116 = "anyscale/ray:2.10.0-py39-cu116"
    ANYSCALE_RAY_2_10_0_PY39_CU117 = "anyscale/ray:2.10.0-py39-cu117"
    ANYSCALE_RAY_2_10_0_PY39_CU118 = "anyscale/ray:2.10.0-py39-cu118"
    ANYSCALE_RAY_2_10_0_PY39_CU121 = "anyscale/ray:2.10.0-py39-cu121"
    ANYSCALE_RAY_2_11_0_PY310 = "anyscale/ray:2.11.0-py310"
    ANYSCALE_RAY_2_11_0_PY310_CU115 = "anyscale/ray:2.11.0-py310-cu115"
    ANYSCALE_RAY_2_11_0_PY310_CU116 = "anyscale/ray:2.11.0-py310-cu116"
    ANYSCALE_RAY_2_11_0_PY310_CU117 = "anyscale/ray:2.11.0-py310-cu117"
    ANYSCALE_RAY_2_11_0_PY310_CU118 = "anyscale/ray:2.11.0-py310-cu118"
    ANYSCALE_RAY_2_11_0_PY310_CU121 = "anyscale/ray:2.11.0-py310-cu121"
    ANYSCALE_RAY_2_11_0_PY311 = "anyscale/ray:2.11.0-py311"
    ANYSCALE_RAY_2_11_0_PY311_CU115 = "anyscale/ray:2.11.0-py311-cu115"
    ANYSCALE_RAY_2_11_0_PY311_CU116 = "anyscale/ray:2.11.0-py311-cu116"
    ANYSCALE_RAY_2_11_0_PY311_CU117 = "anyscale/ray:2.11.0-py311-cu117"
    ANYSCALE_RAY_2_11_0_PY311_CU118 = "anyscale/ray:2.11.0-py311-cu118"
    ANYSCALE_RAY_2_11_0_PY311_CU121 = "anyscale/ray:2.11.0-py311-cu121"
    ANYSCALE_RAY_2_11_0_PY39 = "anyscale/ray:2.11.0-py39"
    ANYSCALE_RAY_2_11_0_PY39_CU115 = "anyscale/ray:2.11.0-py39-cu115"
    ANYSCALE_RAY_2_11_0_PY39_CU116 = "anyscale/ray:2.11.0-py39-cu116"
    ANYSCALE_RAY_2_11_0_PY39_CU117 = "anyscale/ray:2.11.0-py39-cu117"
    ANYSCALE_RAY_2_11_0_PY39_CU118 = "anyscale/ray:2.11.0-py39-cu118"
    ANYSCALE_RAY_2_11_0_PY39_CU121 = "anyscale/ray:2.11.0-py39-cu121"
    ANYSCALE_RAY_2_12_0_PY310 = "anyscale/ray:2.12.0-py310"
    ANYSCALE_RAY_2_12_0_PY310_CU115 = "anyscale/ray:2.12.0-py310-cu115"
    ANYSCALE_RAY_2_12_0_PY310_CU116 = "anyscale/ray:2.12.0-py310-cu116"
    ANYSCALE_RAY_2_12_0_PY310_CU117 = "anyscale/ray:2.12.0-py310-cu117"
    ANYSCALE_RAY_2_12_0_PY310_CU118 = "anyscale/ray:2.12.0-py310-cu118"
    ANYSCALE_RAY_2_12_0_PY310_CU121 = "anyscale/ray:2.12.0-py310-cu121"
    ANYSCALE_RAY_2_12_0_PY311 = "anyscale/ray:2.12.0-py311"
    ANYSCALE_RAY_2_12_0_PY311_CU115 = "anyscale/ray:2.12.0-py311-cu115"
    ANYSCALE_RAY_2_12_0_PY311_CU116 = "anyscale/ray:2.12.0-py311-cu116"
    ANYSCALE_RAY_2_12_0_PY311_CU117 = "anyscale/ray:2.12.0-py311-cu117"
    ANYSCALE_RAY_2_12_0_PY311_CU118 = "anyscale/ray:2.12.0-py311-cu118"
    ANYSCALE_RAY_2_12_0_PY311_CU121 = "anyscale/ray:2.12.0-py311-cu121"
    ANYSCALE_RAY_2_12_0_PY39 = "anyscale/ray:2.12.0-py39"
    ANYSCALE_RAY_2_12_0_PY39_CU115 = "anyscale/ray:2.12.0-py39-cu115"
    ANYSCALE_RAY_2_12_0_PY39_CU116 = "anyscale/ray:2.12.0-py39-cu116"
    ANYSCALE_RAY_2_12_0_PY39_CU117 = "anyscale/ray:2.12.0-py39-cu117"
    ANYSCALE_RAY_2_12_0_PY39_CU118 = "anyscale/ray:2.12.0-py39-cu118"
    ANYSCALE_RAY_2_12_0_PY39_CU121 = "anyscale/ray:2.12.0-py39-cu121"
    ANYSCALE_RAY_2_12_0_SLIM_PY310 = "anyscale/ray:2.12.0-slim-py310"
    ANYSCALE_RAY_2_12_0_SLIM_PY310_CU118 = "anyscale/ray:2.12.0-slim-py310-cu118"
    ANYSCALE_RAY_2_12_0_SLIM_PY310_CU121 = "anyscale/ray:2.12.0-slim-py310-cu121"
    ANYSCALE_RAY_2_12_0_SLIM_PY311 = "anyscale/ray:2.12.0-slim-py311"
    ANYSCALE_RAY_2_12_0_SLIM_PY311_CU118 = "anyscale/ray:2.12.0-slim-py311-cu118"
    ANYSCALE_RAY_2_12_0_SLIM_PY311_CU121 = "anyscale/ray:2.12.0-slim-py311-cu121"
    ANYSCALE_RAY_2_12_0_SLIM_PY39 = "anyscale/ray:2.12.0-slim-py39"
    ANYSCALE_RAY_2_12_0_SLIM_PY39_CU118 = "anyscale/ray:2.12.0-slim-py39-cu118"
    ANYSCALE_RAY_2_12_0_SLIM_PY39_CU121 = "anyscale/ray:2.12.0-slim-py39-cu121"
    ANYSCALE_RAY_2_2_0_PY310 = "anyscale/ray:2.2.0-py310"
    ANYSCALE_RAY_2_2_0_PY310_CU101 = "anyscale/ray:2.2.0-py310-cu101"
    ANYSCALE_RAY_2_2_0_PY310_CU102 = "anyscale/ray:2.2.0-py310-cu102"
    ANYSCALE_RAY_2_2_0_PY310_CU110 = "anyscale/ray:2.2.0-py310-cu110"
    ANYSCALE_RAY_2_2_0_PY310_CU111 = "anyscale/ray:2.2.0-py310-cu111"
    ANYSCALE_RAY_2_2_0_PY310_CU112 = "anyscale/ray:2.2.0-py310-cu112"
    ANYSCALE_RAY_2_2_0_PY310_CU113 = "anyscale/ray:2.2.0-py310-cu113"
    ANYSCALE_RAY_2_2_0_PY310_CU116 = "anyscale/ray:2.2.0-py310-cu116"
    ANYSCALE_RAY_2_2_0_PY37 = "anyscale/ray:2.2.0-py37"
    ANYSCALE_RAY_2_2_0_PY37_CU101 = "anyscale/ray:2.2.0-py37-cu101"
    ANYSCALE_RAY_2_2_0_PY37_CU102 = "anyscale/ray:2.2.0-py37-cu102"
    ANYSCALE_RAY_2_2_0_PY37_CU110 = "anyscale/ray:2.2.0-py37-cu110"
    ANYSCALE_RAY_2_2_0_PY37_CU111 = "anyscale/ray:2.2.0-py37-cu111"
    ANYSCALE_RAY_2_2_0_PY37_CU112 = "anyscale/ray:2.2.0-py37-cu112"
    ANYSCALE_RAY_2_2_0_PY37_CU113 = "anyscale/ray:2.2.0-py37-cu113"
    ANYSCALE_RAY_2_2_0_PY37_CU116 = "anyscale/ray:2.2.0-py37-cu116"
    ANYSCALE_RAY_2_2_0_PY38 = "anyscale/ray:2.2.0-py38"
    ANYSCALE_RAY_2_2_0_PY38_CU101 = "anyscale/ray:2.2.0-py38-cu101"
    ANYSCALE_RAY_2_2_0_PY38_CU102 = "anyscale/ray:2.2.0-py38-cu102"
    ANYSCALE_RAY_2_2_0_PY38_CU110 = "anyscale/ray:2.2.0-py38-cu110"
    ANYSCALE_RAY_2_2_0_PY38_CU111 = "anyscale/ray:2.2.0-py38-cu111"
    ANYSCALE_RAY_2_2_0_PY38_CU112 = "anyscale/ray:2.2.0-py38-cu112"
    ANYSCALE_RAY_2_2_0_PY38_CU113 = "anyscale/ray:2.2.0-py38-cu113"
    ANYSCALE_RAY_2_2_0_PY38_CU116 = "anyscale/ray:2.2.0-py38-cu116"
    ANYSCALE_RAY_2_2_0_PY39 = "anyscale/ray:2.2.0-py39"
    ANYSCALE_RAY_2_2_0_PY39_CU101 = "anyscale/ray:2.2.0-py39-cu101"
    ANYSCALE_RAY_2_2_0_PY39_CU102 = "anyscale/ray:2.2.0-py39-cu102"
    ANYSCALE_RAY_2_2_0_PY39_CU110 = "anyscale/ray:2.2.0-py39-cu110"
    ANYSCALE_RAY_2_2_0_PY39_CU111 = "anyscale/ray:2.2.0-py39-cu111"
    ANYSCALE_RAY_2_2_0_PY39_CU112 = "anyscale/ray:2.2.0-py39-cu112"
    ANYSCALE_RAY_2_2_0_PY39_CU113 = "anyscale/ray:2.2.0-py39-cu113"
    ANYSCALE_RAY_2_2_0_PY39_CU116 = "anyscale/ray:2.2.0-py39-cu116"
    ANYSCALE_RAY_2_20_0_PY310 = "anyscale/ray:2.20.0-py310"
    ANYSCALE_RAY_2_20_0_PY310_CU115 = "anyscale/ray:2.20.0-py310-cu115"
    ANYSCALE_RAY_2_20_0_PY310_CU116 = "anyscale/ray:2.20.0-py310-cu116"
    ANYSCALE_RAY_2_20_0_PY310_CU117 = "anyscale/ray:2.20.0-py310-cu117"
    ANYSCALE_RAY_2_20_0_PY310_CU118 = "anyscale/ray:2.20.0-py310-cu118"
    ANYSCALE_RAY_2_20_0_PY310_CU121 = "anyscale/ray:2.20.0-py310-cu121"
    ANYSCALE_RAY_2_20_0_PY311 = "anyscale/ray:2.20.0-py311"
    ANYSCALE_RAY_2_20_0_PY311_CU115 = "anyscale/ray:2.20.0-py311-cu115"
    ANYSCALE_RAY_2_20_0_PY311_CU116 = "anyscale/ray:2.20.0-py311-cu116"
    ANYSCALE_RAY_2_20_0_PY311_CU117 = "anyscale/ray:2.20.0-py311-cu117"
    ANYSCALE_RAY_2_20_0_PY311_CU118 = "anyscale/ray:2.20.0-py311-cu118"
    ANYSCALE_RAY_2_20_0_PY311_CU121 = "anyscale/ray:2.20.0-py311-cu121"
    ANYSCALE_RAY_2_20_0_PY39 = "anyscale/ray:2.20.0-py39"
    ANYSCALE_RAY_2_20_0_PY39_CU115 = "anyscale/ray:2.20.0-py39-cu115"
    ANYSCALE_RAY_2_20_0_PY39_CU116 = "anyscale/ray:2.20.0-py39-cu116"
    ANYSCALE_RAY_2_20_0_PY39_CU117 = "anyscale/ray:2.20.0-py39-cu117"
    ANYSCALE_RAY_2_20_0_PY39_CU118 = "anyscale/ray:2.20.0-py39-cu118"
    ANYSCALE_RAY_2_20_0_PY39_CU121 = "anyscale/ray:2.20.0-py39-cu121"
    ANYSCALE_RAY_2_20_0_SLIM_PY310 = "anyscale/ray:2.20.0-slim-py310"
    ANYSCALE_RAY_2_20_0_SLIM_PY310_CU118 = "anyscale/ray:2.20.0-slim-py310-cu118"
    ANYSCALE_RAY_2_20_0_SLIM_PY310_CU121 = "anyscale/ray:2.20.0-slim-py310-cu121"
    ANYSCALE_RAY_2_20_0_SLIM_PY311 = "anyscale/ray:2.20.0-slim-py311"
    ANYSCALE_RAY_2_20_0_SLIM_PY311_CU118 = "anyscale/ray:2.20.0-slim-py311-cu118"
    ANYSCALE_RAY_2_20_0_SLIM_PY311_CU121 = "anyscale/ray:2.20.0-slim-py311-cu121"
    ANYSCALE_RAY_2_20_0_SLIM_PY39 = "anyscale/ray:2.20.0-slim-py39"
    ANYSCALE_RAY_2_20_0_SLIM_PY39_CU118 = "anyscale/ray:2.20.0-slim-py39-cu118"
    ANYSCALE_RAY_2_20_0_SLIM_PY39_CU121 = "anyscale/ray:2.20.0-slim-py39-cu121"
    ANYSCALE_RAY_2_21_0_PY310 = "anyscale/ray:2.21.0-py310"
    ANYSCALE_RAY_2_21_0_PY310_CU115 = "anyscale/ray:2.21.0-py310-cu115"
    ANYSCALE_RAY_2_21_0_PY310_CU116 = "anyscale/ray:2.21.0-py310-cu116"
    ANYSCALE_RAY_2_21_0_PY310_CU117 = "anyscale/ray:2.21.0-py310-cu117"
    ANYSCALE_RAY_2_21_0_PY310_CU118 = "anyscale/ray:2.21.0-py310-cu118"
    ANYSCALE_RAY_2_21_0_PY310_CU121 = "anyscale/ray:2.21.0-py310-cu121"
    ANYSCALE_RAY_2_21_0_PY311 = "anyscale/ray:2.21.0-py311"
    ANYSCALE_RAY_2_21_0_PY311_CU115 = "anyscale/ray:2.21.0-py311-cu115"
    ANYSCALE_RAY_2_21_0_PY311_CU116 = "anyscale/ray:2.21.0-py311-cu116"
    ANYSCALE_RAY_2_21_0_PY311_CU117 = "anyscale/ray:2.21.0-py311-cu117"
    ANYSCALE_RAY_2_21_0_PY311_CU118 = "anyscale/ray:2.21.0-py311-cu118"
    ANYSCALE_RAY_2_21_0_PY311_CU121 = "anyscale/ray:2.21.0-py311-cu121"
    ANYSCALE_RAY_2_21_0_PY39 = "anyscale/ray:2.21.0-py39"
    ANYSCALE_RAY_2_21_0_PY39_CU115 = "anyscale/ray:2.21.0-py39-cu115"
    ANYSCALE_RAY_2_21_0_PY39_CU116 = "anyscale/ray:2.21.0-py39-cu116"
    ANYSCALE_RAY_2_21_0_PY39_CU117 = "anyscale/ray:2.21.0-py39-cu117"
    ANYSCALE_RAY_2_21_0_PY39_CU118 = "anyscale/ray:2.21.0-py39-cu118"
    ANYSCALE_RAY_2_21_0_PY39_CU121 = "anyscale/ray:2.21.0-py39-cu121"
    ANYSCALE_RAY_2_21_0_SLIM_PY310 = "anyscale/ray:2.21.0-slim-py310"
    ANYSCALE_RAY_2_21_0_SLIM_PY310_CU118 = "anyscale/ray:2.21.0-slim-py310-cu118"
    ANYSCALE_RAY_2_21_0_SLIM_PY310_CU121 = "anyscale/ray:2.21.0-slim-py310-cu121"
    ANYSCALE_RAY_2_21_0_SLIM_PY311 = "anyscale/ray:2.21.0-slim-py311"
    ANYSCALE_RAY_2_21_0_SLIM_PY311_CU118 = "anyscale/ray:2.21.0-slim-py311-cu118"
    ANYSCALE_RAY_2_21_0_SLIM_PY311_CU121 = "anyscale/ray:2.21.0-slim-py311-cu121"
    ANYSCALE_RAY_2_21_0_SLIM_PY39 = "anyscale/ray:2.21.0-slim-py39"
    ANYSCALE_RAY_2_21_0_SLIM_PY39_CU118 = "anyscale/ray:2.21.0-slim-py39-cu118"
    ANYSCALE_RAY_2_21_0_SLIM_PY39_CU121 = "anyscale/ray:2.21.0-slim-py39-cu121"
    ANYSCALE_RAY_2_22_0_PY310 = "anyscale/ray:2.22.0-py310"
    ANYSCALE_RAY_2_22_0_PY310_CU115 = "anyscale/ray:2.22.0-py310-cu115"
    ANYSCALE_RAY_2_22_0_PY310_CU116 = "anyscale/ray:2.22.0-py310-cu116"
    ANYSCALE_RAY_2_22_0_PY310_CU117 = "anyscale/ray:2.22.0-py310-cu117"
    ANYSCALE_RAY_2_22_0_PY310_CU118 = "anyscale/ray:2.22.0-py310-cu118"
    ANYSCALE_RAY_2_22_0_PY310_CU121 = "anyscale/ray:2.22.0-py310-cu121"
    ANYSCALE_RAY_2_22_0_PY311 = "anyscale/ray:2.22.0-py311"
    ANYSCALE_RAY_2_22_0_PY311_CU115 = "anyscale/ray:2.22.0-py311-cu115"
    ANYSCALE_RAY_2_22_0_PY311_CU116 = "anyscale/ray:2.22.0-py311-cu116"
    ANYSCALE_RAY_2_22_0_PY311_CU117 = "anyscale/ray:2.22.0-py311-cu117"
    ANYSCALE_RAY_2_22_0_PY311_CU118 = "anyscale/ray:2.22.0-py311-cu118"
    ANYSCALE_RAY_2_22_0_PY311_CU121 = "anyscale/ray:2.22.0-py311-cu121"
    ANYSCALE_RAY_2_22_0_PY39 = "anyscale/ray:2.22.0-py39"
    ANYSCALE_RAY_2_22_0_PY39_CU115 = "anyscale/ray:2.22.0-py39-cu115"
    ANYSCALE_RAY_2_22_0_PY39_CU116 = "anyscale/ray:2.22.0-py39-cu116"
    ANYSCALE_RAY_2_22_0_PY39_CU117 = "anyscale/ray:2.22.0-py39-cu117"
    ANYSCALE_RAY_2_22_0_PY39_CU118 = "anyscale/ray:2.22.0-py39-cu118"
    ANYSCALE_RAY_2_22_0_PY39_CU121 = "anyscale/ray:2.22.0-py39-cu121"
    ANYSCALE_RAY_2_22_0_SLIM_PY310 = "anyscale/ray:2.22.0-slim-py310"
    ANYSCALE_RAY_2_22_0_SLIM_PY310_CU118 = "anyscale/ray:2.22.0-slim-py310-cu118"
    ANYSCALE_RAY_2_22_0_SLIM_PY310_CU121 = "anyscale/ray:2.22.0-slim-py310-cu121"
    ANYSCALE_RAY_2_22_0_SLIM_PY311 = "anyscale/ray:2.22.0-slim-py311"
    ANYSCALE_RAY_2_22_0_SLIM_PY311_CU118 = "anyscale/ray:2.22.0-slim-py311-cu118"
    ANYSCALE_RAY_2_22_0_SLIM_PY311_CU121 = "anyscale/ray:2.22.0-slim-py311-cu121"
    ANYSCALE_RAY_2_22_0_SLIM_PY39 = "anyscale/ray:2.22.0-slim-py39"
    ANYSCALE_RAY_2_22_0_SLIM_PY39_CU118 = "anyscale/ray:2.22.0-slim-py39-cu118"
    ANYSCALE_RAY_2_22_0_SLIM_PY39_CU121 = "anyscale/ray:2.22.0-slim-py39-cu121"
    ANYSCALE_RAY_2_23_0_PY310 = "anyscale/ray:2.23.0-py310"
    ANYSCALE_RAY_2_23_0_PY310_CU115 = "anyscale/ray:2.23.0-py310-cu115"
    ANYSCALE_RAY_2_23_0_PY310_CU116 = "anyscale/ray:2.23.0-py310-cu116"
    ANYSCALE_RAY_2_23_0_PY310_CU117 = "anyscale/ray:2.23.0-py310-cu117"
    ANYSCALE_RAY_2_23_0_PY310_CU118 = "anyscale/ray:2.23.0-py310-cu118"
    ANYSCALE_RAY_2_23_0_PY310_CU121 = "anyscale/ray:2.23.0-py310-cu121"
    ANYSCALE_RAY_2_23_0_PY311 = "anyscale/ray:2.23.0-py311"
    ANYSCALE_RAY_2_23_0_PY311_CU115 = "anyscale/ray:2.23.0-py311-cu115"
    ANYSCALE_RAY_2_23_0_PY311_CU116 = "anyscale/ray:2.23.0-py311-cu116"
    ANYSCALE_RAY_2_23_0_PY311_CU117 = "anyscale/ray:2.23.0-py311-cu117"
    ANYSCALE_RAY_2_23_0_PY311_CU118 = "anyscale/ray:2.23.0-py311-cu118"
    ANYSCALE_RAY_2_23_0_PY311_CU121 = "anyscale/ray:2.23.0-py311-cu121"
    ANYSCALE_RAY_2_23_0_PY39 = "anyscale/ray:2.23.0-py39"
    ANYSCALE_RAY_2_23_0_PY39_CU115 = "anyscale/ray:2.23.0-py39-cu115"
    ANYSCALE_RAY_2_23_0_PY39_CU116 = "anyscale/ray:2.23.0-py39-cu116"
    ANYSCALE_RAY_2_23_0_PY39_CU117 = "anyscale/ray:2.23.0-py39-cu117"
    ANYSCALE_RAY_2_23_0_PY39_CU118 = "anyscale/ray:2.23.0-py39-cu118"
    ANYSCALE_RAY_2_23_0_PY39_CU121 = "anyscale/ray:2.23.0-py39-cu121"
    ANYSCALE_RAY_2_23_0_SLIM_PY310 = "anyscale/ray:2.23.0-slim-py310"
    ANYSCALE_RAY_2_23_0_SLIM_PY310_CU118 = "anyscale/ray:2.23.0-slim-py310-cu118"
    ANYSCALE_RAY_2_23_0_SLIM_PY310_CU121 = "anyscale/ray:2.23.0-slim-py310-cu121"
    ANYSCALE_RAY_2_23_0_SLIM_PY311 = "anyscale/ray:2.23.0-slim-py311"
    ANYSCALE_RAY_2_23_0_SLIM_PY311_CU118 = "anyscale/ray:2.23.0-slim-py311-cu118"
    ANYSCALE_RAY_2_23_0_SLIM_PY311_CU121 = "anyscale/ray:2.23.0-slim-py311-cu121"
    ANYSCALE_RAY_2_23_0_SLIM_PY39 = "anyscale/ray:2.23.0-slim-py39"
    ANYSCALE_RAY_2_23_0_SLIM_PY39_CU118 = "anyscale/ray:2.23.0-slim-py39-cu118"
    ANYSCALE_RAY_2_23_0_SLIM_PY39_CU121 = "anyscale/ray:2.23.0-slim-py39-cu121"
    ANYSCALE_RAY_2_24_0_PY310 = "anyscale/ray:2.24.0-py310"
    ANYSCALE_RAY_2_24_0_PY310_CU115 = "anyscale/ray:2.24.0-py310-cu115"
    ANYSCALE_RAY_2_24_0_PY310_CU116 = "anyscale/ray:2.24.0-py310-cu116"
    ANYSCALE_RAY_2_24_0_PY310_CU117 = "anyscale/ray:2.24.0-py310-cu117"
    ANYSCALE_RAY_2_24_0_PY310_CU118 = "anyscale/ray:2.24.0-py310-cu118"
    ANYSCALE_RAY_2_24_0_PY310_CU121 = "anyscale/ray:2.24.0-py310-cu121"
    ANYSCALE_RAY_2_24_0_PY311 = "anyscale/ray:2.24.0-py311"
    ANYSCALE_RAY_2_24_0_PY311_CU115 = "anyscale/ray:2.24.0-py311-cu115"
    ANYSCALE_RAY_2_24_0_PY311_CU116 = "anyscale/ray:2.24.0-py311-cu116"
    ANYSCALE_RAY_2_24_0_PY311_CU117 = "anyscale/ray:2.24.0-py311-cu117"
    ANYSCALE_RAY_2_24_0_PY311_CU118 = "anyscale/ray:2.24.0-py311-cu118"
    ANYSCALE_RAY_2_24_0_PY311_CU121 = "anyscale/ray:2.24.0-py311-cu121"
    ANYSCALE_RAY_2_24_0_PY39 = "anyscale/ray:2.24.0-py39"
    ANYSCALE_RAY_2_24_0_PY39_CU115 = "anyscale/ray:2.24.0-py39-cu115"
    ANYSCALE_RAY_2_24_0_PY39_CU116 = "anyscale/ray:2.24.0-py39-cu116"
    ANYSCALE_RAY_2_24_0_PY39_CU117 = "anyscale/ray:2.24.0-py39-cu117"
    ANYSCALE_RAY_2_24_0_PY39_CU118 = "anyscale/ray:2.24.0-py39-cu118"
    ANYSCALE_RAY_2_24_0_PY39_CU121 = "anyscale/ray:2.24.0-py39-cu121"
    ANYSCALE_RAY_2_24_0_SLIM_PY310 = "anyscale/ray:2.24.0-slim-py310"
    ANYSCALE_RAY_2_24_0_SLIM_PY310_CU118 = "anyscale/ray:2.24.0-slim-py310-cu118"
    ANYSCALE_RAY_2_24_0_SLIM_PY310_CU121 = "anyscale/ray:2.24.0-slim-py310-cu121"
    ANYSCALE_RAY_2_24_0_SLIM_PY311 = "anyscale/ray:2.24.0-slim-py311"
    ANYSCALE_RAY_2_24_0_SLIM_PY311_CU118 = "anyscale/ray:2.24.0-slim-py311-cu118"
    ANYSCALE_RAY_2_24_0_SLIM_PY311_CU121 = "anyscale/ray:2.24.0-slim-py311-cu121"
    ANYSCALE_RAY_2_24_0_SLIM_PY39 = "anyscale/ray:2.24.0-slim-py39"
    ANYSCALE_RAY_2_24_0_SLIM_PY39_CU118 = "anyscale/ray:2.24.0-slim-py39-cu118"
    ANYSCALE_RAY_2_24_0_SLIM_PY39_CU121 = "anyscale/ray:2.24.0-slim-py39-cu121"
    ANYSCALE_RAY_2_3_0_PY310 = "anyscale/ray:2.3.0-py310"
    ANYSCALE_RAY_2_3_0_PY310_CU101 = "anyscale/ray:2.3.0-py310-cu101"
    ANYSCALE_RAY_2_3_0_PY310_CU102 = "anyscale/ray:2.3.0-py310-cu102"
    ANYSCALE_RAY_2_3_0_PY310_CU110 = "anyscale/ray:2.3.0-py310-cu110"
    ANYSCALE_RAY_2_3_0_PY310_CU111 = "anyscale/ray:2.3.0-py310-cu111"
    ANYSCALE_RAY_2_3_0_PY310_CU112 = "anyscale/ray:2.3.0-py310-cu112"
    ANYSCALE_RAY_2_3_0_PY310_CU113 = "anyscale/ray:2.3.0-py310-cu113"
    ANYSCALE_RAY_2_3_0_PY310_CU116 = "anyscale/ray:2.3.0-py310-cu116"
    ANYSCALE_RAY_2_3_0_PY310_CU118 = "anyscale/ray:2.3.0-py310-cu118"
    ANYSCALE_RAY_2_3_0_PY37 = "anyscale/ray:2.3.0-py37"
    ANYSCALE_RAY_2_3_0_PY37_CU101 = "anyscale/ray:2.3.0-py37-cu101"
    ANYSCALE_RAY_2_3_0_PY37_CU102 = "anyscale/ray:2.3.0-py37-cu102"
    ANYSCALE_RAY_2_3_0_PY37_CU110 = "anyscale/ray:2.3.0-py37-cu110"
    ANYSCALE_RAY_2_3_0_PY37_CU111 = "anyscale/ray:2.3.0-py37-cu111"
    ANYSCALE_RAY_2_3_0_PY37_CU112 = "anyscale/ray:2.3.0-py37-cu112"
    ANYSCALE_RAY_2_3_0_PY37_CU113 = "anyscale/ray:2.3.0-py37-cu113"
    ANYSCALE_RAY_2_3_0_PY37_CU116 = "anyscale/ray:2.3.0-py37-cu116"
    ANYSCALE_RAY_2_3_0_PY37_CU118 = "anyscale/ray:2.3.0-py37-cu118"
    ANYSCALE_RAY_2_3_0_PY38 = "anyscale/ray:2.3.0-py38"
    ANYSCALE_RAY_2_3_0_PY38_CU101 = "anyscale/ray:2.3.0-py38-cu101"
    ANYSCALE_RAY_2_3_0_PY38_CU102 = "anyscale/ray:2.3.0-py38-cu102"
    ANYSCALE_RAY_2_3_0_PY38_CU110 = "anyscale/ray:2.3.0-py38-cu110"
    ANYSCALE_RAY_2_3_0_PY38_CU111 = "anyscale/ray:2.3.0-py38-cu111"
    ANYSCALE_RAY_2_3_0_PY38_CU112 = "anyscale/ray:2.3.0-py38-cu112"
    ANYSCALE_RAY_2_3_0_PY38_CU113 = "anyscale/ray:2.3.0-py38-cu113"
    ANYSCALE_RAY_2_3_0_PY38_CU116 = "anyscale/ray:2.3.0-py38-cu116"
    ANYSCALE_RAY_2_3_0_PY38_CU118 = "anyscale/ray:2.3.0-py38-cu118"
    ANYSCALE_RAY_2_3_0_PY39 = "anyscale/ray:2.3.0-py39"
    ANYSCALE_RAY_2_3_0_PY39_CU101 = "anyscale/ray:2.3.0-py39-cu101"
    ANYSCALE_RAY_2_3_0_PY39_CU102 = "anyscale/ray:2.3.0-py39-cu102"
    ANYSCALE_RAY_2_3_0_PY39_CU110 = "anyscale/ray:2.3.0-py39-cu110"
    ANYSCALE_RAY_2_3_0_PY39_CU111 = "anyscale/ray:2.3.0-py39-cu111"
    ANYSCALE_RAY_2_3_0_PY39_CU112 = "anyscale/ray:2.3.0-py39-cu112"
    ANYSCALE_RAY_2_3_0_PY39_CU113 = "anyscale/ray:2.3.0-py39-cu113"
    ANYSCALE_RAY_2_3_0_PY39_CU116 = "anyscale/ray:2.3.0-py39-cu116"
    ANYSCALE_RAY_2_3_0_PY39_CU118 = "anyscale/ray:2.3.0-py39-cu118"
    ANYSCALE_RAY_2_3_1_PY310 = "anyscale/ray:2.3.1-py310"
    ANYSCALE_RAY_2_3_1_PY310_CU101 = "anyscale/ray:2.3.1-py310-cu101"
    ANYSCALE_RAY_2_3_1_PY310_CU102 = "anyscale/ray:2.3.1-py310-cu102"
    ANYSCALE_RAY_2_3_1_PY310_CU110 = "anyscale/ray:2.3.1-py310-cu110"
    ANYSCALE_RAY_2_3_1_PY310_CU111 = "anyscale/ray:2.3.1-py310-cu111"
    ANYSCALE_RAY_2_3_1_PY310_CU112 = "anyscale/ray:2.3.1-py310-cu112"
    ANYSCALE_RAY_2_3_1_PY310_CU113 = "anyscale/ray:2.3.1-py310-cu113"
    ANYSCALE_RAY_2_3_1_PY310_CU116 = "anyscale/ray:2.3.1-py310-cu116"
    ANYSCALE_RAY_2_3_1_PY310_CU118 = "anyscale/ray:2.3.1-py310-cu118"
    ANYSCALE_RAY_2_3_1_PY37 = "anyscale/ray:2.3.1-py37"
    ANYSCALE_RAY_2_3_1_PY37_CU101 = "anyscale/ray:2.3.1-py37-cu101"
    ANYSCALE_RAY_2_3_1_PY37_CU102 = "anyscale/ray:2.3.1-py37-cu102"
    ANYSCALE_RAY_2_3_1_PY37_CU110 = "anyscale/ray:2.3.1-py37-cu110"
    ANYSCALE_RAY_2_3_1_PY37_CU111 = "anyscale/ray:2.3.1-py37-cu111"
    ANYSCALE_RAY_2_3_1_PY37_CU112 = "anyscale/ray:2.3.1-py37-cu112"
    ANYSCALE_RAY_2_3_1_PY37_CU113 = "anyscale/ray:2.3.1-py37-cu113"
    ANYSCALE_RAY_2_3_1_PY37_CU116 = "anyscale/ray:2.3.1-py37-cu116"
    ANYSCALE_RAY_2_3_1_PY37_CU118 = "anyscale/ray:2.3.1-py37-cu118"
    ANYSCALE_RAY_2_3_1_PY38 = "anyscale/ray:2.3.1-py38"
    ANYSCALE_RAY_2_3_1_PY38_CU101 = "anyscale/ray:2.3.1-py38-cu101"
    ANYSCALE_RAY_2_3_1_PY38_CU102 = "anyscale/ray:2.3.1-py38-cu102"
    ANYSCALE_RAY_2_3_1_PY38_CU110 = "anyscale/ray:2.3.1-py38-cu110"
    ANYSCALE_RAY_2_3_1_PY38_CU111 = "anyscale/ray:2.3.1-py38-cu111"
    ANYSCALE_RAY_2_3_1_PY38_CU112 = "anyscale/ray:2.3.1-py38-cu112"
    ANYSCALE_RAY_2_3_1_PY38_CU113 = "anyscale/ray:2.3.1-py38-cu113"
    ANYSCALE_RAY_2_3_1_PY38_CU116 = "anyscale/ray:2.3.1-py38-cu116"
    ANYSCALE_RAY_2_3_1_PY38_CU118 = "anyscale/ray:2.3.1-py38-cu118"
    ANYSCALE_RAY_2_3_1_PY39 = "anyscale/ray:2.3.1-py39"
    ANYSCALE_RAY_2_3_1_PY39_CU101 = "anyscale/ray:2.3.1-py39-cu101"
    ANYSCALE_RAY_2_3_1_PY39_CU102 = "anyscale/ray:2.3.1-py39-cu102"
    ANYSCALE_RAY_2_3_1_PY39_CU110 = "anyscale/ray:2.3.1-py39-cu110"
    ANYSCALE_RAY_2_3_1_PY39_CU111 = "anyscale/ray:2.3.1-py39-cu111"
    ANYSCALE_RAY_2_3_1_PY39_CU112 = "anyscale/ray:2.3.1-py39-cu112"
    ANYSCALE_RAY_2_3_1_PY39_CU113 = "anyscale/ray:2.3.1-py39-cu113"
    ANYSCALE_RAY_2_3_1_PY39_CU116 = "anyscale/ray:2.3.1-py39-cu116"
    ANYSCALE_RAY_2_3_1_PY39_CU118 = "anyscale/ray:2.3.1-py39-cu118"
    ANYSCALE_RAY_2_30_0_PY310 = "anyscale/ray:2.30.0-py310"
    ANYSCALE_RAY_2_30_0_PY310_CU117 = "anyscale/ray:2.30.0-py310-cu117"
    ANYSCALE_RAY_2_30_0_PY310_CU118 = "anyscale/ray:2.30.0-py310-cu118"
    ANYSCALE_RAY_2_30_0_PY310_CU121 = "anyscale/ray:2.30.0-py310-cu121"
    ANYSCALE_RAY_2_30_0_PY310_CU123 = "anyscale/ray:2.30.0-py310-cu123"
    ANYSCALE_RAY_2_30_0_PY311 = "anyscale/ray:2.30.0-py311"
    ANYSCALE_RAY_2_30_0_PY311_CU117 = "anyscale/ray:2.30.0-py311-cu117"
    ANYSCALE_RAY_2_30_0_PY311_CU118 = "anyscale/ray:2.30.0-py311-cu118"
    ANYSCALE_RAY_2_30_0_PY311_CU121 = "anyscale/ray:2.30.0-py311-cu121"
    ANYSCALE_RAY_2_30_0_PY311_CU123 = "anyscale/ray:2.30.0-py311-cu123"
    ANYSCALE_RAY_2_30_0_PY39 = "anyscale/ray:2.30.0-py39"
    ANYSCALE_RAY_2_30_0_PY39_CU117 = "anyscale/ray:2.30.0-py39-cu117"
    ANYSCALE_RAY_2_30_0_PY39_CU118 = "anyscale/ray:2.30.0-py39-cu118"
    ANYSCALE_RAY_2_30_0_PY39_CU121 = "anyscale/ray:2.30.0-py39-cu121"
    ANYSCALE_RAY_2_30_0_PY39_CU123 = "anyscale/ray:2.30.0-py39-cu123"
    ANYSCALE_RAY_2_30_0_SLIM_PY310 = "anyscale/ray:2.30.0-slim-py310"
    ANYSCALE_RAY_2_30_0_SLIM_PY310_CU118 = "anyscale/ray:2.30.0-slim-py310-cu118"
    ANYSCALE_RAY_2_30_0_SLIM_PY310_CU121 = "anyscale/ray:2.30.0-slim-py310-cu121"
    ANYSCALE_RAY_2_30_0_SLIM_PY310_CU123 = "anyscale/ray:2.30.0-slim-py310-cu123"
    ANYSCALE_RAY_2_30_0_SLIM_PY311 = "anyscale/ray:2.30.0-slim-py311"
    ANYSCALE_RAY_2_30_0_SLIM_PY311_CU118 = "anyscale/ray:2.30.0-slim-py311-cu118"
    ANYSCALE_RAY_2_30_0_SLIM_PY311_CU121 = "anyscale/ray:2.30.0-slim-py311-cu121"
    ANYSCALE_RAY_2_30_0_SLIM_PY311_CU123 = "anyscale/ray:2.30.0-slim-py311-cu123"
    ANYSCALE_RAY_2_30_0_SLIM_PY39 = "anyscale/ray:2.30.0-slim-py39"
    ANYSCALE_RAY_2_30_0_SLIM_PY39_CU118 = "anyscale/ray:2.30.0-slim-py39-cu118"
    ANYSCALE_RAY_2_30_0_SLIM_PY39_CU121 = "anyscale/ray:2.30.0-slim-py39-cu121"
    ANYSCALE_RAY_2_30_0_SLIM_PY39_CU123 = "anyscale/ray:2.30.0-slim-py39-cu123"
    ANYSCALE_RAY_2_31_0_PY310 = "anyscale/ray:2.31.0-py310"
    ANYSCALE_RAY_2_31_0_PY310_CU117 = "anyscale/ray:2.31.0-py310-cu117"
    ANYSCALE_RAY_2_31_0_PY310_CU118 = "anyscale/ray:2.31.0-py310-cu118"
    ANYSCALE_RAY_2_31_0_PY310_CU121 = "anyscale/ray:2.31.0-py310-cu121"
    ANYSCALE_RAY_2_31_0_PY310_CU123 = "anyscale/ray:2.31.0-py310-cu123"
    ANYSCALE_RAY_2_31_0_PY311 = "anyscale/ray:2.31.0-py311"
    ANYSCALE_RAY_2_31_0_PY311_CU117 = "anyscale/ray:2.31.0-py311-cu117"
    ANYSCALE_RAY_2_31_0_PY311_CU118 = "anyscale/ray:2.31.0-py311-cu118"
    ANYSCALE_RAY_2_31_0_PY311_CU121 = "anyscale/ray:2.31.0-py311-cu121"
    ANYSCALE_RAY_2_31_0_PY311_CU123 = "anyscale/ray:2.31.0-py311-cu123"
    ANYSCALE_RAY_2_31_0_PY39 = "anyscale/ray:2.31.0-py39"
    ANYSCALE_RAY_2_31_0_PY39_CU117 = "anyscale/ray:2.31.0-py39-cu117"
    ANYSCALE_RAY_2_31_0_PY39_CU118 = "anyscale/ray:2.31.0-py39-cu118"
    ANYSCALE_RAY_2_31_0_PY39_CU121 = "anyscale/ray:2.31.0-py39-cu121"
    ANYSCALE_RAY_2_31_0_PY39_CU123 = "anyscale/ray:2.31.0-py39-cu123"
    ANYSCALE_RAY_2_31_0_SLIM_PY310 = "anyscale/ray:2.31.0-slim-py310"
    ANYSCALE_RAY_2_31_0_SLIM_PY310_CU118 = "anyscale/ray:2.31.0-slim-py310-cu118"
    ANYSCALE_RAY_2_31_0_SLIM_PY310_CU121 = "anyscale/ray:2.31.0-slim-py310-cu121"
    ANYSCALE_RAY_2_31_0_SLIM_PY310_CU123 = "anyscale/ray:2.31.0-slim-py310-cu123"
    ANYSCALE_RAY_2_31_0_SLIM_PY311 = "anyscale/ray:2.31.0-slim-py311"
    ANYSCALE_RAY_2_31_0_SLIM_PY311_CU118 = "anyscale/ray:2.31.0-slim-py311-cu118"
    ANYSCALE_RAY_2_31_0_SLIM_PY311_CU121 = "anyscale/ray:2.31.0-slim-py311-cu121"
    ANYSCALE_RAY_2_31_0_SLIM_PY311_CU123 = "anyscale/ray:2.31.0-slim-py311-cu123"
    ANYSCALE_RAY_2_31_0_SLIM_PY39 = "anyscale/ray:2.31.0-slim-py39"
    ANYSCALE_RAY_2_31_0_SLIM_PY39_CU118 = "anyscale/ray:2.31.0-slim-py39-cu118"
    ANYSCALE_RAY_2_31_0_SLIM_PY39_CU121 = "anyscale/ray:2.31.0-slim-py39-cu121"
    ANYSCALE_RAY_2_31_0_SLIM_PY39_CU123 = "anyscale/ray:2.31.0-slim-py39-cu123"
    ANYSCALE_RAY_2_32_0_PY310 = "anyscale/ray:2.32.0-py310"
    ANYSCALE_RAY_2_32_0_PY310_CU117 = "anyscale/ray:2.32.0-py310-cu117"
    ANYSCALE_RAY_2_32_0_PY310_CU118 = "anyscale/ray:2.32.0-py310-cu118"
    ANYSCALE_RAY_2_32_0_PY310_CU121 = "anyscale/ray:2.32.0-py310-cu121"
    ANYSCALE_RAY_2_32_0_PY310_CU123 = "anyscale/ray:2.32.0-py310-cu123"
    ANYSCALE_RAY_2_32_0_PY311 = "anyscale/ray:2.32.0-py311"
    ANYSCALE_RAY_2_32_0_PY311_CU117 = "anyscale/ray:2.32.0-py311-cu117"
    ANYSCALE_RAY_2_32_0_PY311_CU118 = "anyscale/ray:2.32.0-py311-cu118"
    ANYSCALE_RAY_2_32_0_PY311_CU121 = "anyscale/ray:2.32.0-py311-cu121"
    ANYSCALE_RAY_2_32_0_PY311_CU123 = "anyscale/ray:2.32.0-py311-cu123"
    ANYSCALE_RAY_2_32_0_PY39 = "anyscale/ray:2.32.0-py39"
    ANYSCALE_RAY_2_32_0_PY39_CU117 = "anyscale/ray:2.32.0-py39-cu117"
    ANYSCALE_RAY_2_32_0_PY39_CU118 = "anyscale/ray:2.32.0-py39-cu118"
    ANYSCALE_RAY_2_32_0_PY39_CU121 = "anyscale/ray:2.32.0-py39-cu121"
    ANYSCALE_RAY_2_32_0_PY39_CU123 = "anyscale/ray:2.32.0-py39-cu123"
    ANYSCALE_RAY_2_32_0_SLIM_PY310 = "anyscale/ray:2.32.0-slim-py310"
    ANYSCALE_RAY_2_32_0_SLIM_PY310_CU118 = "anyscale/ray:2.32.0-slim-py310-cu118"
    ANYSCALE_RAY_2_32_0_SLIM_PY310_CU121 = "anyscale/ray:2.32.0-slim-py310-cu121"
    ANYSCALE_RAY_2_32_0_SLIM_PY310_CU123 = "anyscale/ray:2.32.0-slim-py310-cu123"
    ANYSCALE_RAY_2_32_0_SLIM_PY311 = "anyscale/ray:2.32.0-slim-py311"
    ANYSCALE_RAY_2_32_0_SLIM_PY311_CU118 = "anyscale/ray:2.32.0-slim-py311-cu118"
    ANYSCALE_RAY_2_32_0_SLIM_PY311_CU121 = "anyscale/ray:2.32.0-slim-py311-cu121"
    ANYSCALE_RAY_2_32_0_SLIM_PY311_CU123 = "anyscale/ray:2.32.0-slim-py311-cu123"
    ANYSCALE_RAY_2_32_0_SLIM_PY39 = "anyscale/ray:2.32.0-slim-py39"
    ANYSCALE_RAY_2_32_0_SLIM_PY39_CU118 = "anyscale/ray:2.32.0-slim-py39-cu118"
    ANYSCALE_RAY_2_32_0_SLIM_PY39_CU121 = "anyscale/ray:2.32.0-slim-py39-cu121"
    ANYSCALE_RAY_2_32_0_SLIM_PY39_CU123 = "anyscale/ray:2.32.0-slim-py39-cu123"
    ANYSCALE_RAY_2_33_0_PY310 = "anyscale/ray:2.33.0-py310"
    ANYSCALE_RAY_2_33_0_PY310_CU117 = "anyscale/ray:2.33.0-py310-cu117"
    ANYSCALE_RAY_2_33_0_PY310_CU118 = "anyscale/ray:2.33.0-py310-cu118"
    ANYSCALE_RAY_2_33_0_PY310_CU121 = "anyscale/ray:2.33.0-py310-cu121"
    ANYSCALE_RAY_2_33_0_PY310_CU123 = "anyscale/ray:2.33.0-py310-cu123"
    ANYSCALE_RAY_2_33_0_PY311 = "anyscale/ray:2.33.0-py311"
    ANYSCALE_RAY_2_33_0_PY311_CU117 = "anyscale/ray:2.33.0-py311-cu117"
    ANYSCALE_RAY_2_33_0_PY311_CU118 = "anyscale/ray:2.33.0-py311-cu118"
    ANYSCALE_RAY_2_33_0_PY311_CU121 = "anyscale/ray:2.33.0-py311-cu121"
    ANYSCALE_RAY_2_33_0_PY311_CU123 = "anyscale/ray:2.33.0-py311-cu123"
    ANYSCALE_RAY_2_33_0_PY39 = "anyscale/ray:2.33.0-py39"
    ANYSCALE_RAY_2_33_0_PY39_CU117 = "anyscale/ray:2.33.0-py39-cu117"
    ANYSCALE_RAY_2_33_0_PY39_CU118 = "anyscale/ray:2.33.0-py39-cu118"
    ANYSCALE_RAY_2_33_0_PY39_CU121 = "anyscale/ray:2.33.0-py39-cu121"
    ANYSCALE_RAY_2_33_0_PY39_CU123 = "anyscale/ray:2.33.0-py39-cu123"
    ANYSCALE_RAY_2_33_0_SLIM_PY310 = "anyscale/ray:2.33.0-slim-py310"
    ANYSCALE_RAY_2_33_0_SLIM_PY310_CU118 = "anyscale/ray:2.33.0-slim-py310-cu118"
    ANYSCALE_RAY_2_33_0_SLIM_PY310_CU121 = "anyscale/ray:2.33.0-slim-py310-cu121"
    ANYSCALE_RAY_2_33_0_SLIM_PY310_CU123 = "anyscale/ray:2.33.0-slim-py310-cu123"
    ANYSCALE_RAY_2_33_0_SLIM_PY311 = "anyscale/ray:2.33.0-slim-py311"
    ANYSCALE_RAY_2_33_0_SLIM_PY311_CU118 = "anyscale/ray:2.33.0-slim-py311-cu118"
    ANYSCALE_RAY_2_33_0_SLIM_PY311_CU121 = "anyscale/ray:2.33.0-slim-py311-cu121"
    ANYSCALE_RAY_2_33_0_SLIM_PY311_CU123 = "anyscale/ray:2.33.0-slim-py311-cu123"
    ANYSCALE_RAY_2_33_0_SLIM_PY39 = "anyscale/ray:2.33.0-slim-py39"
    ANYSCALE_RAY_2_33_0_SLIM_PY39_CU118 = "anyscale/ray:2.33.0-slim-py39-cu118"
    ANYSCALE_RAY_2_33_0_SLIM_PY39_CU121 = "anyscale/ray:2.33.0-slim-py39-cu121"
    ANYSCALE_RAY_2_33_0_SLIM_PY39_CU123 = "anyscale/ray:2.33.0-slim-py39-cu123"
    ANYSCALE_RAY_2_34_0_PY310 = "anyscale/ray:2.34.0-py310"
    ANYSCALE_RAY_2_34_0_PY310_CU117 = "anyscale/ray:2.34.0-py310-cu117"
    ANYSCALE_RAY_2_34_0_PY310_CU118 = "anyscale/ray:2.34.0-py310-cu118"
    ANYSCALE_RAY_2_34_0_PY310_CU121 = "anyscale/ray:2.34.0-py310-cu121"
    ANYSCALE_RAY_2_34_0_PY310_CU123 = "anyscale/ray:2.34.0-py310-cu123"
    ANYSCALE_RAY_2_34_0_PY311 = "anyscale/ray:2.34.0-py311"
    ANYSCALE_RAY_2_34_0_PY311_CU117 = "anyscale/ray:2.34.0-py311-cu117"
    ANYSCALE_RAY_2_34_0_PY311_CU118 = "anyscale/ray:2.34.0-py311-cu118"
    ANYSCALE_RAY_2_34_0_PY311_CU121 = "anyscale/ray:2.34.0-py311-cu121"
    ANYSCALE_RAY_2_34_0_PY311_CU123 = "anyscale/ray:2.34.0-py311-cu123"
    ANYSCALE_RAY_2_34_0_PY39 = "anyscale/ray:2.34.0-py39"
    ANYSCALE_RAY_2_34_0_PY39_CU117 = "anyscale/ray:2.34.0-py39-cu117"
    ANYSCALE_RAY_2_34_0_PY39_CU118 = "anyscale/ray:2.34.0-py39-cu118"
    ANYSCALE_RAY_2_34_0_PY39_CU121 = "anyscale/ray:2.34.0-py39-cu121"
    ANYSCALE_RAY_2_34_0_PY39_CU123 = "anyscale/ray:2.34.0-py39-cu123"
    ANYSCALE_RAY_2_34_0_SLIM_PY310 = "anyscale/ray:2.34.0-slim-py310"
    ANYSCALE_RAY_2_34_0_SLIM_PY310_CU118 = "anyscale/ray:2.34.0-slim-py310-cu118"
    ANYSCALE_RAY_2_34_0_SLIM_PY310_CU121 = "anyscale/ray:2.34.0-slim-py310-cu121"
    ANYSCALE_RAY_2_34_0_SLIM_PY310_CU123 = "anyscale/ray:2.34.0-slim-py310-cu123"
    ANYSCALE_RAY_2_34_0_SLIM_PY311 = "anyscale/ray:2.34.0-slim-py311"
    ANYSCALE_RAY_2_34_0_SLIM_PY311_CU118 = "anyscale/ray:2.34.0-slim-py311-cu118"
    ANYSCALE_RAY_2_34_0_SLIM_PY311_CU121 = "anyscale/ray:2.34.0-slim-py311-cu121"
    ANYSCALE_RAY_2_34_0_SLIM_PY311_CU123 = "anyscale/ray:2.34.0-slim-py311-cu123"
    ANYSCALE_RAY_2_34_0_SLIM_PY39 = "anyscale/ray:2.34.0-slim-py39"
    ANYSCALE_RAY_2_34_0_SLIM_PY39_CU118 = "anyscale/ray:2.34.0-slim-py39-cu118"
    ANYSCALE_RAY_2_34_0_SLIM_PY39_CU121 = "anyscale/ray:2.34.0-slim-py39-cu121"
    ANYSCALE_RAY_2_34_0_SLIM_PY39_CU123 = "anyscale/ray:2.34.0-slim-py39-cu123"
    ANYSCALE_RAY_2_35_0_PY310 = "anyscale/ray:2.35.0-py310"
    ANYSCALE_RAY_2_35_0_PY310_CU117 = "anyscale/ray:2.35.0-py310-cu117"
    ANYSCALE_RAY_2_35_0_PY310_CU118 = "anyscale/ray:2.35.0-py310-cu118"
    ANYSCALE_RAY_2_35_0_PY310_CU121 = "anyscale/ray:2.35.0-py310-cu121"
    ANYSCALE_RAY_2_35_0_PY310_CU123 = "anyscale/ray:2.35.0-py310-cu123"
    ANYSCALE_RAY_2_35_0_PY311 = "anyscale/ray:2.35.0-py311"
    ANYSCALE_RAY_2_35_0_PY311_CU117 = "anyscale/ray:2.35.0-py311-cu117"
    ANYSCALE_RAY_2_35_0_PY311_CU118 = "anyscale/ray:2.35.0-py311-cu118"
    ANYSCALE_RAY_2_35_0_PY311_CU121 = "anyscale/ray:2.35.0-py311-cu121"
    ANYSCALE_RAY_2_35_0_PY311_CU123 = "anyscale/ray:2.35.0-py311-cu123"
    ANYSCALE_RAY_2_35_0_PY312 = "anyscale/ray:2.35.0-py312"
    ANYSCALE_RAY_2_35_0_PY312_CU117 = "anyscale/ray:2.35.0-py312-cu117"
    ANYSCALE_RAY_2_35_0_PY312_CU118 = "anyscale/ray:2.35.0-py312-cu118"
    ANYSCALE_RAY_2_35_0_PY312_CU121 = "anyscale/ray:2.35.0-py312-cu121"
    ANYSCALE_RAY_2_35_0_PY312_CU123 = "anyscale/ray:2.35.0-py312-cu123"
    ANYSCALE_RAY_2_35_0_PY39 = "anyscale/ray:2.35.0-py39"
    ANYSCALE_RAY_2_35_0_PY39_CU117 = "anyscale/ray:2.35.0-py39-cu117"
    ANYSCALE_RAY_2_35_0_PY39_CU118 = "anyscale/ray:2.35.0-py39-cu118"
    ANYSCALE_RAY_2_35_0_PY39_CU121 = "anyscale/ray:2.35.0-py39-cu121"
    ANYSCALE_RAY_2_35_0_PY39_CU123 = "anyscale/ray:2.35.0-py39-cu123"
    ANYSCALE_RAY_2_35_0_SLIM_PY310 = "anyscale/ray:2.35.0-slim-py310"
    ANYSCALE_RAY_2_35_0_SLIM_PY310_CU118 = "anyscale/ray:2.35.0-slim-py310-cu118"
    ANYSCALE_RAY_2_35_0_SLIM_PY310_CU121 = "anyscale/ray:2.35.0-slim-py310-cu121"
    ANYSCALE_RAY_2_35_0_SLIM_PY310_CU123 = "anyscale/ray:2.35.0-slim-py310-cu123"
    ANYSCALE_RAY_2_35_0_SLIM_PY311 = "anyscale/ray:2.35.0-slim-py311"
    ANYSCALE_RAY_2_35_0_SLIM_PY311_CU118 = "anyscale/ray:2.35.0-slim-py311-cu118"
    ANYSCALE_RAY_2_35_0_SLIM_PY311_CU121 = "anyscale/ray:2.35.0-slim-py311-cu121"
    ANYSCALE_RAY_2_35_0_SLIM_PY311_CU123 = "anyscale/ray:2.35.0-slim-py311-cu123"
    ANYSCALE_RAY_2_35_0_SLIM_PY312 = "anyscale/ray:2.35.0-slim-py312"
    ANYSCALE_RAY_2_35_0_SLIM_PY312_CU118 = "anyscale/ray:2.35.0-slim-py312-cu118"
    ANYSCALE_RAY_2_35_0_SLIM_PY312_CU121 = "anyscale/ray:2.35.0-slim-py312-cu121"
    ANYSCALE_RAY_2_35_0_SLIM_PY312_CU123 = "anyscale/ray:2.35.0-slim-py312-cu123"
    ANYSCALE_RAY_2_35_0_SLIM_PY39 = "anyscale/ray:2.35.0-slim-py39"
    ANYSCALE_RAY_2_35_0_SLIM_PY39_CU118 = "anyscale/ray:2.35.0-slim-py39-cu118"
    ANYSCALE_RAY_2_35_0_SLIM_PY39_CU121 = "anyscale/ray:2.35.0-slim-py39-cu121"
    ANYSCALE_RAY_2_35_0_SLIM_PY39_CU123 = "anyscale/ray:2.35.0-slim-py39-cu123"
    ANYSCALE_RAY_2_36_0_PY310 = "anyscale/ray:2.36.0-py310"
    ANYSCALE_RAY_2_36_0_PY310_CU117 = "anyscale/ray:2.36.0-py310-cu117"
    ANYSCALE_RAY_2_36_0_PY310_CU118 = "anyscale/ray:2.36.0-py310-cu118"
    ANYSCALE_RAY_2_36_0_PY310_CU121 = "anyscale/ray:2.36.0-py310-cu121"
    ANYSCALE_RAY_2_36_0_PY310_CU123 = "anyscale/ray:2.36.0-py310-cu123"
    ANYSCALE_RAY_2_36_0_PY311 = "anyscale/ray:2.36.0-py311"
    ANYSCALE_RAY_2_36_0_PY311_CU117 = "anyscale/ray:2.36.0-py311-cu117"
    ANYSCALE_RAY_2_36_0_PY311_CU118 = "anyscale/ray:2.36.0-py311-cu118"
    ANYSCALE_RAY_2_36_0_PY311_CU121 = "anyscale/ray:2.36.0-py311-cu121"
    ANYSCALE_RAY_2_36_0_PY311_CU123 = "anyscale/ray:2.36.0-py311-cu123"
    ANYSCALE_RAY_2_36_0_PY312 = "anyscale/ray:2.36.0-py312"
    ANYSCALE_RAY_2_36_0_PY312_CU117 = "anyscale/ray:2.36.0-py312-cu117"
    ANYSCALE_RAY_2_36_0_PY312_CU118 = "anyscale/ray:2.36.0-py312-cu118"
    ANYSCALE_RAY_2_36_0_PY312_CU121 = "anyscale/ray:2.36.0-py312-cu121"
    ANYSCALE_RAY_2_36_0_PY312_CU123 = "anyscale/ray:2.36.0-py312-cu123"
    ANYSCALE_RAY_2_36_0_PY39 = "anyscale/ray:2.36.0-py39"
    ANYSCALE_RAY_2_36_0_PY39_CU117 = "anyscale/ray:2.36.0-py39-cu117"
    ANYSCALE_RAY_2_36_0_PY39_CU118 = "anyscale/ray:2.36.0-py39-cu118"
    ANYSCALE_RAY_2_36_0_PY39_CU121 = "anyscale/ray:2.36.0-py39-cu121"
    ANYSCALE_RAY_2_36_0_PY39_CU123 = "anyscale/ray:2.36.0-py39-cu123"
    ANYSCALE_RAY_2_36_0_SLIM_PY310 = "anyscale/ray:2.36.0-slim-py310"
    ANYSCALE_RAY_2_36_0_SLIM_PY310_CU118 = "anyscale/ray:2.36.0-slim-py310-cu118"
    ANYSCALE_RAY_2_36_0_SLIM_PY310_CU121 = "anyscale/ray:2.36.0-slim-py310-cu121"
    ANYSCALE_RAY_2_36_0_SLIM_PY310_CU123 = "anyscale/ray:2.36.0-slim-py310-cu123"
    ANYSCALE_RAY_2_36_0_SLIM_PY311 = "anyscale/ray:2.36.0-slim-py311"
    ANYSCALE_RAY_2_36_0_SLIM_PY311_CU118 = "anyscale/ray:2.36.0-slim-py311-cu118"
    ANYSCALE_RAY_2_36_0_SLIM_PY311_CU121 = "anyscale/ray:2.36.0-slim-py311-cu121"
    ANYSCALE_RAY_2_36_0_SLIM_PY311_CU123 = "anyscale/ray:2.36.0-slim-py311-cu123"
    ANYSCALE_RAY_2_36_0_SLIM_PY312 = "anyscale/ray:2.36.0-slim-py312"
    ANYSCALE_RAY_2_36_0_SLIM_PY312_CU118 = "anyscale/ray:2.36.0-slim-py312-cu118"
    ANYSCALE_RAY_2_36_0_SLIM_PY312_CU121 = "anyscale/ray:2.36.0-slim-py312-cu121"
    ANYSCALE_RAY_2_36_0_SLIM_PY312_CU123 = "anyscale/ray:2.36.0-slim-py312-cu123"
    ANYSCALE_RAY_2_36_0_SLIM_PY39 = "anyscale/ray:2.36.0-slim-py39"
    ANYSCALE_RAY_2_36_0_SLIM_PY39_CU118 = "anyscale/ray:2.36.0-slim-py39-cu118"
    ANYSCALE_RAY_2_36_0_SLIM_PY39_CU121 = "anyscale/ray:2.36.0-slim-py39-cu121"
    ANYSCALE_RAY_2_36_0_SLIM_PY39_CU123 = "anyscale/ray:2.36.0-slim-py39-cu123"
    ANYSCALE_RAY_2_36_1_PY310 = "anyscale/ray:2.36.1-py310"
    ANYSCALE_RAY_2_36_1_PY310_CU117 = "anyscale/ray:2.36.1-py310-cu117"
    ANYSCALE_RAY_2_36_1_PY310_CU118 = "anyscale/ray:2.36.1-py310-cu118"
    ANYSCALE_RAY_2_36_1_PY310_CU121 = "anyscale/ray:2.36.1-py310-cu121"
    ANYSCALE_RAY_2_36_1_PY310_CU123 = "anyscale/ray:2.36.1-py310-cu123"
    ANYSCALE_RAY_2_36_1_PY311 = "anyscale/ray:2.36.1-py311"
    ANYSCALE_RAY_2_36_1_PY311_CU117 = "anyscale/ray:2.36.1-py311-cu117"
    ANYSCALE_RAY_2_36_1_PY311_CU118 = "anyscale/ray:2.36.1-py311-cu118"
    ANYSCALE_RAY_2_36_1_PY311_CU121 = "anyscale/ray:2.36.1-py311-cu121"
    ANYSCALE_RAY_2_36_1_PY311_CU123 = "anyscale/ray:2.36.1-py311-cu123"
    ANYSCALE_RAY_2_36_1_PY312 = "anyscale/ray:2.36.1-py312"
    ANYSCALE_RAY_2_36_1_PY312_CU117 = "anyscale/ray:2.36.1-py312-cu117"
    ANYSCALE_RAY_2_36_1_PY312_CU118 = "anyscale/ray:2.36.1-py312-cu118"
    ANYSCALE_RAY_2_36_1_PY312_CU121 = "anyscale/ray:2.36.1-py312-cu121"
    ANYSCALE_RAY_2_36_1_PY312_CU123 = "anyscale/ray:2.36.1-py312-cu123"
    ANYSCALE_RAY_2_36_1_PY39 = "anyscale/ray:2.36.1-py39"
    ANYSCALE_RAY_2_36_1_PY39_CU117 = "anyscale/ray:2.36.1-py39-cu117"
    ANYSCALE_RAY_2_36_1_PY39_CU118 = "anyscale/ray:2.36.1-py39-cu118"
    ANYSCALE_RAY_2_36_1_PY39_CU121 = "anyscale/ray:2.36.1-py39-cu121"
    ANYSCALE_RAY_2_36_1_PY39_CU123 = "anyscale/ray:2.36.1-py39-cu123"
    ANYSCALE_RAY_2_36_1_SLIM_PY310 = "anyscale/ray:2.36.1-slim-py310"
    ANYSCALE_RAY_2_36_1_SLIM_PY310_CU118 = "anyscale/ray:2.36.1-slim-py310-cu118"
    ANYSCALE_RAY_2_36_1_SLIM_PY310_CU121 = "anyscale/ray:2.36.1-slim-py310-cu121"
    ANYSCALE_RAY_2_36_1_SLIM_PY310_CU123 = "anyscale/ray:2.36.1-slim-py310-cu123"
    ANYSCALE_RAY_2_36_1_SLIM_PY311 = "anyscale/ray:2.36.1-slim-py311"
    ANYSCALE_RAY_2_36_1_SLIM_PY311_CU118 = "anyscale/ray:2.36.1-slim-py311-cu118"
    ANYSCALE_RAY_2_36_1_SLIM_PY311_CU121 = "anyscale/ray:2.36.1-slim-py311-cu121"
    ANYSCALE_RAY_2_36_1_SLIM_PY311_CU123 = "anyscale/ray:2.36.1-slim-py311-cu123"
    ANYSCALE_RAY_2_36_1_SLIM_PY312 = "anyscale/ray:2.36.1-slim-py312"
    ANYSCALE_RAY_2_36_1_SLIM_PY312_CU118 = "anyscale/ray:2.36.1-slim-py312-cu118"
    ANYSCALE_RAY_2_36_1_SLIM_PY312_CU121 = "anyscale/ray:2.36.1-slim-py312-cu121"
    ANYSCALE_RAY_2_36_1_SLIM_PY312_CU123 = "anyscale/ray:2.36.1-slim-py312-cu123"
    ANYSCALE_RAY_2_36_1_SLIM_PY39 = "anyscale/ray:2.36.1-slim-py39"
    ANYSCALE_RAY_2_36_1_SLIM_PY39_CU118 = "anyscale/ray:2.36.1-slim-py39-cu118"
    ANYSCALE_RAY_2_36_1_SLIM_PY39_CU121 = "anyscale/ray:2.36.1-slim-py39-cu121"
    ANYSCALE_RAY_2_36_1_SLIM_PY39_CU123 = "anyscale/ray:2.36.1-slim-py39-cu123"
    ANYSCALE_RAY_2_37_0_PY310 = "anyscale/ray:2.37.0-py310"
    ANYSCALE_RAY_2_37_0_PY310_CU117 = "anyscale/ray:2.37.0-py310-cu117"
    ANYSCALE_RAY_2_37_0_PY310_CU118 = "anyscale/ray:2.37.0-py310-cu118"
    ANYSCALE_RAY_2_37_0_PY310_CU121 = "anyscale/ray:2.37.0-py310-cu121"
    ANYSCALE_RAY_2_37_0_PY310_CU123 = "anyscale/ray:2.37.0-py310-cu123"
    ANYSCALE_RAY_2_37_0_PY311 = "anyscale/ray:2.37.0-py311"
    ANYSCALE_RAY_2_37_0_PY311_CU117 = "anyscale/ray:2.37.0-py311-cu117"
    ANYSCALE_RAY_2_37_0_PY311_CU118 = "anyscale/ray:2.37.0-py311-cu118"
    ANYSCALE_RAY_2_37_0_PY311_CU121 = "anyscale/ray:2.37.0-py311-cu121"
    ANYSCALE_RAY_2_37_0_PY311_CU123 = "anyscale/ray:2.37.0-py311-cu123"
    ANYSCALE_RAY_2_37_0_PY312 = "anyscale/ray:2.37.0-py312"
    ANYSCALE_RAY_2_37_0_PY312_CU117 = "anyscale/ray:2.37.0-py312-cu117"
    ANYSCALE_RAY_2_37_0_PY312_CU118 = "anyscale/ray:2.37.0-py312-cu118"
    ANYSCALE_RAY_2_37_0_PY312_CU121 = "anyscale/ray:2.37.0-py312-cu121"
    ANYSCALE_RAY_2_37_0_PY312_CU123 = "anyscale/ray:2.37.0-py312-cu123"
    ANYSCALE_RAY_2_37_0_PY39 = "anyscale/ray:2.37.0-py39"
    ANYSCALE_RAY_2_37_0_PY39_CU117 = "anyscale/ray:2.37.0-py39-cu117"
    ANYSCALE_RAY_2_37_0_PY39_CU118 = "anyscale/ray:2.37.0-py39-cu118"
    ANYSCALE_RAY_2_37_0_PY39_CU121 = "anyscale/ray:2.37.0-py39-cu121"
    ANYSCALE_RAY_2_37_0_PY39_CU123 = "anyscale/ray:2.37.0-py39-cu123"
    ANYSCALE_RAY_2_37_0_SLIM_PY310 = "anyscale/ray:2.37.0-slim-py310"
    ANYSCALE_RAY_2_37_0_SLIM_PY310_CU118 = "anyscale/ray:2.37.0-slim-py310-cu118"
    ANYSCALE_RAY_2_37_0_SLIM_PY310_CU121 = "anyscale/ray:2.37.0-slim-py310-cu121"
    ANYSCALE_RAY_2_37_0_SLIM_PY310_CU123 = "anyscale/ray:2.37.0-slim-py310-cu123"
    ANYSCALE_RAY_2_37_0_SLIM_PY311 = "anyscale/ray:2.37.0-slim-py311"
    ANYSCALE_RAY_2_37_0_SLIM_PY311_CU118 = "anyscale/ray:2.37.0-slim-py311-cu118"
    ANYSCALE_RAY_2_37_0_SLIM_PY311_CU121 = "anyscale/ray:2.37.0-slim-py311-cu121"
    ANYSCALE_RAY_2_37_0_SLIM_PY311_CU123 = "anyscale/ray:2.37.0-slim-py311-cu123"
    ANYSCALE_RAY_2_37_0_SLIM_PY312 = "anyscale/ray:2.37.0-slim-py312"
    ANYSCALE_RAY_2_37_0_SLIM_PY312_CU118 = "anyscale/ray:2.37.0-slim-py312-cu118"
    ANYSCALE_RAY_2_37_0_SLIM_PY312_CU121 = "anyscale/ray:2.37.0-slim-py312-cu121"
    ANYSCALE_RAY_2_37_0_SLIM_PY312_CU123 = "anyscale/ray:2.37.0-slim-py312-cu123"
    ANYSCALE_RAY_2_37_0_SLIM_PY39 = "anyscale/ray:2.37.0-slim-py39"
    ANYSCALE_RAY_2_37_0_SLIM_PY39_CU118 = "anyscale/ray:2.37.0-slim-py39-cu118"
    ANYSCALE_RAY_2_37_0_SLIM_PY39_CU121 = "anyscale/ray:2.37.0-slim-py39-cu121"
    ANYSCALE_RAY_2_37_0_SLIM_PY39_CU123 = "anyscale/ray:2.37.0-slim-py39-cu123"
    ANYSCALE_RAY_2_38_0_PY310 = "anyscale/ray:2.38.0-py310"
    ANYSCALE_RAY_2_38_0_PY310_CU117 = "anyscale/ray:2.38.0-py310-cu117"
    ANYSCALE_RAY_2_38_0_PY310_CU118 = "anyscale/ray:2.38.0-py310-cu118"
    ANYSCALE_RAY_2_38_0_PY310_CU121 = "anyscale/ray:2.38.0-py310-cu121"
    ANYSCALE_RAY_2_38_0_PY310_CU123 = "anyscale/ray:2.38.0-py310-cu123"
    ANYSCALE_RAY_2_38_0_PY311 = "anyscale/ray:2.38.0-py311"
    ANYSCALE_RAY_2_38_0_PY311_CU117 = "anyscale/ray:2.38.0-py311-cu117"
    ANYSCALE_RAY_2_38_0_PY311_CU118 = "anyscale/ray:2.38.0-py311-cu118"
    ANYSCALE_RAY_2_38_0_PY311_CU121 = "anyscale/ray:2.38.0-py311-cu121"
    ANYSCALE_RAY_2_38_0_PY311_CU123 = "anyscale/ray:2.38.0-py311-cu123"
    ANYSCALE_RAY_2_38_0_PY312 = "anyscale/ray:2.38.0-py312"
    ANYSCALE_RAY_2_38_0_PY312_CU117 = "anyscale/ray:2.38.0-py312-cu117"
    ANYSCALE_RAY_2_38_0_PY312_CU118 = "anyscale/ray:2.38.0-py312-cu118"
    ANYSCALE_RAY_2_38_0_PY312_CU121 = "anyscale/ray:2.38.0-py312-cu121"
    ANYSCALE_RAY_2_38_0_PY312_CU123 = "anyscale/ray:2.38.0-py312-cu123"
    ANYSCALE_RAY_2_38_0_PY39 = "anyscale/ray:2.38.0-py39"
    ANYSCALE_RAY_2_38_0_PY39_CU117 = "anyscale/ray:2.38.0-py39-cu117"
    ANYSCALE_RAY_2_38_0_PY39_CU118 = "anyscale/ray:2.38.0-py39-cu118"
    ANYSCALE_RAY_2_38_0_PY39_CU121 = "anyscale/ray:2.38.0-py39-cu121"
    ANYSCALE_RAY_2_38_0_PY39_CU123 = "anyscale/ray:2.38.0-py39-cu123"
    ANYSCALE_RAY_2_38_0_SLIM_PY310 = "anyscale/ray:2.38.0-slim-py310"
    ANYSCALE_RAY_2_38_0_SLIM_PY310_CU118 = "anyscale/ray:2.38.0-slim-py310-cu118"
    ANYSCALE_RAY_2_38_0_SLIM_PY310_CU121 = "anyscale/ray:2.38.0-slim-py310-cu121"
    ANYSCALE_RAY_2_38_0_SLIM_PY310_CU123 = "anyscale/ray:2.38.0-slim-py310-cu123"
    ANYSCALE_RAY_2_38_0_SLIM_PY311 = "anyscale/ray:2.38.0-slim-py311"
    ANYSCALE_RAY_2_38_0_SLIM_PY311_CU118 = "anyscale/ray:2.38.0-slim-py311-cu118"
    ANYSCALE_RAY_2_38_0_SLIM_PY311_CU121 = "anyscale/ray:2.38.0-slim-py311-cu121"
    ANYSCALE_RAY_2_38_0_SLIM_PY311_CU123 = "anyscale/ray:2.38.0-slim-py311-cu123"
    ANYSCALE_RAY_2_38_0_SLIM_PY312 = "anyscale/ray:2.38.0-slim-py312"
    ANYSCALE_RAY_2_38_0_SLIM_PY312_CU118 = "anyscale/ray:2.38.0-slim-py312-cu118"
    ANYSCALE_RAY_2_38_0_SLIM_PY312_CU121 = "anyscale/ray:2.38.0-slim-py312-cu121"
    ANYSCALE_RAY_2_38_0_SLIM_PY312_CU123 = "anyscale/ray:2.38.0-slim-py312-cu123"
    ANYSCALE_RAY_2_38_0_SLIM_PY39 = "anyscale/ray:2.38.0-slim-py39"
    ANYSCALE_RAY_2_38_0_SLIM_PY39_CU118 = "anyscale/ray:2.38.0-slim-py39-cu118"
    ANYSCALE_RAY_2_38_0_SLIM_PY39_CU121 = "anyscale/ray:2.38.0-slim-py39-cu121"
    ANYSCALE_RAY_2_38_0_SLIM_PY39_CU123 = "anyscale/ray:2.38.0-slim-py39-cu123"
    ANYSCALE_RAY_2_39_0_PY310 = "anyscale/ray:2.39.0-py310"
    ANYSCALE_RAY_2_39_0_PY310_CU117 = "anyscale/ray:2.39.0-py310-cu117"
    ANYSCALE_RAY_2_39_0_PY310_CU118 = "anyscale/ray:2.39.0-py310-cu118"
    ANYSCALE_RAY_2_39_0_PY310_CU121 = "anyscale/ray:2.39.0-py310-cu121"
    ANYSCALE_RAY_2_39_0_PY310_CU123 = "anyscale/ray:2.39.0-py310-cu123"
    ANYSCALE_RAY_2_39_0_PY311 = "anyscale/ray:2.39.0-py311"
    ANYSCALE_RAY_2_39_0_PY311_CU117 = "anyscale/ray:2.39.0-py311-cu117"
    ANYSCALE_RAY_2_39_0_PY311_CU118 = "anyscale/ray:2.39.0-py311-cu118"
    ANYSCALE_RAY_2_39_0_PY311_CU121 = "anyscale/ray:2.39.0-py311-cu121"
    ANYSCALE_RAY_2_39_0_PY311_CU123 = "anyscale/ray:2.39.0-py311-cu123"
    ANYSCALE_RAY_2_39_0_PY312 = "anyscale/ray:2.39.0-py312"
    ANYSCALE_RAY_2_39_0_PY312_CU117 = "anyscale/ray:2.39.0-py312-cu117"
    ANYSCALE_RAY_2_39_0_PY312_CU118 = "anyscale/ray:2.39.0-py312-cu118"
    ANYSCALE_RAY_2_39_0_PY312_CU121 = "anyscale/ray:2.39.0-py312-cu121"
    ANYSCALE_RAY_2_39_0_PY312_CU123 = "anyscale/ray:2.39.0-py312-cu123"
    ANYSCALE_RAY_2_39_0_PY39 = "anyscale/ray:2.39.0-py39"
    ANYSCALE_RAY_2_39_0_PY39_CU117 = "anyscale/ray:2.39.0-py39-cu117"
    ANYSCALE_RAY_2_39_0_PY39_CU118 = "anyscale/ray:2.39.0-py39-cu118"
    ANYSCALE_RAY_2_39_0_PY39_CU121 = "anyscale/ray:2.39.0-py39-cu121"
    ANYSCALE_RAY_2_39_0_PY39_CU123 = "anyscale/ray:2.39.0-py39-cu123"
    ANYSCALE_RAY_2_39_0_SLIM_PY310 = "anyscale/ray:2.39.0-slim-py310"
    ANYSCALE_RAY_2_39_0_SLIM_PY310_CU118 = "anyscale/ray:2.39.0-slim-py310-cu118"
    ANYSCALE_RAY_2_39_0_SLIM_PY310_CU121 = "anyscale/ray:2.39.0-slim-py310-cu121"
    ANYSCALE_RAY_2_39_0_SLIM_PY310_CU123 = "anyscale/ray:2.39.0-slim-py310-cu123"
    ANYSCALE_RAY_2_39_0_SLIM_PY311 = "anyscale/ray:2.39.0-slim-py311"
    ANYSCALE_RAY_2_39_0_SLIM_PY311_CU118 = "anyscale/ray:2.39.0-slim-py311-cu118"
    ANYSCALE_RAY_2_39_0_SLIM_PY311_CU121 = "anyscale/ray:2.39.0-slim-py311-cu121"
    ANYSCALE_RAY_2_39_0_SLIM_PY311_CU123 = "anyscale/ray:2.39.0-slim-py311-cu123"
    ANYSCALE_RAY_2_39_0_SLIM_PY312 = "anyscale/ray:2.39.0-slim-py312"
    ANYSCALE_RAY_2_39_0_SLIM_PY312_CU118 = "anyscale/ray:2.39.0-slim-py312-cu118"
    ANYSCALE_RAY_2_39_0_SLIM_PY312_CU121 = "anyscale/ray:2.39.0-slim-py312-cu121"
    ANYSCALE_RAY_2_39_0_SLIM_PY312_CU123 = "anyscale/ray:2.39.0-slim-py312-cu123"
    ANYSCALE_RAY_2_39_0_SLIM_PY39 = "anyscale/ray:2.39.0-slim-py39"
    ANYSCALE_RAY_2_39_0_SLIM_PY39_CU118 = "anyscale/ray:2.39.0-slim-py39-cu118"
    ANYSCALE_RAY_2_39_0_SLIM_PY39_CU121 = "anyscale/ray:2.39.0-slim-py39-cu121"
    ANYSCALE_RAY_2_39_0_SLIM_PY39_CU123 = "anyscale/ray:2.39.0-slim-py39-cu123"
    ANYSCALE_RAY_2_4_0_PY310 = "anyscale/ray:2.4.0-py310"
    ANYSCALE_RAY_2_4_0_PY310_CU101 = "anyscale/ray:2.4.0-py310-cu101"
    ANYSCALE_RAY_2_4_0_PY310_CU102 = "anyscale/ray:2.4.0-py310-cu102"
    ANYSCALE_RAY_2_4_0_PY310_CU110 = "anyscale/ray:2.4.0-py310-cu110"
    ANYSCALE_RAY_2_4_0_PY310_CU111 = "anyscale/ray:2.4.0-py310-cu111"
    ANYSCALE_RAY_2_4_0_PY310_CU112 = "anyscale/ray:2.4.0-py310-cu112"
    ANYSCALE_RAY_2_4_0_PY310_CU113 = "anyscale/ray:2.4.0-py310-cu113"
    ANYSCALE_RAY_2_4_0_PY310_CU116 = "anyscale/ray:2.4.0-py310-cu116"
    ANYSCALE_RAY_2_4_0_PY310_CU118 = "anyscale/ray:2.4.0-py310-cu118"
    ANYSCALE_RAY_2_4_0_PY37 = "anyscale/ray:2.4.0-py37"
    ANYSCALE_RAY_2_4_0_PY37_CU101 = "anyscale/ray:2.4.0-py37-cu101"
    ANYSCALE_RAY_2_4_0_PY37_CU102 = "anyscale/ray:2.4.0-py37-cu102"
    ANYSCALE_RAY_2_4_0_PY37_CU110 = "anyscale/ray:2.4.0-py37-cu110"
    ANYSCALE_RAY_2_4_0_PY37_CU111 = "anyscale/ray:2.4.0-py37-cu111"
    ANYSCALE_RAY_2_4_0_PY37_CU112 = "anyscale/ray:2.4.0-py37-cu112"
    ANYSCALE_RAY_2_4_0_PY37_CU113 = "anyscale/ray:2.4.0-py37-cu113"
    ANYSCALE_RAY_2_4_0_PY37_CU116 = "anyscale/ray:2.4.0-py37-cu116"
    ANYSCALE_RAY_2_4_0_PY37_CU118 = "anyscale/ray:2.4.0-py37-cu118"
    ANYSCALE_RAY_2_4_0_PY38 = "anyscale/ray:2.4.0-py38"
    ANYSCALE_RAY_2_4_0_PY38_CU101 = "anyscale/ray:2.4.0-py38-cu101"
    ANYSCALE_RAY_2_4_0_PY38_CU102 = "anyscale/ray:2.4.0-py38-cu102"
    ANYSCALE_RAY_2_4_0_PY38_CU110 = "anyscale/ray:2.4.0-py38-cu110"
    ANYSCALE_RAY_2_4_0_PY38_CU111 = "anyscale/ray:2.4.0-py38-cu111"
    ANYSCALE_RAY_2_4_0_PY38_CU112 = "anyscale/ray:2.4.0-py38-cu112"
    ANYSCALE_RAY_2_4_0_PY38_CU113 = "anyscale/ray:2.4.0-py38-cu113"
    ANYSCALE_RAY_2_4_0_PY38_CU116 = "anyscale/ray:2.4.0-py38-cu116"
    ANYSCALE_RAY_2_4_0_PY38_CU118 = "anyscale/ray:2.4.0-py38-cu118"
    ANYSCALE_RAY_2_4_0_PY39 = "anyscale/ray:2.4.0-py39"
    ANYSCALE_RAY_2_4_0_PY39_CU101 = "anyscale/ray:2.4.0-py39-cu101"
    ANYSCALE_RAY_2_4_0_PY39_CU102 = "anyscale/ray:2.4.0-py39-cu102"
    ANYSCALE_RAY_2_4_0_PY39_CU110 = "anyscale/ray:2.4.0-py39-cu110"
    ANYSCALE_RAY_2_4_0_PY39_CU111 = "anyscale/ray:2.4.0-py39-cu111"
    ANYSCALE_RAY_2_4_0_PY39_CU112 = "anyscale/ray:2.4.0-py39-cu112"
    ANYSCALE_RAY_2_4_0_PY39_CU113 = "anyscale/ray:2.4.0-py39-cu113"
    ANYSCALE_RAY_2_4_0_PY39_CU116 = "anyscale/ray:2.4.0-py39-cu116"
    ANYSCALE_RAY_2_4_0_PY39_CU118 = "anyscale/ray:2.4.0-py39-cu118"
    ANYSCALE_RAY_2_40_0_PY310 = "anyscale/ray:2.40.0-py310"
    ANYSCALE_RAY_2_40_0_PY310_CU117 = "anyscale/ray:2.40.0-py310-cu117"
    ANYSCALE_RAY_2_40_0_PY310_CU118 = "anyscale/ray:2.40.0-py310-cu118"
    ANYSCALE_RAY_2_40_0_PY310_CU121 = "anyscale/ray:2.40.0-py310-cu121"
    ANYSCALE_RAY_2_40_0_PY310_CU123 = "anyscale/ray:2.40.0-py310-cu123"
    ANYSCALE_RAY_2_40_0_PY311 = "anyscale/ray:2.40.0-py311"
    ANYSCALE_RAY_2_40_0_PY311_CU117 = "anyscale/ray:2.40.0-py311-cu117"
    ANYSCALE_RAY_2_40_0_PY311_CU118 = "anyscale/ray:2.40.0-py311-cu118"
    ANYSCALE_RAY_2_40_0_PY311_CU121 = "anyscale/ray:2.40.0-py311-cu121"
    ANYSCALE_RAY_2_40_0_PY311_CU123 = "anyscale/ray:2.40.0-py311-cu123"
    ANYSCALE_RAY_2_40_0_PY312 = "anyscale/ray:2.40.0-py312"
    ANYSCALE_RAY_2_40_0_PY312_CU117 = "anyscale/ray:2.40.0-py312-cu117"
    ANYSCALE_RAY_2_40_0_PY312_CU118 = "anyscale/ray:2.40.0-py312-cu118"
    ANYSCALE_RAY_2_40_0_PY312_CU121 = "anyscale/ray:2.40.0-py312-cu121"
    ANYSCALE_RAY_2_40_0_PY312_CU123 = "anyscale/ray:2.40.0-py312-cu123"
    ANYSCALE_RAY_2_40_0_PY39 = "anyscale/ray:2.40.0-py39"
    ANYSCALE_RAY_2_40_0_PY39_CU117 = "anyscale/ray:2.40.0-py39-cu117"
    ANYSCALE_RAY_2_40_0_PY39_CU118 = "anyscale/ray:2.40.0-py39-cu118"
    ANYSCALE_RAY_2_40_0_PY39_CU121 = "anyscale/ray:2.40.0-py39-cu121"
    ANYSCALE_RAY_2_40_0_PY39_CU123 = "anyscale/ray:2.40.0-py39-cu123"
    ANYSCALE_RAY_2_40_0_SLIM_PY310 = "anyscale/ray:2.40.0-slim-py310"
    ANYSCALE_RAY_2_40_0_SLIM_PY310_CU118 = "anyscale/ray:2.40.0-slim-py310-cu118"
    ANYSCALE_RAY_2_40_0_SLIM_PY310_CU121 = "anyscale/ray:2.40.0-slim-py310-cu121"
    ANYSCALE_RAY_2_40_0_SLIM_PY310_CU123 = "anyscale/ray:2.40.0-slim-py310-cu123"
    ANYSCALE_RAY_2_40_0_SLIM_PY311 = "anyscale/ray:2.40.0-slim-py311"
    ANYSCALE_RAY_2_40_0_SLIM_PY311_CU118 = "anyscale/ray:2.40.0-slim-py311-cu118"
    ANYSCALE_RAY_2_40_0_SLIM_PY311_CU121 = "anyscale/ray:2.40.0-slim-py311-cu121"
    ANYSCALE_RAY_2_40_0_SLIM_PY311_CU123 = "anyscale/ray:2.40.0-slim-py311-cu123"
    ANYSCALE_RAY_2_40_0_SLIM_PY312 = "anyscale/ray:2.40.0-slim-py312"
    ANYSCALE_RAY_2_40_0_SLIM_PY312_CU118 = "anyscale/ray:2.40.0-slim-py312-cu118"
    ANYSCALE_RAY_2_40_0_SLIM_PY312_CU121 = "anyscale/ray:2.40.0-slim-py312-cu121"
    ANYSCALE_RAY_2_40_0_SLIM_PY312_CU123 = "anyscale/ray:2.40.0-slim-py312-cu123"
    ANYSCALE_RAY_2_40_0_SLIM_PY39 = "anyscale/ray:2.40.0-slim-py39"
    ANYSCALE_RAY_2_40_0_SLIM_PY39_CU118 = "anyscale/ray:2.40.0-slim-py39-cu118"
    ANYSCALE_RAY_2_40_0_SLIM_PY39_CU121 = "anyscale/ray:2.40.0-slim-py39-cu121"
    ANYSCALE_RAY_2_40_0_SLIM_PY39_CU123 = "anyscale/ray:2.40.0-slim-py39-cu123"
    ANYSCALE_RAY_2_5_0_PY310 = "anyscale/ray:2.5.0-py310"
    ANYSCALE_RAY_2_5_0_PY310_CU101 = "anyscale/ray:2.5.0-py310-cu101"
    ANYSCALE_RAY_2_5_0_PY310_CU102 = "anyscale/ray:2.5.0-py310-cu102"
    ANYSCALE_RAY_2_5_0_PY310_CU110 = "anyscale/ray:2.5.0-py310-cu110"
    ANYSCALE_RAY_2_5_0_PY310_CU111 = "anyscale/ray:2.5.0-py310-cu111"
    ANYSCALE_RAY_2_5_0_PY310_CU112 = "anyscale/ray:2.5.0-py310-cu112"
    ANYSCALE_RAY_2_5_0_PY310_CU113 = "anyscale/ray:2.5.0-py310-cu113"
    ANYSCALE_RAY_2_5_0_PY310_CU116 = "anyscale/ray:2.5.0-py310-cu116"
    ANYSCALE_RAY_2_5_0_PY310_CU118 = "anyscale/ray:2.5.0-py310-cu118"
    ANYSCALE_RAY_2_5_0_PY37 = "anyscale/ray:2.5.0-py37"
    ANYSCALE_RAY_2_5_0_PY37_CU101 = "anyscale/ray:2.5.0-py37-cu101"
    ANYSCALE_RAY_2_5_0_PY37_CU102 = "anyscale/ray:2.5.0-py37-cu102"
    ANYSCALE_RAY_2_5_0_PY37_CU110 = "anyscale/ray:2.5.0-py37-cu110"
    ANYSCALE_RAY_2_5_0_PY37_CU111 = "anyscale/ray:2.5.0-py37-cu111"
    ANYSCALE_RAY_2_5_0_PY37_CU112 = "anyscale/ray:2.5.0-py37-cu112"
    ANYSCALE_RAY_2_5_0_PY37_CU113 = "anyscale/ray:2.5.0-py37-cu113"
    ANYSCALE_RAY_2_5_0_PY37_CU116 = "anyscale/ray:2.5.0-py37-cu116"
    ANYSCALE_RAY_2_5_0_PY37_CU118 = "anyscale/ray:2.5.0-py37-cu118"
    ANYSCALE_RAY_2_5_0_PY38 = "anyscale/ray:2.5.0-py38"
    ANYSCALE_RAY_2_5_0_PY38_CU101 = "anyscale/ray:2.5.0-py38-cu101"
    ANYSCALE_RAY_2_5_0_PY38_CU102 = "anyscale/ray:2.5.0-py38-cu102"
    ANYSCALE_RAY_2_5_0_PY38_CU110 = "anyscale/ray:2.5.0-py38-cu110"
    ANYSCALE_RAY_2_5_0_PY38_CU111 = "anyscale/ray:2.5.0-py38-cu111"
    ANYSCALE_RAY_2_5_0_PY38_CU112 = "anyscale/ray:2.5.0-py38-cu112"
    ANYSCALE_RAY_2_5_0_PY38_CU113 = "anyscale/ray:2.5.0-py38-cu113"
    ANYSCALE_RAY_2_5_0_PY38_CU116 = "anyscale/ray:2.5.0-py38-cu116"
    ANYSCALE_RAY_2_5_0_PY38_CU118 = "anyscale/ray:2.5.0-py38-cu118"
    ANYSCALE_RAY_2_5_0_PY39 = "anyscale/ray:2.5.0-py39"
    ANYSCALE_RAY_2_5_0_PY39_CU101 = "anyscale/ray:2.5.0-py39-cu101"
    ANYSCALE_RAY_2_5_0_PY39_CU102 = "anyscale/ray:2.5.0-py39-cu102"
    ANYSCALE_RAY_2_5_0_PY39_CU110 = "anyscale/ray:2.5.0-py39-cu110"
    ANYSCALE_RAY_2_5_0_PY39_CU111 = "anyscale/ray:2.5.0-py39-cu111"
    ANYSCALE_RAY_2_5_0_PY39_CU112 = "anyscale/ray:2.5.0-py39-cu112"
    ANYSCALE_RAY_2_5_0_PY39_CU113 = "anyscale/ray:2.5.0-py39-cu113"
    ANYSCALE_RAY_2_5_0_PY39_CU116 = "anyscale/ray:2.5.0-py39-cu116"
    ANYSCALE_RAY_2_5_0_PY39_CU118 = "anyscale/ray:2.5.0-py39-cu118"
    ANYSCALE_RAY_2_5_1_PY310 = "anyscale/ray:2.5.1-py310"
    ANYSCALE_RAY_2_5_1_PY310_CU101 = "anyscale/ray:2.5.1-py310-cu101"
    ANYSCALE_RAY_2_5_1_PY310_CU102 = "anyscale/ray:2.5.1-py310-cu102"
    ANYSCALE_RAY_2_5_1_PY310_CU110 = "anyscale/ray:2.5.1-py310-cu110"
    ANYSCALE_RAY_2_5_1_PY310_CU111 = "anyscale/ray:2.5.1-py310-cu111"
    ANYSCALE_RAY_2_5_1_PY310_CU112 = "anyscale/ray:2.5.1-py310-cu112"
    ANYSCALE_RAY_2_5_1_PY310_CU113 = "anyscale/ray:2.5.1-py310-cu113"
    ANYSCALE_RAY_2_5_1_PY310_CU116 = "anyscale/ray:2.5.1-py310-cu116"
    ANYSCALE_RAY_2_5_1_PY310_CU118 = "anyscale/ray:2.5.1-py310-cu118"
    ANYSCALE_RAY_2_5_1_PY37 = "anyscale/ray:2.5.1-py37"
    ANYSCALE_RAY_2_5_1_PY37_CU101 = "anyscale/ray:2.5.1-py37-cu101"
    ANYSCALE_RAY_2_5_1_PY37_CU102 = "anyscale/ray:2.5.1-py37-cu102"
    ANYSCALE_RAY_2_5_1_PY37_CU110 = "anyscale/ray:2.5.1-py37-cu110"
    ANYSCALE_RAY_2_5_1_PY37_CU111 = "anyscale/ray:2.5.1-py37-cu111"
    ANYSCALE_RAY_2_5_1_PY37_CU112 = "anyscale/ray:2.5.1-py37-cu112"
    ANYSCALE_RAY_2_5_1_PY37_CU113 = "anyscale/ray:2.5.1-py37-cu113"
    ANYSCALE_RAY_2_5_1_PY37_CU116 = "anyscale/ray:2.5.1-py37-cu116"
    ANYSCALE_RAY_2_5_1_PY37_CU118 = "anyscale/ray:2.5.1-py37-cu118"
    ANYSCALE_RAY_2_5_1_PY38 = "anyscale/ray:2.5.1-py38"
    ANYSCALE_RAY_2_5_1_PY38_CU101 = "anyscale/ray:2.5.1-py38-cu101"
    ANYSCALE_RAY_2_5_1_PY38_CU102 = "anyscale/ray:2.5.1-py38-cu102"
    ANYSCALE_RAY_2_5_1_PY38_CU110 = "anyscale/ray:2.5.1-py38-cu110"
    ANYSCALE_RAY_2_5_1_PY38_CU111 = "anyscale/ray:2.5.1-py38-cu111"
    ANYSCALE_RAY_2_5_1_PY38_CU112 = "anyscale/ray:2.5.1-py38-cu112"
    ANYSCALE_RAY_2_5_1_PY38_CU113 = "anyscale/ray:2.5.1-py38-cu113"
    ANYSCALE_RAY_2_5_1_PY38_CU116 = "anyscale/ray:2.5.1-py38-cu116"
    ANYSCALE_RAY_2_5_1_PY38_CU118 = "anyscale/ray:2.5.1-py38-cu118"
    ANYSCALE_RAY_2_5_1_PY39 = "anyscale/ray:2.5.1-py39"
    ANYSCALE_RAY_2_5_1_PY39_CU101 = "anyscale/ray:2.5.1-py39-cu101"
    ANYSCALE_RAY_2_5_1_PY39_CU102 = "anyscale/ray:2.5.1-py39-cu102"
    ANYSCALE_RAY_2_5_1_PY39_CU110 = "anyscale/ray:2.5.1-py39-cu110"
    ANYSCALE_RAY_2_5_1_PY39_CU111 = "anyscale/ray:2.5.1-py39-cu111"
    ANYSCALE_RAY_2_5_1_PY39_CU112 = "anyscale/ray:2.5.1-py39-cu112"
    ANYSCALE_RAY_2_5_1_PY39_CU113 = "anyscale/ray:2.5.1-py39-cu113"
    ANYSCALE_RAY_2_5_1_PY39_CU116 = "anyscale/ray:2.5.1-py39-cu116"
    ANYSCALE_RAY_2_5_1_PY39_CU118 = "anyscale/ray:2.5.1-py39-cu118"
    ANYSCALE_RAY_2_6_0_PY310 = "anyscale/ray:2.6.0-py310"
    ANYSCALE_RAY_2_6_0_PY310_CU115 = "anyscale/ray:2.6.0-py310-cu115"
    ANYSCALE_RAY_2_6_0_PY310_CU116 = "anyscale/ray:2.6.0-py310-cu116"
    ANYSCALE_RAY_2_6_0_PY310_CU117 = "anyscale/ray:2.6.0-py310-cu117"
    ANYSCALE_RAY_2_6_0_PY310_CU118 = "anyscale/ray:2.6.0-py310-cu118"
    ANYSCALE_RAY_2_6_0_PY37 = "anyscale/ray:2.6.0-py37"
    ANYSCALE_RAY_2_6_0_PY37_CU115 = "anyscale/ray:2.6.0-py37-cu115"
    ANYSCALE_RAY_2_6_0_PY37_CU116 = "anyscale/ray:2.6.0-py37-cu116"
    ANYSCALE_RAY_2_6_0_PY37_CU117 = "anyscale/ray:2.6.0-py37-cu117"
    ANYSCALE_RAY_2_6_0_PY37_CU118 = "anyscale/ray:2.6.0-py37-cu118"
    ANYSCALE_RAY_2_6_0_PY38 = "anyscale/ray:2.6.0-py38"
    ANYSCALE_RAY_2_6_0_PY38_CU115 = "anyscale/ray:2.6.0-py38-cu115"
    ANYSCALE_RAY_2_6_0_PY38_CU116 = "anyscale/ray:2.6.0-py38-cu116"
    ANYSCALE_RAY_2_6_0_PY38_CU117 = "anyscale/ray:2.6.0-py38-cu117"
    ANYSCALE_RAY_2_6_0_PY38_CU118 = "anyscale/ray:2.6.0-py38-cu118"
    ANYSCALE_RAY_2_6_0_PY39 = "anyscale/ray:2.6.0-py39"
    ANYSCALE_RAY_2_6_0_PY39_CU115 = "anyscale/ray:2.6.0-py39-cu115"
    ANYSCALE_RAY_2_6_0_PY39_CU116 = "anyscale/ray:2.6.0-py39-cu116"
    ANYSCALE_RAY_2_6_0_PY39_CU117 = "anyscale/ray:2.6.0-py39-cu117"
    ANYSCALE_RAY_2_6_0_PY39_CU118 = "anyscale/ray:2.6.0-py39-cu118"
    ANYSCALE_RAY_2_6_1_PY310 = "anyscale/ray:2.6.1-py310"
    ANYSCALE_RAY_2_6_1_PY310_CU115 = "anyscale/ray:2.6.1-py310-cu115"
    ANYSCALE_RAY_2_6_1_PY310_CU116 = "anyscale/ray:2.6.1-py310-cu116"
    ANYSCALE_RAY_2_6_1_PY310_CU117 = "anyscale/ray:2.6.1-py310-cu117"
    ANYSCALE_RAY_2_6_1_PY310_CU118 = "anyscale/ray:2.6.1-py310-cu118"
    ANYSCALE_RAY_2_6_1_PY37 = "anyscale/ray:2.6.1-py37"
    ANYSCALE_RAY_2_6_1_PY37_CU115 = "anyscale/ray:2.6.1-py37-cu115"
    ANYSCALE_RAY_2_6_1_PY37_CU116 = "anyscale/ray:2.6.1-py37-cu116"
    ANYSCALE_RAY_2_6_1_PY37_CU117 = "anyscale/ray:2.6.1-py37-cu117"
    ANYSCALE_RAY_2_6_1_PY37_CU118 = "anyscale/ray:2.6.1-py37-cu118"
    ANYSCALE_RAY_2_6_1_PY38 = "anyscale/ray:2.6.1-py38"
    ANYSCALE_RAY_2_6_1_PY38_CU115 = "anyscale/ray:2.6.1-py38-cu115"
    ANYSCALE_RAY_2_6_1_PY38_CU116 = "anyscale/ray:2.6.1-py38-cu116"
    ANYSCALE_RAY_2_6_1_PY38_CU117 = "anyscale/ray:2.6.1-py38-cu117"
    ANYSCALE_RAY_2_6_1_PY38_CU118 = "anyscale/ray:2.6.1-py38-cu118"
    ANYSCALE_RAY_2_6_1_PY39 = "anyscale/ray:2.6.1-py39"
    ANYSCALE_RAY_2_6_1_PY39_CU115 = "anyscale/ray:2.6.1-py39-cu115"
    ANYSCALE_RAY_2_6_1_PY39_CU116 = "anyscale/ray:2.6.1-py39-cu116"
    ANYSCALE_RAY_2_6_1_PY39_CU117 = "anyscale/ray:2.6.1-py39-cu117"
    ANYSCALE_RAY_2_6_1_PY39_CU118 = "anyscale/ray:2.6.1-py39-cu118"
    ANYSCALE_RAY_2_6_2_PY310 = "anyscale/ray:2.6.2-py310"
    ANYSCALE_RAY_2_6_2_PY310_CU115 = "anyscale/ray:2.6.2-py310-cu115"
    ANYSCALE_RAY_2_6_2_PY310_CU116 = "anyscale/ray:2.6.2-py310-cu116"
    ANYSCALE_RAY_2_6_2_PY310_CU117 = "anyscale/ray:2.6.2-py310-cu117"
    ANYSCALE_RAY_2_6_2_PY310_CU118 = "anyscale/ray:2.6.2-py310-cu118"
    ANYSCALE_RAY_2_6_2_PY37 = "anyscale/ray:2.6.2-py37"
    ANYSCALE_RAY_2_6_2_PY37_CU115 = "anyscale/ray:2.6.2-py37-cu115"
    ANYSCALE_RAY_2_6_2_PY37_CU116 = "anyscale/ray:2.6.2-py37-cu116"
    ANYSCALE_RAY_2_6_2_PY37_CU117 = "anyscale/ray:2.6.2-py37-cu117"
    ANYSCALE_RAY_2_6_2_PY37_CU118 = "anyscale/ray:2.6.2-py37-cu118"
    ANYSCALE_RAY_2_6_2_PY38 = "anyscale/ray:2.6.2-py38"
    ANYSCALE_RAY_2_6_2_PY38_CU115 = "anyscale/ray:2.6.2-py38-cu115"
    ANYSCALE_RAY_2_6_2_PY38_CU116 = "anyscale/ray:2.6.2-py38-cu116"
    ANYSCALE_RAY_2_6_2_PY38_CU117 = "anyscale/ray:2.6.2-py38-cu117"
    ANYSCALE_RAY_2_6_2_PY38_CU118 = "anyscale/ray:2.6.2-py38-cu118"
    ANYSCALE_RAY_2_6_2_PY39 = "anyscale/ray:2.6.2-py39"
    ANYSCALE_RAY_2_6_2_PY39_CU115 = "anyscale/ray:2.6.2-py39-cu115"
    ANYSCALE_RAY_2_6_2_PY39_CU116 = "anyscale/ray:2.6.2-py39-cu116"
    ANYSCALE_RAY_2_6_2_PY39_CU117 = "anyscale/ray:2.6.2-py39-cu117"
    ANYSCALE_RAY_2_6_2_PY39_CU118 = "anyscale/ray:2.6.2-py39-cu118"
    ANYSCALE_RAY_2_6_3_PY310 = "anyscale/ray:2.6.3-py310"
    ANYSCALE_RAY_2_6_3_PY310_CU115 = "anyscale/ray:2.6.3-py310-cu115"
    ANYSCALE_RAY_2_6_3_PY310_CU116 = "anyscale/ray:2.6.3-py310-cu116"
    ANYSCALE_RAY_2_6_3_PY310_CU117 = "anyscale/ray:2.6.3-py310-cu117"
    ANYSCALE_RAY_2_6_3_PY310_CU118 = "anyscale/ray:2.6.3-py310-cu118"
    ANYSCALE_RAY_2_6_3_PY37 = "anyscale/ray:2.6.3-py37"
    ANYSCALE_RAY_2_6_3_PY37_CU115 = "anyscale/ray:2.6.3-py37-cu115"
    ANYSCALE_RAY_2_6_3_PY37_CU116 = "anyscale/ray:2.6.3-py37-cu116"
    ANYSCALE_RAY_2_6_3_PY37_CU117 = "anyscale/ray:2.6.3-py37-cu117"
    ANYSCALE_RAY_2_6_3_PY37_CU118 = "anyscale/ray:2.6.3-py37-cu118"
    ANYSCALE_RAY_2_6_3_PY38 = "anyscale/ray:2.6.3-py38"
    ANYSCALE_RAY_2_6_3_PY38_CU115 = "anyscale/ray:2.6.3-py38-cu115"
    ANYSCALE_RAY_2_6_3_PY38_CU116 = "anyscale/ray:2.6.3-py38-cu116"
    ANYSCALE_RAY_2_6_3_PY38_CU117 = "anyscale/ray:2.6.3-py38-cu117"
    ANYSCALE_RAY_2_6_3_PY38_CU118 = "anyscale/ray:2.6.3-py38-cu118"
    ANYSCALE_RAY_2_6_3_PY39 = "anyscale/ray:2.6.3-py39"
    ANYSCALE_RAY_2_6_3_PY39_CU115 = "anyscale/ray:2.6.3-py39-cu115"
    ANYSCALE_RAY_2_6_3_PY39_CU116 = "anyscale/ray:2.6.3-py39-cu116"
    ANYSCALE_RAY_2_6_3_PY39_CU117 = "anyscale/ray:2.6.3-py39-cu117"
    ANYSCALE_RAY_2_6_3_PY39_CU118 = "anyscale/ray:2.6.3-py39-cu118"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY310 = "anyscale/ray:2.7.0optimized-py310"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY310_CU115 = "anyscale/ray:2.7.0optimized-py310-cu115"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY310_CU116 = "anyscale/ray:2.7.0optimized-py310-cu116"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY310_CU117 = "anyscale/ray:2.7.0optimized-py310-cu117"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY310_CU118 = "anyscale/ray:2.7.0optimized-py310-cu118"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY310_CU121 = "anyscale/ray:2.7.0optimized-py310-cu121"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY311 = "anyscale/ray:2.7.0optimized-py311"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY311_CU115 = "anyscale/ray:2.7.0optimized-py311-cu115"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY311_CU116 = "anyscale/ray:2.7.0optimized-py311-cu116"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY311_CU117 = "anyscale/ray:2.7.0optimized-py311-cu117"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY311_CU118 = "anyscale/ray:2.7.0optimized-py311-cu118"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY311_CU121 = "anyscale/ray:2.7.0optimized-py311-cu121"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY37 = "anyscale/ray:2.7.0optimized-py37"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY37_CU115 = "anyscale/ray:2.7.0optimized-py37-cu115"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY37_CU116 = "anyscale/ray:2.7.0optimized-py37-cu116"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY37_CU117 = "anyscale/ray:2.7.0optimized-py37-cu117"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY37_CU118 = "anyscale/ray:2.7.0optimized-py37-cu118"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY37_CU121 = "anyscale/ray:2.7.0optimized-py37-cu121"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY38 = "anyscale/ray:2.7.0optimized-py38"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY38_CU115 = "anyscale/ray:2.7.0optimized-py38-cu115"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY38_CU116 = "anyscale/ray:2.7.0optimized-py38-cu116"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY38_CU117 = "anyscale/ray:2.7.0optimized-py38-cu117"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY38_CU118 = "anyscale/ray:2.7.0optimized-py38-cu118"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY38_CU121 = "anyscale/ray:2.7.0optimized-py38-cu121"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY39 = "anyscale/ray:2.7.0optimized-py39"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY39_CU115 = "anyscale/ray:2.7.0optimized-py39-cu115"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY39_CU116 = "anyscale/ray:2.7.0optimized-py39-cu116"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY39_CU117 = "anyscale/ray:2.7.0optimized-py39-cu117"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY39_CU118 = "anyscale/ray:2.7.0optimized-py39-cu118"
    ANYSCALE_RAY_2_7_0OPTIMIZED_PY39_CU121 = "anyscale/ray:2.7.0optimized-py39-cu121"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY310 = "anyscale/ray:2.7.1optimized-py310"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY310_CU115 = "anyscale/ray:2.7.1optimized-py310-cu115"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY310_CU116 = "anyscale/ray:2.7.1optimized-py310-cu116"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY310_CU117 = "anyscale/ray:2.7.1optimized-py310-cu117"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY310_CU118 = "anyscale/ray:2.7.1optimized-py310-cu118"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY310_CU121 = "anyscale/ray:2.7.1optimized-py310-cu121"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY311 = "anyscale/ray:2.7.1optimized-py311"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY311_CU115 = "anyscale/ray:2.7.1optimized-py311-cu115"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY311_CU116 = "anyscale/ray:2.7.1optimized-py311-cu116"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY311_CU117 = "anyscale/ray:2.7.1optimized-py311-cu117"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY311_CU118 = "anyscale/ray:2.7.1optimized-py311-cu118"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY311_CU121 = "anyscale/ray:2.7.1optimized-py311-cu121"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY37 = "anyscale/ray:2.7.1optimized-py37"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY37_CU115 = "anyscale/ray:2.7.1optimized-py37-cu115"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY37_CU116 = "anyscale/ray:2.7.1optimized-py37-cu116"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY37_CU117 = "anyscale/ray:2.7.1optimized-py37-cu117"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY37_CU118 = "anyscale/ray:2.7.1optimized-py37-cu118"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY37_CU121 = "anyscale/ray:2.7.1optimized-py37-cu121"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY38 = "anyscale/ray:2.7.1optimized-py38"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY38_CU115 = "anyscale/ray:2.7.1optimized-py38-cu115"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY38_CU116 = "anyscale/ray:2.7.1optimized-py38-cu116"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY38_CU117 = "anyscale/ray:2.7.1optimized-py38-cu117"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY38_CU118 = "anyscale/ray:2.7.1optimized-py38-cu118"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY38_CU121 = "anyscale/ray:2.7.1optimized-py38-cu121"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY39 = "anyscale/ray:2.7.1optimized-py39"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY39_CU115 = "anyscale/ray:2.7.1optimized-py39-cu115"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY39_CU116 = "anyscale/ray:2.7.1optimized-py39-cu116"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY39_CU117 = "anyscale/ray:2.7.1optimized-py39-cu117"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY39_CU118 = "anyscale/ray:2.7.1optimized-py39-cu118"
    ANYSCALE_RAY_2_7_1OPTIMIZED_PY39_CU121 = "anyscale/ray:2.7.1optimized-py39-cu121"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY310 = "anyscale/ray:2.7.2optimized-py310"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY310_CU115 = "anyscale/ray:2.7.2optimized-py310-cu115"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY310_CU116 = "anyscale/ray:2.7.2optimized-py310-cu116"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY310_CU117 = "anyscale/ray:2.7.2optimized-py310-cu117"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY310_CU118 = "anyscale/ray:2.7.2optimized-py310-cu118"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY310_CU121 = "anyscale/ray:2.7.2optimized-py310-cu121"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY311 = "anyscale/ray:2.7.2optimized-py311"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY311_CU115 = "anyscale/ray:2.7.2optimized-py311-cu115"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY311_CU116 = "anyscale/ray:2.7.2optimized-py311-cu116"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY311_CU117 = "anyscale/ray:2.7.2optimized-py311-cu117"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY311_CU118 = "anyscale/ray:2.7.2optimized-py311-cu118"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY311_CU121 = "anyscale/ray:2.7.2optimized-py311-cu121"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY37 = "anyscale/ray:2.7.2optimized-py37"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY37_CU115 = "anyscale/ray:2.7.2optimized-py37-cu115"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY37_CU116 = "anyscale/ray:2.7.2optimized-py37-cu116"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY37_CU117 = "anyscale/ray:2.7.2optimized-py37-cu117"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY37_CU118 = "anyscale/ray:2.7.2optimized-py37-cu118"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY37_CU121 = "anyscale/ray:2.7.2optimized-py37-cu121"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY38 = "anyscale/ray:2.7.2optimized-py38"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY38_CU115 = "anyscale/ray:2.7.2optimized-py38-cu115"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY38_CU116 = "anyscale/ray:2.7.2optimized-py38-cu116"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY38_CU117 = "anyscale/ray:2.7.2optimized-py38-cu117"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY38_CU118 = "anyscale/ray:2.7.2optimized-py38-cu118"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY38_CU121 = "anyscale/ray:2.7.2optimized-py38-cu121"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY39 = "anyscale/ray:2.7.2optimized-py39"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY39_CU115 = "anyscale/ray:2.7.2optimized-py39-cu115"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY39_CU116 = "anyscale/ray:2.7.2optimized-py39-cu116"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY39_CU117 = "anyscale/ray:2.7.2optimized-py39-cu117"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY39_CU118 = "anyscale/ray:2.7.2optimized-py39-cu118"
    ANYSCALE_RAY_2_7_2OPTIMIZED_PY39_CU121 = "anyscale/ray:2.7.2optimized-py39-cu121"
    ANYSCALE_RAY_2_8_0_PY310 = "anyscale/ray:2.8.0-py310"
    ANYSCALE_RAY_2_8_0_PY310_CU115 = "anyscale/ray:2.8.0-py310-cu115"
    ANYSCALE_RAY_2_8_0_PY310_CU116 = "anyscale/ray:2.8.0-py310-cu116"
    ANYSCALE_RAY_2_8_0_PY310_CU117 = "anyscale/ray:2.8.0-py310-cu117"
    ANYSCALE_RAY_2_8_0_PY310_CU118 = "anyscale/ray:2.8.0-py310-cu118"
    ANYSCALE_RAY_2_8_0_PY310_CU121 = "anyscale/ray:2.8.0-py310-cu121"
    ANYSCALE_RAY_2_8_0_PY311 = "anyscale/ray:2.8.0-py311"
    ANYSCALE_RAY_2_8_0_PY311_CU115 = "anyscale/ray:2.8.0-py311-cu115"
    ANYSCALE_RAY_2_8_0_PY311_CU116 = "anyscale/ray:2.8.0-py311-cu116"
    ANYSCALE_RAY_2_8_0_PY311_CU117 = "anyscale/ray:2.8.0-py311-cu117"
    ANYSCALE_RAY_2_8_0_PY311_CU118 = "anyscale/ray:2.8.0-py311-cu118"
    ANYSCALE_RAY_2_8_0_PY311_CU121 = "anyscale/ray:2.8.0-py311-cu121"
    ANYSCALE_RAY_2_8_0_PY38 = "anyscale/ray:2.8.0-py38"
    ANYSCALE_RAY_2_8_0_PY38_CU115 = "anyscale/ray:2.8.0-py38-cu115"
    ANYSCALE_RAY_2_8_0_PY38_CU116 = "anyscale/ray:2.8.0-py38-cu116"
    ANYSCALE_RAY_2_8_0_PY38_CU117 = "anyscale/ray:2.8.0-py38-cu117"
    ANYSCALE_RAY_2_8_0_PY38_CU118 = "anyscale/ray:2.8.0-py38-cu118"
    ANYSCALE_RAY_2_8_0_PY38_CU121 = "anyscale/ray:2.8.0-py38-cu121"
    ANYSCALE_RAY_2_8_0_PY39 = "anyscale/ray:2.8.0-py39"
    ANYSCALE_RAY_2_8_0_PY39_CU115 = "anyscale/ray:2.8.0-py39-cu115"
    ANYSCALE_RAY_2_8_0_PY39_CU116 = "anyscale/ray:2.8.0-py39-cu116"
    ANYSCALE_RAY_2_8_0_PY39_CU117 = "anyscale/ray:2.8.0-py39-cu117"
    ANYSCALE_RAY_2_8_0_PY39_CU118 = "anyscale/ray:2.8.0-py39-cu118"
    ANYSCALE_RAY_2_8_0_PY39_CU121 = "anyscale/ray:2.8.0-py39-cu121"
    ANYSCALE_RAY_2_8_1_PY310 = "anyscale/ray:2.8.1-py310"
    ANYSCALE_RAY_2_8_1_PY310_CU115 = "anyscale/ray:2.8.1-py310-cu115"
    ANYSCALE_RAY_2_8_1_PY310_CU116 = "anyscale/ray:2.8.1-py310-cu116"
    ANYSCALE_RAY_2_8_1_PY310_CU117 = "anyscale/ray:2.8.1-py310-cu117"
    ANYSCALE_RAY_2_8_1_PY310_CU118 = "anyscale/ray:2.8.1-py310-cu118"
    ANYSCALE_RAY_2_8_1_PY310_CU121 = "anyscale/ray:2.8.1-py310-cu121"
    ANYSCALE_RAY_2_8_1_PY311 = "anyscale/ray:2.8.1-py311"
    ANYSCALE_RAY_2_8_1_PY311_CU115 = "anyscale/ray:2.8.1-py311-cu115"
    ANYSCALE_RAY_2_8_1_PY311_CU116 = "anyscale/ray:2.8.1-py311-cu116"
    ANYSCALE_RAY_2_8_1_PY311_CU117 = "anyscale/ray:2.8.1-py311-cu117"
    ANYSCALE_RAY_2_8_1_PY311_CU118 = "anyscale/ray:2.8.1-py311-cu118"
    ANYSCALE_RAY_2_8_1_PY311_CU121 = "anyscale/ray:2.8.1-py311-cu121"
    ANYSCALE_RAY_2_8_1_PY38 = "anyscale/ray:2.8.1-py38"
    ANYSCALE_RAY_2_8_1_PY38_CU115 = "anyscale/ray:2.8.1-py38-cu115"
    ANYSCALE_RAY_2_8_1_PY38_CU116 = "anyscale/ray:2.8.1-py38-cu116"
    ANYSCALE_RAY_2_8_1_PY38_CU117 = "anyscale/ray:2.8.1-py38-cu117"
    ANYSCALE_RAY_2_8_1_PY38_CU118 = "anyscale/ray:2.8.1-py38-cu118"
    ANYSCALE_RAY_2_8_1_PY38_CU121 = "anyscale/ray:2.8.1-py38-cu121"
    ANYSCALE_RAY_2_8_1_PY39 = "anyscale/ray:2.8.1-py39"
    ANYSCALE_RAY_2_8_1_PY39_CU115 = "anyscale/ray:2.8.1-py39-cu115"
    ANYSCALE_RAY_2_8_1_PY39_CU116 = "anyscale/ray:2.8.1-py39-cu116"
    ANYSCALE_RAY_2_8_1_PY39_CU117 = "anyscale/ray:2.8.1-py39-cu117"
    ANYSCALE_RAY_2_8_1_PY39_CU118 = "anyscale/ray:2.8.1-py39-cu118"
    ANYSCALE_RAY_2_8_1_PY39_CU121 = "anyscale/ray:2.8.1-py39-cu121"
    ANYSCALE_RAY_2_9_0_PY310 = "anyscale/ray:2.9.0-py310"
    ANYSCALE_RAY_2_9_0_PY310_CU115 = "anyscale/ray:2.9.0-py310-cu115"
    ANYSCALE_RAY_2_9_0_PY310_CU116 = "anyscale/ray:2.9.0-py310-cu116"
    ANYSCALE_RAY_2_9_0_PY310_CU117 = "anyscale/ray:2.9.0-py310-cu117"
    ANYSCALE_RAY_2_9_0_PY310_CU118 = "anyscale/ray:2.9.0-py310-cu118"
    ANYSCALE_RAY_2_9_0_PY310_CU121 = "anyscale/ray:2.9.0-py310-cu121"
    ANYSCALE_RAY_2_9_0_PY311 = "anyscale/ray:2.9.0-py311"
    ANYSCALE_RAY_2_9_0_PY311_CU115 = "anyscale/ray:2.9.0-py311-cu115"
    ANYSCALE_RAY_2_9_0_PY311_CU116 = "anyscale/ray:2.9.0-py311-cu116"
    ANYSCALE_RAY_2_9_0_PY311_CU117 = "anyscale/ray:2.9.0-py311-cu117"
    ANYSCALE_RAY_2_9_0_PY311_CU118 = "anyscale/ray:2.9.0-py311-cu118"
    ANYSCALE_RAY_2_9_0_PY311_CU121 = "anyscale/ray:2.9.0-py311-cu121"
    ANYSCALE_RAY_2_9_0_PY38 = "anyscale/ray:2.9.0-py38"
    ANYSCALE_RAY_2_9_0_PY38_CU115 = "anyscale/ray:2.9.0-py38-cu115"
    ANYSCALE_RAY_2_9_0_PY38_CU116 = "anyscale/ray:2.9.0-py38-cu116"
    ANYSCALE_RAY_2_9_0_PY38_CU117 = "anyscale/ray:2.9.0-py38-cu117"
    ANYSCALE_RAY_2_9_0_PY38_CU118 = "anyscale/ray:2.9.0-py38-cu118"
    ANYSCALE_RAY_2_9_0_PY38_CU121 = "anyscale/ray:2.9.0-py38-cu121"
    ANYSCALE_RAY_2_9_0_PY39 = "anyscale/ray:2.9.0-py39"
    ANYSCALE_RAY_2_9_0_PY39_CU115 = "anyscale/ray:2.9.0-py39-cu115"
    ANYSCALE_RAY_2_9_0_PY39_CU116 = "anyscale/ray:2.9.0-py39-cu116"
    ANYSCALE_RAY_2_9_0_PY39_CU117 = "anyscale/ray:2.9.0-py39-cu117"
    ANYSCALE_RAY_2_9_0_PY39_CU118 = "anyscale/ray:2.9.0-py39-cu118"
    ANYSCALE_RAY_2_9_0_PY39_CU121 = "anyscale/ray:2.9.0-py39-cu121"
    ANYSCALE_RAY_2_9_1_PY310 = "anyscale/ray:2.9.1-py310"
    ANYSCALE_RAY_2_9_1_PY310_CU115 = "anyscale/ray:2.9.1-py310-cu115"
    ANYSCALE_RAY_2_9_1_PY310_CU116 = "anyscale/ray:2.9.1-py310-cu116"
    ANYSCALE_RAY_2_9_1_PY310_CU117 = "anyscale/ray:2.9.1-py310-cu117"
    ANYSCALE_RAY_2_9_1_PY310_CU118 = "anyscale/ray:2.9.1-py310-cu118"
    ANYSCALE_RAY_2_9_1_PY310_CU121 = "anyscale/ray:2.9.1-py310-cu121"
    ANYSCALE_RAY_2_9_1_PY311 = "anyscale/ray:2.9.1-py311"
    ANYSCALE_RAY_2_9_1_PY311_CU115 = "anyscale/ray:2.9.1-py311-cu115"
    ANYSCALE_RAY_2_9_1_PY311_CU116 = "anyscale/ray:2.9.1-py311-cu116"
    ANYSCALE_RAY_2_9_1_PY311_CU117 = "anyscale/ray:2.9.1-py311-cu117"
    ANYSCALE_RAY_2_9_1_PY311_CU118 = "anyscale/ray:2.9.1-py311-cu118"
    ANYSCALE_RAY_2_9_1_PY311_CU121 = "anyscale/ray:2.9.1-py311-cu121"
    ANYSCALE_RAY_2_9_1_PY38 = "anyscale/ray:2.9.1-py38"
    ANYSCALE_RAY_2_9_1_PY38_CU115 = "anyscale/ray:2.9.1-py38-cu115"
    ANYSCALE_RAY_2_9_1_PY38_CU116 = "anyscale/ray:2.9.1-py38-cu116"
    ANYSCALE_RAY_2_9_1_PY38_CU117 = "anyscale/ray:2.9.1-py38-cu117"
    ANYSCALE_RAY_2_9_1_PY38_CU118 = "anyscale/ray:2.9.1-py38-cu118"
    ANYSCALE_RAY_2_9_1_PY38_CU121 = "anyscale/ray:2.9.1-py38-cu121"
    ANYSCALE_RAY_2_9_1_PY39 = "anyscale/ray:2.9.1-py39"
    ANYSCALE_RAY_2_9_1_PY39_CU115 = "anyscale/ray:2.9.1-py39-cu115"
    ANYSCALE_RAY_2_9_1_PY39_CU116 = "anyscale/ray:2.9.1-py39-cu116"
    ANYSCALE_RAY_2_9_1_PY39_CU117 = "anyscale/ray:2.9.1-py39-cu117"
    ANYSCALE_RAY_2_9_1_PY39_CU118 = "anyscale/ray:2.9.1-py39-cu118"
    ANYSCALE_RAY_2_9_1_PY39_CU121 = "anyscale/ray:2.9.1-py39-cu121"
    ANYSCALE_RAY_2_9_2_PY310 = "anyscale/ray:2.9.2-py310"
    ANYSCALE_RAY_2_9_2_PY310_CU115 = "anyscale/ray:2.9.2-py310-cu115"
    ANYSCALE_RAY_2_9_2_PY310_CU116 = "anyscale/ray:2.9.2-py310-cu116"
    ANYSCALE_RAY_2_9_2_PY310_CU117 = "anyscale/ray:2.9.2-py310-cu117"
    ANYSCALE_RAY_2_9_2_PY310_CU118 = "anyscale/ray:2.9.2-py310-cu118"
    ANYSCALE_RAY_2_9_2_PY310_CU121 = "anyscale/ray:2.9.2-py310-cu121"
    ANYSCALE_RAY_2_9_2_PY311 = "anyscale/ray:2.9.2-py311"
    ANYSCALE_RAY_2_9_2_PY311_CU115 = "anyscale/ray:2.9.2-py311-cu115"
    ANYSCALE_RAY_2_9_2_PY311_CU116 = "anyscale/ray:2.9.2-py311-cu116"
    ANYSCALE_RAY_2_9_2_PY311_CU117 = "anyscale/ray:2.9.2-py311-cu117"
    ANYSCALE_RAY_2_9_2_PY311_CU118 = "anyscale/ray:2.9.2-py311-cu118"
    ANYSCALE_RAY_2_9_2_PY311_CU121 = "anyscale/ray:2.9.2-py311-cu121"
    ANYSCALE_RAY_2_9_2_PY38 = "anyscale/ray:2.9.2-py38"
    ANYSCALE_RAY_2_9_2_PY38_CU115 = "anyscale/ray:2.9.2-py38-cu115"
    ANYSCALE_RAY_2_9_2_PY38_CU116 = "anyscale/ray:2.9.2-py38-cu116"
    ANYSCALE_RAY_2_9_2_PY38_CU117 = "anyscale/ray:2.9.2-py38-cu117"
    ANYSCALE_RAY_2_9_2_PY38_CU118 = "anyscale/ray:2.9.2-py38-cu118"
    ANYSCALE_RAY_2_9_2_PY38_CU121 = "anyscale/ray:2.9.2-py38-cu121"
    ANYSCALE_RAY_2_9_2_PY39 = "anyscale/ray:2.9.2-py39"
    ANYSCALE_RAY_2_9_2_PY39_CU115 = "anyscale/ray:2.9.2-py39-cu115"
    ANYSCALE_RAY_2_9_2_PY39_CU116 = "anyscale/ray:2.9.2-py39-cu116"
    ANYSCALE_RAY_2_9_2_PY39_CU117 = "anyscale/ray:2.9.2-py39-cu117"
    ANYSCALE_RAY_2_9_2_PY39_CU118 = "anyscale/ray:2.9.2-py39-cu118"
    ANYSCALE_RAY_2_9_2_PY39_CU121 = "anyscale/ray:2.9.2-py39-cu121"
    ANYSCALE_RAY_2_9_3_PY310 = "anyscale/ray:2.9.3-py310"
    ANYSCALE_RAY_2_9_3_PY310_CU115 = "anyscale/ray:2.9.3-py310-cu115"
    ANYSCALE_RAY_2_9_3_PY310_CU116 = "anyscale/ray:2.9.3-py310-cu116"
    ANYSCALE_RAY_2_9_3_PY310_CU117 = "anyscale/ray:2.9.3-py310-cu117"
    ANYSCALE_RAY_2_9_3_PY310_CU118 = "anyscale/ray:2.9.3-py310-cu118"
    ANYSCALE_RAY_2_9_3_PY310_CU121 = "anyscale/ray:2.9.3-py310-cu121"
    ANYSCALE_RAY_2_9_3_PY311 = "anyscale/ray:2.9.3-py311"
    ANYSCALE_RAY_2_9_3_PY311_CU115 = "anyscale/ray:2.9.3-py311-cu115"
    ANYSCALE_RAY_2_9_3_PY311_CU116 = "anyscale/ray:2.9.3-py311-cu116"
    ANYSCALE_RAY_2_9_3_PY311_CU117 = "anyscale/ray:2.9.3-py311-cu117"
    ANYSCALE_RAY_2_9_3_PY311_CU118 = "anyscale/ray:2.9.3-py311-cu118"
    ANYSCALE_RAY_2_9_3_PY311_CU121 = "anyscale/ray:2.9.3-py311-cu121"
    ANYSCALE_RAY_2_9_3_PY38 = "anyscale/ray:2.9.3-py38"
    ANYSCALE_RAY_2_9_3_PY38_CU115 = "anyscale/ray:2.9.3-py38-cu115"
    ANYSCALE_RAY_2_9_3_PY38_CU116 = "anyscale/ray:2.9.3-py38-cu116"
    ANYSCALE_RAY_2_9_3_PY38_CU117 = "anyscale/ray:2.9.3-py38-cu117"
    ANYSCALE_RAY_2_9_3_PY38_CU118 = "anyscale/ray:2.9.3-py38-cu118"
    ANYSCALE_RAY_2_9_3_PY38_CU121 = "anyscale/ray:2.9.3-py38-cu121"
    ANYSCALE_RAY_2_9_3_PY39 = "anyscale/ray:2.9.3-py39"
    ANYSCALE_RAY_2_9_3_PY39_CU115 = "anyscale/ray:2.9.3-py39-cu115"
    ANYSCALE_RAY_2_9_3_PY39_CU116 = "anyscale/ray:2.9.3-py39-cu116"
    ANYSCALE_RAY_2_9_3_PY39_CU117 = "anyscale/ray:2.9.3-py39-cu117"
    ANYSCALE_RAY_2_9_3_PY39_CU118 = "anyscale/ray:2.9.3-py39-cu118"
    ANYSCALE_RAY_2_9_3_PY39_CU121 = "anyscale/ray:2.9.3-py39-cu121"
    ANYSCALE_RAY_LATEST = "anyscale/ray:latest"
    ANYSCALE_RAY_NIGHTLY = "anyscale/ray:nightly"
    ANYSCALE_RAY_NIGHTLY_GPU = "anyscale/ray:nightly-gpu"
    ANYSCALE_RAY_NIGHTLY_PY310 = "anyscale/ray:nightly-py310"
    ANYSCALE_RAY_NIGHTLY_PY310_CU117 = "anyscale/ray:nightly-py310-cu117"
    ANYSCALE_RAY_NIGHTLY_PY310_CU118 = "anyscale/ray:nightly-py310-cu118"
    ANYSCALE_RAY_NIGHTLY_PY310_CU121 = "anyscale/ray:nightly-py310-cu121"
    ANYSCALE_RAY_NIGHTLY_PY310_CU123 = "anyscale/ray:nightly-py310-cu123"
    ANYSCALE_RAY_NIGHTLY_PY311 = "anyscale/ray:nightly-py311"
    ANYSCALE_RAY_NIGHTLY_PY311_CU117 = "anyscale/ray:nightly-py311-cu117"
    ANYSCALE_RAY_NIGHTLY_PY311_CU118 = "anyscale/ray:nightly-py311-cu118"
    ANYSCALE_RAY_NIGHTLY_PY311_CU121 = "anyscale/ray:nightly-py311-cu121"
    ANYSCALE_RAY_NIGHTLY_PY311_CU123 = "anyscale/ray:nightly-py311-cu123"
    ANYSCALE_RAY_NIGHTLY_PY312 = "anyscale/ray:nightly-py312"
    ANYSCALE_RAY_NIGHTLY_PY312_CU117 = "anyscale/ray:nightly-py312-cu117"
    ANYSCALE_RAY_NIGHTLY_PY312_CU118 = "anyscale/ray:nightly-py312-cu118"
    ANYSCALE_RAY_NIGHTLY_PY312_CU121 = "anyscale/ray:nightly-py312-cu121"
    ANYSCALE_RAY_NIGHTLY_PY312_CU123 = "anyscale/ray:nightly-py312-cu123"
    ANYSCALE_RAY_NIGHTLY_PY36 = "anyscale/ray:nightly-py36"
    ANYSCALE_RAY_NIGHTLY_PY36_CU117 = "anyscale/ray:nightly-py36-cu117"
    ANYSCALE_RAY_NIGHTLY_PY36_CU118 = "anyscale/ray:nightly-py36-cu118"
    ANYSCALE_RAY_NIGHTLY_PY36_CU121 = "anyscale/ray:nightly-py36-cu121"
    ANYSCALE_RAY_NIGHTLY_PY36_CU123 = "anyscale/ray:nightly-py36-cu123"
    ANYSCALE_RAY_NIGHTLY_PY37 = "anyscale/ray:nightly-py37"
    ANYSCALE_RAY_NIGHTLY_PY37_CU117 = "anyscale/ray:nightly-py37-cu117"
    ANYSCALE_RAY_NIGHTLY_PY37_CU118 = "anyscale/ray:nightly-py37-cu118"
    ANYSCALE_RAY_NIGHTLY_PY37_CU121 = "anyscale/ray:nightly-py37-cu121"
    ANYSCALE_RAY_NIGHTLY_PY37_CU123 = "anyscale/ray:nightly-py37-cu123"
    ANYSCALE_RAY_NIGHTLY_PY38 = "anyscale/ray:nightly-py38"
    ANYSCALE_RAY_NIGHTLY_PY38_CU117 = "anyscale/ray:nightly-py38-cu117"
    ANYSCALE_RAY_NIGHTLY_PY38_CU118 = "anyscale/ray:nightly-py38-cu118"
    ANYSCALE_RAY_NIGHTLY_PY38_CU121 = "anyscale/ray:nightly-py38-cu121"
    ANYSCALE_RAY_NIGHTLY_PY38_CU123 = "anyscale/ray:nightly-py38-cu123"
    ANYSCALE_RAY_NIGHTLY_PY39 = "anyscale/ray:nightly-py39"
    ANYSCALE_RAY_NIGHTLY_PY39_CU117 = "anyscale/ray:nightly-py39-cu117"
    ANYSCALE_RAY_NIGHTLY_PY39_CU118 = "anyscale/ray:nightly-py39-cu118"
    ANYSCALE_RAY_NIGHTLY_PY39_CU121 = "anyscale/ray:nightly-py39-cu121"
    ANYSCALE_RAY_NIGHTLY_PY39_CU123 = "anyscale/ray:nightly-py39-cu123"
    UNKNOWN = "unknown"

    allowable_values = [ANYSCALE_RAY_ML_1_10_0_PY36_GPU, ANYSCALE_RAY_ML_1_10_0_PY37_GPU, ANYSCALE_RAY_ML_1_10_0_PY38_GPU, ANYSCALE_RAY_ML_1_10_0RC0_PY36_GPU, ANYSCALE_RAY_ML_1_10_0RC0_PY37_GPU, ANYSCALE_RAY_ML_1_10_0RC0_PY38_GPU, ANYSCALE_RAY_ML_1_11_0_PY36_GPU, ANYSCALE_RAY_ML_1_11_0_PY37_GPU, ANYSCALE_RAY_ML_1_11_0_PY38_GPU, ANYSCALE_RAY_ML_1_11_1_PY36_GPU, ANYSCALE_RAY_ML_1_11_1_PY37_GPU, ANYSCALE_RAY_ML_1_11_1_PY38_GPU, ANYSCALE_RAY_ML_1_12_0_PY36_GPU, ANYSCALE_RAY_ML_1_12_0_PY37_GPU, ANYSCALE_RAY_ML_1_12_0_PY38_GPU, ANYSCALE_RAY_ML_1_12_1_PY36_GPU, ANYSCALE_RAY_ML_1_12_1_PY37_GPU, ANYSCALE_RAY_ML_1_12_1_PY38_GPU, ANYSCALE_RAY_ML_1_13_0_PY36_CPU, ANYSCALE_RAY_ML_1_13_0_PY36_GPU, ANYSCALE_RAY_ML_1_13_0_PY37_CPU, ANYSCALE_RAY_ML_1_13_0_PY37_GPU, ANYSCALE_RAY_ML_1_13_0_PY38_CPU, ANYSCALE_RAY_ML_1_13_0_PY38_GPU, ANYSCALE_RAY_ML_1_13_0RC0_PY36_GPU, ANYSCALE_RAY_ML_1_13_0RC0_PY37_GPU, ANYSCALE_RAY_ML_1_13_0RC0_PY38_GPU, ANYSCALE_RAY_ML_1_7_0, ANYSCALE_RAY_ML_1_7_0_GPU, ANYSCALE_RAY_ML_1_7_0_PY36, ANYSCALE_RAY_ML_1_7_0_PY36_GPU, ANYSCALE_RAY_ML_1_7_0_PY37, ANYSCALE_RAY_ML_1_7_0_PY37_GPU, ANYSCALE_RAY_ML_1_7_0_PY38, ANYSCALE_RAY_ML_1_7_0_PY38_GPU, ANYSCALE_RAY_ML_1_7_0RC0, ANYSCALE_RAY_ML_1_7_0RC0_GPU, ANYSCALE_RAY_ML_1_7_0RC0_PY36, ANYSCALE_RAY_ML_1_7_0RC0_PY36_GPU, ANYSCALE_RAY_ML_1_7_0RC0_PY37, ANYSCALE_RAY_ML_1_7_0RC0_PY37_GPU, ANYSCALE_RAY_ML_1_7_0RC0_PY38, ANYSCALE_RAY_ML_1_7_0RC0_PY38_GPU, ANYSCALE_RAY_ML_1_7_1, ANYSCALE_RAY_ML_1_7_1_GPU, ANYSCALE_RAY_ML_1_7_1_PY36, ANYSCALE_RAY_ML_1_7_1_PY36_GPU, ANYSCALE_RAY_ML_1_7_1_PY37, ANYSCALE_RAY_ML_1_7_1_PY37_GPU, ANYSCALE_RAY_ML_1_7_1_PY38, ANYSCALE_RAY_ML_1_7_1_PY38_GPU, ANYSCALE_RAY_ML_1_8_0, ANYSCALE_RAY_ML_1_8_0_GPU, ANYSCALE_RAY_ML_1_8_0_PY36, ANYSCALE_RAY_ML_1_8_0_PY36_GPU, ANYSCALE_RAY_ML_1_8_0_PY37, ANYSCALE_RAY_ML_1_8_0_PY37_GPU, ANYSCALE_RAY_ML_1_8_0_PY38, ANYSCALE_RAY_ML_1_8_0_PY38_GPU, ANYSCALE_RAY_ML_1_9_0_PY36_GPU, ANYSCALE_RAY_ML_1_9_0_PY37_GPU, ANYSCALE_RAY_ML_1_9_0_PY38_GPU, ANYSCALE_RAY_ML_1_9_0RC1_PY36_GPU, ANYSCALE_RAY_ML_1_9_0RC1_PY37_GPU, ANYSCALE_RAY_ML_1_9_0RC1_PY38_GPU, ANYSCALE_RAY_ML_1_9_0RC2_PY36_GPU, ANYSCALE_RAY_ML_1_9_0RC2_PY37_GPU, ANYSCALE_RAY_ML_1_9_0RC2_PY38_GPU, ANYSCALE_RAY_ML_1_9_1_PY36_GPU, ANYSCALE_RAY_ML_1_9_1_PY37_GPU, ANYSCALE_RAY_ML_1_9_1_PY38_GPU, ANYSCALE_RAY_ML_1_9_1RC0_PY36_GPU, ANYSCALE_RAY_ML_1_9_1RC0_PY37_GPU, ANYSCALE_RAY_ML_1_9_1RC0_PY38_GPU, ANYSCALE_RAY_ML_1_9_2_PY36_GPU, ANYSCALE_RAY_ML_1_9_2_PY37_GPU, ANYSCALE_RAY_ML_1_9_2_PY38_GPU, ANYSCALE_RAY_ML_2_0_0_PY36_CPU, ANYSCALE_RAY_ML_2_0_0_PY36_GPU, ANYSCALE_RAY_ML_2_0_0_PY37_CPU, ANYSCALE_RAY_ML_2_0_0_PY37_GPU, ANYSCALE_RAY_ML_2_0_0_PY38_CPU, ANYSCALE_RAY_ML_2_0_0_PY38_GPU, ANYSCALE_RAY_ML_2_0_0RC0_PY36_CPU, ANYSCALE_RAY_ML_2_0_0RC0_PY36_GPU, ANYSCALE_RAY_ML_2_0_0RC0_PY37_CPU, ANYSCALE_RAY_ML_2_0_0RC0_PY37_GPU, ANYSCALE_RAY_ML_2_0_0RC0_PY38_CPU, ANYSCALE_RAY_ML_2_0_0RC0_PY38_GPU, ANYSCALE_RAY_ML_2_0_0RC1_PY36_CPU, ANYSCALE_RAY_ML_2_0_0RC1_PY36_GPU, ANYSCALE_RAY_ML_2_0_0RC1_PY37_CPU, ANYSCALE_RAY_ML_2_0_0RC1_PY37_GPU, ANYSCALE_RAY_ML_2_0_0RC1_PY38_CPU, ANYSCALE_RAY_ML_2_0_0RC1_PY38_GPU, ANYSCALE_RAY_ML_2_0_1_PY36_CPU, ANYSCALE_RAY_ML_2_0_1_PY36_GPU, ANYSCALE_RAY_ML_2_0_1_PY37_CPU, ANYSCALE_RAY_ML_2_0_1_PY37_GPU, ANYSCALE_RAY_ML_2_0_1_PY38_CPU, ANYSCALE_RAY_ML_2_0_1_PY38_GPU, ANYSCALE_RAY_ML_2_1_0_PY36_CPU, ANYSCALE_RAY_ML_2_1_0_PY36_GPU, ANYSCALE_RAY_ML_2_1_0_PY37_CPU, ANYSCALE_RAY_ML_2_1_0_PY37_GPU, ANYSCALE_RAY_ML_2_1_0_PY38_CPU, ANYSCALE_RAY_ML_2_1_0_PY38_GPU, ANYSCALE_RAY_ML_2_10_0_PY310_CPU, ANYSCALE_RAY_ML_2_10_0_PY310_GPU, ANYSCALE_RAY_ML_2_10_0_PY38_CPU, ANYSCALE_RAY_ML_2_10_0_PY38_GPU, ANYSCALE_RAY_ML_2_10_0_PY39_CPU, ANYSCALE_RAY_ML_2_10_0_PY39_GPU, ANYSCALE_RAY_ML_2_11_0_PY310_CPU, ANYSCALE_RAY_ML_2_11_0_PY310_GPU, ANYSCALE_RAY_ML_2_11_0_PY311_CPU, ANYSCALE_RAY_ML_2_11_0_PY311_GPU, ANYSCALE_RAY_ML_2_11_0_PY39_CPU, ANYSCALE_RAY_ML_2_11_0_PY39_GPU, ANYSCALE_RAY_ML_2_12_0_PY310_CPU, ANYSCALE_RAY_ML_2_12_0_PY310_GPU, ANYSCALE_RAY_ML_2_12_0_PY311_CPU, ANYSCALE_RAY_ML_2_12_0_PY311_GPU, ANYSCALE_RAY_ML_2_12_0_PY39_CPU, ANYSCALE_RAY_ML_2_12_0_PY39_GPU, ANYSCALE_RAY_ML_2_2_0_PY310_CPU, ANYSCALE_RAY_ML_2_2_0_PY310_GPU, ANYSCALE_RAY_ML_2_2_0_PY37_CPU, ANYSCALE_RAY_ML_2_2_0_PY37_GPU, ANYSCALE_RAY_ML_2_2_0_PY38_CPU, ANYSCALE_RAY_ML_2_2_0_PY38_GPU, ANYSCALE_RAY_ML_2_2_0_PY39_CPU, ANYSCALE_RAY_ML_2_2_0_PY39_GPU, ANYSCALE_RAY_ML_2_20_0_PY310_CPU, ANYSCALE_RAY_ML_2_20_0_PY310_GPU, ANYSCALE_RAY_ML_2_20_0_PY311_CPU, ANYSCALE_RAY_ML_2_20_0_PY311_GPU, ANYSCALE_RAY_ML_2_20_0_PY39_CPU, ANYSCALE_RAY_ML_2_20_0_PY39_GPU, ANYSCALE_RAY_ML_2_21_0_PY310_CPU, ANYSCALE_RAY_ML_2_21_0_PY310_GPU, ANYSCALE_RAY_ML_2_21_0_PY311_CPU, ANYSCALE_RAY_ML_2_21_0_PY311_GPU, ANYSCALE_RAY_ML_2_21_0_PY39_CPU, ANYSCALE_RAY_ML_2_21_0_PY39_GPU, ANYSCALE_RAY_ML_2_22_0_PY310_CPU, ANYSCALE_RAY_ML_2_22_0_PY310_GPU, ANYSCALE_RAY_ML_2_22_0_PY311_CPU, ANYSCALE_RAY_ML_2_22_0_PY311_GPU, ANYSCALE_RAY_ML_2_22_0_PY39_CPU, ANYSCALE_RAY_ML_2_22_0_PY39_GPU, ANYSCALE_RAY_ML_2_23_0_PY310_CPU, ANYSCALE_RAY_ML_2_23_0_PY310_GPU, ANYSCALE_RAY_ML_2_23_0_PY311_CPU, ANYSCALE_RAY_ML_2_23_0_PY311_GPU, ANYSCALE_RAY_ML_2_23_0_PY39_CPU, ANYSCALE_RAY_ML_2_23_0_PY39_GPU, ANYSCALE_RAY_ML_2_24_0_PY310_CPU, ANYSCALE_RAY_ML_2_24_0_PY310_GPU, ANYSCALE_RAY_ML_2_24_0_PY311_CPU, ANYSCALE_RAY_ML_2_24_0_PY311_GPU, ANYSCALE_RAY_ML_2_24_0_PY39_CPU, ANYSCALE_RAY_ML_2_24_0_PY39_GPU, ANYSCALE_RAY_ML_2_3_0_PY310_CPU, ANYSCALE_RAY_ML_2_3_0_PY310_GPU, ANYSCALE_RAY_ML_2_3_0_PY37_CPU, ANYSCALE_RAY_ML_2_3_0_PY37_GPU, ANYSCALE_RAY_ML_2_3_0_PY38_CPU, ANYSCALE_RAY_ML_2_3_0_PY38_GPU, ANYSCALE_RAY_ML_2_3_0_PY39_CPU, ANYSCALE_RAY_ML_2_3_0_PY39_GPU, ANYSCALE_RAY_ML_2_3_1_PY310_CPU, ANYSCALE_RAY_ML_2_3_1_PY310_GPU, ANYSCALE_RAY_ML_2_3_1_PY37_CPU, ANYSCALE_RAY_ML_2_3_1_PY37_GPU, ANYSCALE_RAY_ML_2_3_1_PY38_CPU, ANYSCALE_RAY_ML_2_3_1_PY38_GPU, ANYSCALE_RAY_ML_2_3_1_PY39_CPU, ANYSCALE_RAY_ML_2_3_1_PY39_GPU, ANYSCALE_RAY_ML_2_30_0_PY310_CPU, ANYSCALE_RAY_ML_2_30_0_PY310_GPU, ANYSCALE_RAY_ML_2_30_0_PY311_CPU, ANYSCALE_RAY_ML_2_30_0_PY311_GPU, ANYSCALE_RAY_ML_2_30_0_PY39_CPU, ANYSCALE_RAY_ML_2_30_0_PY39_GPU, ANYSCALE_RAY_ML_2_31_0_PY310_CPU, ANYSCALE_RAY_ML_2_31_0_PY310_GPU, ANYSCALE_RAY_ML_2_31_0_PY311_CPU, ANYSCALE_RAY_ML_2_31_0_PY311_GPU, ANYSCALE_RAY_ML_2_31_0_PY39_CPU, ANYSCALE_RAY_ML_2_31_0_PY39_GPU, ANYSCALE_RAY_ML_2_32_0_PY310_CPU, ANYSCALE_RAY_ML_2_32_0_PY310_GPU, ANYSCALE_RAY_ML_2_32_0_PY311_CPU, ANYSCALE_RAY_ML_2_32_0_PY311_GPU, ANYSCALE_RAY_ML_2_32_0_PY39_CPU, ANYSCALE_RAY_ML_2_32_0_PY39_GPU, ANYSCALE_RAY_ML_2_33_0_PY310_CPU, ANYSCALE_RAY_ML_2_33_0_PY310_GPU, ANYSCALE_RAY_ML_2_33_0_PY311_CPU, ANYSCALE_RAY_ML_2_33_0_PY311_GPU, ANYSCALE_RAY_ML_2_33_0_PY39_CPU, ANYSCALE_RAY_ML_2_33_0_PY39_GPU, ANYSCALE_RAY_ML_2_34_0_PY310_CPU, ANYSCALE_RAY_ML_2_34_0_PY310_GPU, ANYSCALE_RAY_ML_2_34_0_PY311_CPU, ANYSCALE_RAY_ML_2_34_0_PY311_GPU, ANYSCALE_RAY_ML_2_34_0_PY39_CPU, ANYSCALE_RAY_ML_2_34_0_PY39_GPU, ANYSCALE_RAY_ML_2_35_0_PY310_CPU, ANYSCALE_RAY_ML_2_35_0_PY310_GPU, ANYSCALE_RAY_ML_2_35_0_PY311_CPU, ANYSCALE_RAY_ML_2_35_0_PY311_GPU, ANYSCALE_RAY_ML_2_35_0_PY39_CPU, ANYSCALE_RAY_ML_2_35_0_PY39_GPU, ANYSCALE_RAY_ML_2_36_0_PY310_CPU, ANYSCALE_RAY_ML_2_36_0_PY310_GPU, ANYSCALE_RAY_ML_2_36_0_PY311_CPU, ANYSCALE_RAY_ML_2_36_0_PY311_GPU, ANYSCALE_RAY_ML_2_36_0_PY39_CPU, ANYSCALE_RAY_ML_2_36_0_PY39_GPU, ANYSCALE_RAY_ML_2_36_1_PY310_CPU, ANYSCALE_RAY_ML_2_36_1_PY310_GPU, ANYSCALE_RAY_ML_2_36_1_PY311_CPU, ANYSCALE_RAY_ML_2_36_1_PY311_GPU, ANYSCALE_RAY_ML_2_36_1_PY39_CPU, ANYSCALE_RAY_ML_2_36_1_PY39_GPU, ANYSCALE_RAY_ML_2_37_0_PY310_CPU, ANYSCALE_RAY_ML_2_37_0_PY310_GPU, ANYSCALE_RAY_ML_2_37_0_PY311_CPU, ANYSCALE_RAY_ML_2_37_0_PY311_GPU, ANYSCALE_RAY_ML_2_37_0_PY39_CPU, ANYSCALE_RAY_ML_2_37_0_PY39_GPU, ANYSCALE_RAY_ML_2_38_0_PY310_CPU, ANYSCALE_RAY_ML_2_38_0_PY310_GPU, ANYSCALE_RAY_ML_2_38_0_PY311_CPU, ANYSCALE_RAY_ML_2_38_0_PY311_GPU, ANYSCALE_RAY_ML_2_38_0_PY39_CPU, ANYSCALE_RAY_ML_2_38_0_PY39_GPU, ANYSCALE_RAY_ML_2_39_0_PY310_CPU, ANYSCALE_RAY_ML_2_39_0_PY310_GPU, ANYSCALE_RAY_ML_2_39_0_PY311_CPU, ANYSCALE_RAY_ML_2_39_0_PY311_GPU, ANYSCALE_RAY_ML_2_39_0_PY39_CPU, ANYSCALE_RAY_ML_2_39_0_PY39_GPU, ANYSCALE_RAY_ML_2_4_0_PY310_CPU, ANYSCALE_RAY_ML_2_4_0_PY310_GPU, ANYSCALE_RAY_ML_2_4_0_PY37_CPU, ANYSCALE_RAY_ML_2_4_0_PY37_GPU, ANYSCALE_RAY_ML_2_4_0_PY38_CPU, ANYSCALE_RAY_ML_2_4_0_PY38_GPU, ANYSCALE_RAY_ML_2_4_0_PY39_CPU, ANYSCALE_RAY_ML_2_4_0_PY39_GPU, ANYSCALE_RAY_ML_2_40_0_PY310_CPU, ANYSCALE_RAY_ML_2_40_0_PY310_GPU, ANYSCALE_RAY_ML_2_40_0_PY311_CPU, ANYSCALE_RAY_ML_2_40_0_PY311_GPU, ANYSCALE_RAY_ML_2_40_0_PY39_CPU, ANYSCALE_RAY_ML_2_40_0_PY39_GPU, ANYSCALE_RAY_ML_2_5_0_PY310_CPU, ANYSCALE_RAY_ML_2_5_0_PY310_GPU, ANYSCALE_RAY_ML_2_5_0_PY37_CPU, ANYSCALE_RAY_ML_2_5_0_PY37_GPU, ANYSCALE_RAY_ML_2_5_0_PY38_CPU, ANYSCALE_RAY_ML_2_5_0_PY38_GPU, ANYSCALE_RAY_ML_2_5_0_PY39_CPU, ANYSCALE_RAY_ML_2_5_0_PY39_GPU, ANYSCALE_RAY_ML_2_5_1_PY310_CPU, ANYSCALE_RAY_ML_2_5_1_PY310_GPU, ANYSCALE_RAY_ML_2_5_1_PY37_CPU, ANYSCALE_RAY_ML_2_5_1_PY37_GPU, ANYSCALE_RAY_ML_2_5_1_PY38_CPU, ANYSCALE_RAY_ML_2_5_1_PY38_GPU, ANYSCALE_RAY_ML_2_5_1_PY39_CPU, ANYSCALE_RAY_ML_2_5_1_PY39_GPU, ANYSCALE_RAY_ML_2_6_0_PY310_CPU, ANYSCALE_RAY_ML_2_6_0_PY310_GPU, ANYSCALE_RAY_ML_2_6_0_PY38_CPU, ANYSCALE_RAY_ML_2_6_0_PY38_GPU, ANYSCALE_RAY_ML_2_6_0_PY39_CPU, ANYSCALE_RAY_ML_2_6_0_PY39_GPU, ANYSCALE_RAY_ML_2_6_1_PY310_CPU, ANYSCALE_RAY_ML_2_6_1_PY310_GPU, ANYSCALE_RAY_ML_2_6_1_PY38_CPU, ANYSCALE_RAY_ML_2_6_1_PY38_GPU, ANYSCALE_RAY_ML_2_6_1_PY39_CPU, ANYSCALE_RAY_ML_2_6_1_PY39_GPU, ANYSCALE_RAY_ML_2_6_2_PY310_CPU, ANYSCALE_RAY_ML_2_6_2_PY310_GPU, ANYSCALE_RAY_ML_2_6_2_PY38_CPU, ANYSCALE_RAY_ML_2_6_2_PY38_GPU, ANYSCALE_RAY_ML_2_6_2_PY39_CPU, ANYSCALE_RAY_ML_2_6_2_PY39_GPU, ANYSCALE_RAY_ML_2_6_3_PY310_CPU, ANYSCALE_RAY_ML_2_6_3_PY310_GPU, ANYSCALE_RAY_ML_2_6_3_PY38_CPU, ANYSCALE_RAY_ML_2_6_3_PY38_GPU, ANYSCALE_RAY_ML_2_6_3_PY39_CPU, ANYSCALE_RAY_ML_2_6_3_PY39_GPU, ANYSCALE_RAY_ML_2_7_0OPTIMIZED_PY310_CPU, ANYSCALE_RAY_ML_2_7_0OPTIMIZED_PY310_GPU, ANYSCALE_RAY_ML_2_7_0OPTIMIZED_PY38_CPU, ANYSCALE_RAY_ML_2_7_0OPTIMIZED_PY38_GPU, ANYSCALE_RAY_ML_2_7_0OPTIMIZED_PY39_CPU, ANYSCALE_RAY_ML_2_7_0OPTIMIZED_PY39_GPU, ANYSCALE_RAY_ML_2_7_1OPTIMIZED_PY310_CPU, ANYSCALE_RAY_ML_2_7_1OPTIMIZED_PY310_GPU, ANYSCALE_RAY_ML_2_7_1OPTIMIZED_PY38_CPU, ANYSCALE_RAY_ML_2_7_1OPTIMIZED_PY38_GPU, ANYSCALE_RAY_ML_2_7_1OPTIMIZED_PY39_CPU, ANYSCALE_RAY_ML_2_7_1OPTIMIZED_PY39_GPU, ANYSCALE_RAY_ML_2_7_2OPTIMIZED_PY310_CPU, ANYSCALE_RAY_ML_2_7_2OPTIMIZED_PY310_GPU, ANYSCALE_RAY_ML_2_7_2OPTIMIZED_PY38_CPU, ANYSCALE_RAY_ML_2_7_2OPTIMIZED_PY38_GPU, ANYSCALE_RAY_ML_2_7_2OPTIMIZED_PY39_CPU, ANYSCALE_RAY_ML_2_7_2OPTIMIZED_PY39_GPU, ANYSCALE_RAY_ML_2_8_0_PY310_CPU, ANYSCALE_RAY_ML_2_8_0_PY310_GPU, ANYSCALE_RAY_ML_2_8_0_PY38_CPU, ANYSCALE_RAY_ML_2_8_0_PY38_GPU, ANYSCALE_RAY_ML_2_8_0_PY39_CPU, ANYSCALE_RAY_ML_2_8_0_PY39_GPU, ANYSCALE_RAY_ML_2_8_1_PY310_CPU, ANYSCALE_RAY_ML_2_8_1_PY310_GPU, ANYSCALE_RAY_ML_2_8_1_PY38_CPU, ANYSCALE_RAY_ML_2_8_1_PY38_GPU, ANYSCALE_RAY_ML_2_8_1_PY39_CPU, ANYSCALE_RAY_ML_2_8_1_PY39_GPU, ANYSCALE_RAY_ML_2_9_0_PY310_CPU, ANYSCALE_RAY_ML_2_9_0_PY310_GPU, ANYSCALE_RAY_ML_2_9_0_PY38_CPU, ANYSCALE_RAY_ML_2_9_0_PY38_GPU, ANYSCALE_RAY_ML_2_9_0_PY39_CPU, ANYSCALE_RAY_ML_2_9_0_PY39_GPU, ANYSCALE_RAY_ML_2_9_1_PY310_CPU, ANYSCALE_RAY_ML_2_9_1_PY310_GPU, ANYSCALE_RAY_ML_2_9_1_PY38_CPU, ANYSCALE_RAY_ML_2_9_1_PY38_GPU, ANYSCALE_RAY_ML_2_9_1_PY39_CPU, ANYSCALE_RAY_ML_2_9_1_PY39_GPU, ANYSCALE_RAY_ML_2_9_2_PY310_CPU, ANYSCALE_RAY_ML_2_9_2_PY310_GPU, ANYSCALE_RAY_ML_2_9_2_PY38_CPU, ANYSCALE_RAY_ML_2_9_2_PY38_GPU, ANYSCALE_RAY_ML_2_9_2_PY39_CPU, ANYSCALE_RAY_ML_2_9_2_PY39_GPU, ANYSCALE_RAY_ML_2_9_3_PY310_CPU, ANYSCALE_RAY_ML_2_9_3_PY310_GPU, ANYSCALE_RAY_ML_2_9_3_PY38_CPU, ANYSCALE_RAY_ML_2_9_3_PY38_GPU, ANYSCALE_RAY_ML_2_9_3_PY39_CPU, ANYSCALE_RAY_ML_2_9_3_PY39_GPU, ANYSCALE_RAY_ML_LATEST, ANYSCALE_RAY_ML_NIGHTLY, ANYSCALE_RAY_ML_NIGHTLY_GPU, ANYSCALE_RAY_ML_NIGHTLY_PY310_GPU, ANYSCALE_RAY_ML_NIGHTLY_PY311_GPU, ANYSCALE_RAY_ML_NIGHTLY_PY312_GPU, ANYSCALE_RAY_ML_NIGHTLY_PY36_GPU, ANYSCALE_RAY_ML_NIGHTLY_PY37_GPU, ANYSCALE_RAY_ML_NIGHTLY_PY38_GPU, ANYSCALE_RAY_ML_NIGHTLY_PY39_GPU, ANYSCALE_RAY_ML_PINNED_NIGHTLY, ANYSCALE_RAY_ML_PINNED_NIGHTLY_GPU, ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY310, ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY310_GPU, ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY311, ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY311_GPU, ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY312, ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY312_GPU, ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY36, ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY36_GPU, ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY37, ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY37_GPU, ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY38, ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY38_GPU, ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY39, ANYSCALE_RAY_ML_PINNED_NIGHTLY_PY39_GPU, ANYSCALE_RAY_1_10_0_PY36, ANYSCALE_RAY_1_10_0_PY36_CU101, ANYSCALE_RAY_1_10_0_PY36_CU102, ANYSCALE_RAY_1_10_0_PY36_CU110, ANYSCALE_RAY_1_10_0_PY36_CU111, ANYSCALE_RAY_1_10_0_PY36_CU112, ANYSCALE_RAY_1_10_0_PY37, ANYSCALE_RAY_1_10_0_PY37_CU101, ANYSCALE_RAY_1_10_0_PY37_CU102, ANYSCALE_RAY_1_10_0_PY37_CU110, ANYSCALE_RAY_1_10_0_PY37_CU111, ANYSCALE_RAY_1_10_0_PY37_CU112, ANYSCALE_RAY_1_10_0_PY38, ANYSCALE_RAY_1_10_0_PY38_CU101, ANYSCALE_RAY_1_10_0_PY38_CU102, ANYSCALE_RAY_1_10_0_PY38_CU110, ANYSCALE_RAY_1_10_0_PY38_CU111, ANYSCALE_RAY_1_10_0_PY38_CU112, ANYSCALE_RAY_1_10_0_PY39, ANYSCALE_RAY_1_10_0_PY39_CU101, ANYSCALE_RAY_1_10_0_PY39_CU102, ANYSCALE_RAY_1_10_0_PY39_CU110, ANYSCALE_RAY_1_10_0_PY39_CU111, ANYSCALE_RAY_1_10_0_PY39_CU112, ANYSCALE_RAY_1_10_0RC0_PY36, ANYSCALE_RAY_1_10_0RC0_PY36_CU101, ANYSCALE_RAY_1_10_0RC0_PY36_CU102, ANYSCALE_RAY_1_10_0RC0_PY36_CU110, ANYSCALE_RAY_1_10_0RC0_PY36_CU111, ANYSCALE_RAY_1_10_0RC0_PY36_CU112, ANYSCALE_RAY_1_10_0RC0_PY37, ANYSCALE_RAY_1_10_0RC0_PY37_CU101, ANYSCALE_RAY_1_10_0RC0_PY37_CU102, ANYSCALE_RAY_1_10_0RC0_PY37_CU110, ANYSCALE_RAY_1_10_0RC0_PY37_CU111, ANYSCALE_RAY_1_10_0RC0_PY37_CU112, ANYSCALE_RAY_1_10_0RC0_PY38, ANYSCALE_RAY_1_10_0RC0_PY38_CU101, ANYSCALE_RAY_1_10_0RC0_PY38_CU102, ANYSCALE_RAY_1_10_0RC0_PY38_CU110, ANYSCALE_RAY_1_10_0RC0_PY38_CU111, ANYSCALE_RAY_1_10_0RC0_PY38_CU112, ANYSCALE_RAY_1_11_0_PY36, ANYSCALE_RAY_1_11_0_PY36_CU101, ANYSCALE_RAY_1_11_0_PY36_CU102, ANYSCALE_RAY_1_11_0_PY36_CU110, ANYSCALE_RAY_1_11_0_PY36_CU111, ANYSCALE_RAY_1_11_0_PY36_CU112, ANYSCALE_RAY_1_11_0_PY37, ANYSCALE_RAY_1_11_0_PY37_CU101, ANYSCALE_RAY_1_11_0_PY37_CU102, ANYSCALE_RAY_1_11_0_PY37_CU110, ANYSCALE_RAY_1_11_0_PY37_CU111, ANYSCALE_RAY_1_11_0_PY37_CU112, ANYSCALE_RAY_1_11_0_PY38, ANYSCALE_RAY_1_11_0_PY38_CU101, ANYSCALE_RAY_1_11_0_PY38_CU102, ANYSCALE_RAY_1_11_0_PY38_CU110, ANYSCALE_RAY_1_11_0_PY38_CU111, ANYSCALE_RAY_1_11_0_PY38_CU112, ANYSCALE_RAY_1_11_0_PY39, ANYSCALE_RAY_1_11_0_PY39_CU101, ANYSCALE_RAY_1_11_0_PY39_CU102, ANYSCALE_RAY_1_11_0_PY39_CU110, ANYSCALE_RAY_1_11_0_PY39_CU111, ANYSCALE_RAY_1_11_0_PY39_CU112, ANYSCALE_RAY_1_11_1_PY36, ANYSCALE_RAY_1_11_1_PY36_CU101, ANYSCALE_RAY_1_11_1_PY36_CU102, ANYSCALE_RAY_1_11_1_PY36_CU110, ANYSCALE_RAY_1_11_1_PY36_CU111, ANYSCALE_RAY_1_11_1_PY36_CU112, ANYSCALE_RAY_1_11_1_PY37, ANYSCALE_RAY_1_11_1_PY37_CU101, ANYSCALE_RAY_1_11_1_PY37_CU102, ANYSCALE_RAY_1_11_1_PY37_CU110, ANYSCALE_RAY_1_11_1_PY37_CU111, ANYSCALE_RAY_1_11_1_PY37_CU112, ANYSCALE_RAY_1_11_1_PY38, ANYSCALE_RAY_1_11_1_PY38_CU101, ANYSCALE_RAY_1_11_1_PY38_CU102, ANYSCALE_RAY_1_11_1_PY38_CU110, ANYSCALE_RAY_1_11_1_PY38_CU111, ANYSCALE_RAY_1_11_1_PY38_CU112, ANYSCALE_RAY_1_11_1_PY39, ANYSCALE_RAY_1_11_1_PY39_CU101, ANYSCALE_RAY_1_11_1_PY39_CU102, ANYSCALE_RAY_1_11_1_PY39_CU110, ANYSCALE_RAY_1_11_1_PY39_CU111, ANYSCALE_RAY_1_11_1_PY39_CU112, ANYSCALE_RAY_1_12_0_PY36, ANYSCALE_RAY_1_12_0_PY36_CU101, ANYSCALE_RAY_1_12_0_PY36_CU102, ANYSCALE_RAY_1_12_0_PY36_CU110, ANYSCALE_RAY_1_12_0_PY36_CU111, ANYSCALE_RAY_1_12_0_PY36_CU112, ANYSCALE_RAY_1_12_0_PY37, ANYSCALE_RAY_1_12_0_PY37_CU101, ANYSCALE_RAY_1_12_0_PY37_CU102, ANYSCALE_RAY_1_12_0_PY37_CU110, ANYSCALE_RAY_1_12_0_PY37_CU111, ANYSCALE_RAY_1_12_0_PY37_CU112, ANYSCALE_RAY_1_12_0_PY38, ANYSCALE_RAY_1_12_0_PY38_CU101, ANYSCALE_RAY_1_12_0_PY38_CU102, ANYSCALE_RAY_1_12_0_PY38_CU110, ANYSCALE_RAY_1_12_0_PY38_CU111, ANYSCALE_RAY_1_12_0_PY38_CU112, ANYSCALE_RAY_1_12_0_PY39, ANYSCALE_RAY_1_12_0_PY39_CU101, ANYSCALE_RAY_1_12_0_PY39_CU102, ANYSCALE_RAY_1_12_0_PY39_CU110, ANYSCALE_RAY_1_12_0_PY39_CU111, ANYSCALE_RAY_1_12_0_PY39_CU112, ANYSCALE_RAY_1_12_1_PY36, ANYSCALE_RAY_1_12_1_PY36_CU101, ANYSCALE_RAY_1_12_1_PY36_CU102, ANYSCALE_RAY_1_12_1_PY36_CU110, ANYSCALE_RAY_1_12_1_PY36_CU111, ANYSCALE_RAY_1_12_1_PY36_CU112, ANYSCALE_RAY_1_12_1_PY37, ANYSCALE_RAY_1_12_1_PY37_CU101, ANYSCALE_RAY_1_12_1_PY37_CU102, ANYSCALE_RAY_1_12_1_PY37_CU110, ANYSCALE_RAY_1_12_1_PY37_CU111, ANYSCALE_RAY_1_12_1_PY37_CU112, ANYSCALE_RAY_1_12_1_PY38, ANYSCALE_RAY_1_12_1_PY38_CU101, ANYSCALE_RAY_1_12_1_PY38_CU102, ANYSCALE_RAY_1_12_1_PY38_CU110, ANYSCALE_RAY_1_12_1_PY38_CU111, ANYSCALE_RAY_1_12_1_PY38_CU112, ANYSCALE_RAY_1_12_1_PY39, ANYSCALE_RAY_1_12_1_PY39_CU101, ANYSCALE_RAY_1_12_1_PY39_CU102, ANYSCALE_RAY_1_12_1_PY39_CU110, ANYSCALE_RAY_1_12_1_PY39_CU111, ANYSCALE_RAY_1_12_1_PY39_CU112, ANYSCALE_RAY_1_13_0_PY310, ANYSCALE_RAY_1_13_0_PY36, ANYSCALE_RAY_1_13_0_PY36_CU101, ANYSCALE_RAY_1_13_0_PY36_CU102, ANYSCALE_RAY_1_13_0_PY36_CU110, ANYSCALE_RAY_1_13_0_PY36_CU111, ANYSCALE_RAY_1_13_0_PY36_CU112, ANYSCALE_RAY_1_13_0_PY37, ANYSCALE_RAY_1_13_0_PY37_CU101, ANYSCALE_RAY_1_13_0_PY37_CU102, ANYSCALE_RAY_1_13_0_PY37_CU110, ANYSCALE_RAY_1_13_0_PY37_CU111, ANYSCALE_RAY_1_13_0_PY37_CU112, ANYSCALE_RAY_1_13_0_PY38, ANYSCALE_RAY_1_13_0_PY38_CU101, ANYSCALE_RAY_1_13_0_PY38_CU102, ANYSCALE_RAY_1_13_0_PY38_CU110, ANYSCALE_RAY_1_13_0_PY38_CU111, ANYSCALE_RAY_1_13_0_PY38_CU112, ANYSCALE_RAY_1_13_0_PY39, ANYSCALE_RAY_1_13_0_PY39_CU101, ANYSCALE_RAY_1_13_0_PY39_CU102, ANYSCALE_RAY_1_13_0_PY39_CU110, ANYSCALE_RAY_1_13_0_PY39_CU111, ANYSCALE_RAY_1_13_0_PY39_CU112, ANYSCALE_RAY_1_13_0RC0_PY36, ANYSCALE_RAY_1_13_0RC0_PY36_CU101, ANYSCALE_RAY_1_13_0RC0_PY36_CU102, ANYSCALE_RAY_1_13_0RC0_PY36_CU110, ANYSCALE_RAY_1_13_0RC0_PY36_CU111, ANYSCALE_RAY_1_13_0RC0_PY36_CU112, ANYSCALE_RAY_1_13_0RC0_PY37, ANYSCALE_RAY_1_13_0RC0_PY37_CU101, ANYSCALE_RAY_1_13_0RC0_PY37_CU102, ANYSCALE_RAY_1_13_0RC0_PY37_CU110, ANYSCALE_RAY_1_13_0RC0_PY37_CU111, ANYSCALE_RAY_1_13_0RC0_PY37_CU112, ANYSCALE_RAY_1_13_0RC0_PY38, ANYSCALE_RAY_1_13_0RC0_PY38_CU101, ANYSCALE_RAY_1_13_0RC0_PY38_CU102, ANYSCALE_RAY_1_13_0RC0_PY38_CU110, ANYSCALE_RAY_1_13_0RC0_PY38_CU111, ANYSCALE_RAY_1_13_0RC0_PY38_CU112, ANYSCALE_RAY_1_13_0RC0_PY39, ANYSCALE_RAY_1_13_0RC0_PY39_CU101, ANYSCALE_RAY_1_13_0RC0_PY39_CU102, ANYSCALE_RAY_1_13_0RC0_PY39_CU110, ANYSCALE_RAY_1_13_0RC0_PY39_CU111, ANYSCALE_RAY_1_13_0RC0_PY39_CU112, ANYSCALE_RAY_1_7_0, ANYSCALE_RAY_1_7_0_GPU, ANYSCALE_RAY_1_7_0_PY36, ANYSCALE_RAY_1_7_0_PY36_GPU, ANYSCALE_RAY_1_7_0_PY37, ANYSCALE_RAY_1_7_0_PY37_GPU, ANYSCALE_RAY_1_7_0_PY38, ANYSCALE_RAY_1_7_0_PY38_GPU, ANYSCALE_RAY_1_7_0RC0, ANYSCALE_RAY_1_7_0RC0_GPU, ANYSCALE_RAY_1_7_0RC0_PY36, ANYSCALE_RAY_1_7_0RC0_PY36_GPU, ANYSCALE_RAY_1_7_0RC0_PY37, ANYSCALE_RAY_1_7_0RC0_PY37_GPU, ANYSCALE_RAY_1_7_0RC0_PY38, ANYSCALE_RAY_1_7_0RC0_PY38_GPU, ANYSCALE_RAY_1_7_1, ANYSCALE_RAY_1_7_1_GPU, ANYSCALE_RAY_1_7_1_PY36, ANYSCALE_RAY_1_7_1_PY36_GPU, ANYSCALE_RAY_1_7_1_PY37, ANYSCALE_RAY_1_7_1_PY37_GPU, ANYSCALE_RAY_1_7_1_PY38, ANYSCALE_RAY_1_7_1_PY38_GPU, ANYSCALE_RAY_1_8_0, ANYSCALE_RAY_1_8_0_GPU, ANYSCALE_RAY_1_8_0_PY36, ANYSCALE_RAY_1_8_0_PY36_GPU, ANYSCALE_RAY_1_8_0_PY37, ANYSCALE_RAY_1_8_0_PY37_GPU, ANYSCALE_RAY_1_8_0_PY38, ANYSCALE_RAY_1_8_0_PY38_GPU, ANYSCALE_RAY_1_9_0_PY36, ANYSCALE_RAY_1_9_0_PY36_CU101, ANYSCALE_RAY_1_9_0_PY36_CU102, ANYSCALE_RAY_1_9_0_PY36_CU110, ANYSCALE_RAY_1_9_0_PY36_CU111, ANYSCALE_RAY_1_9_0_PY36_CU112, ANYSCALE_RAY_1_9_0_PY37, ANYSCALE_RAY_1_9_0_PY37_CU101, ANYSCALE_RAY_1_9_0_PY37_CU102, ANYSCALE_RAY_1_9_0_PY37_CU110, ANYSCALE_RAY_1_9_0_PY37_CU111, ANYSCALE_RAY_1_9_0_PY37_CU112, ANYSCALE_RAY_1_9_0_PY38, ANYSCALE_RAY_1_9_0_PY38_CU101, ANYSCALE_RAY_1_9_0_PY38_CU102, ANYSCALE_RAY_1_9_0_PY38_CU110, ANYSCALE_RAY_1_9_0_PY38_CU111, ANYSCALE_RAY_1_9_0_PY38_CU112, ANYSCALE_RAY_1_9_0_PY39, ANYSCALE_RAY_1_9_0_PY39_CU101, ANYSCALE_RAY_1_9_0_PY39_CU102, ANYSCALE_RAY_1_9_0_PY39_CU110, ANYSCALE_RAY_1_9_0_PY39_CU111, ANYSCALE_RAY_1_9_0_PY39_CU112, ANYSCALE_RAY_1_9_0RC1_PY36, ANYSCALE_RAY_1_9_0RC1_PY36_CU101, ANYSCALE_RAY_1_9_0RC1_PY36_CU102, ANYSCALE_RAY_1_9_0RC1_PY36_CU110, ANYSCALE_RAY_1_9_0RC1_PY36_CU111, ANYSCALE_RAY_1_9_0RC1_PY36_CU112, ANYSCALE_RAY_1_9_0RC1_PY37, ANYSCALE_RAY_1_9_0RC1_PY37_CU101, ANYSCALE_RAY_1_9_0RC1_PY37_CU102, ANYSCALE_RAY_1_9_0RC1_PY37_CU110, ANYSCALE_RAY_1_9_0RC1_PY37_CU111, ANYSCALE_RAY_1_9_0RC1_PY37_CU112, ANYSCALE_RAY_1_9_0RC1_PY38, ANYSCALE_RAY_1_9_0RC1_PY38_CU101, ANYSCALE_RAY_1_9_0RC1_PY38_CU102, ANYSCALE_RAY_1_9_0RC1_PY38_CU110, ANYSCALE_RAY_1_9_0RC1_PY38_CU111, ANYSCALE_RAY_1_9_0RC1_PY38_CU112, ANYSCALE_RAY_1_9_0RC2_PY36, ANYSCALE_RAY_1_9_0RC2_PY36_CU101, ANYSCALE_RAY_1_9_0RC2_PY36_CU102, ANYSCALE_RAY_1_9_0RC2_PY36_CU110, ANYSCALE_RAY_1_9_0RC2_PY36_CU111, ANYSCALE_RAY_1_9_0RC2_PY36_CU112, ANYSCALE_RAY_1_9_0RC2_PY37, ANYSCALE_RAY_1_9_0RC2_PY37_CU101, ANYSCALE_RAY_1_9_0RC2_PY37_CU102, ANYSCALE_RAY_1_9_0RC2_PY37_CU110, ANYSCALE_RAY_1_9_0RC2_PY37_CU111, ANYSCALE_RAY_1_9_0RC2_PY37_CU112, ANYSCALE_RAY_1_9_0RC2_PY38, ANYSCALE_RAY_1_9_0RC2_PY38_CU101, ANYSCALE_RAY_1_9_0RC2_PY38_CU102, ANYSCALE_RAY_1_9_0RC2_PY38_CU110, ANYSCALE_RAY_1_9_0RC2_PY38_CU111, ANYSCALE_RAY_1_9_0RC2_PY38_CU112, ANYSCALE_RAY_1_9_1_PY36, ANYSCALE_RAY_1_9_1_PY36_CU101, ANYSCALE_RAY_1_9_1_PY36_CU102, ANYSCALE_RAY_1_9_1_PY36_CU110, ANYSCALE_RAY_1_9_1_PY36_CU111, ANYSCALE_RAY_1_9_1_PY36_CU112, ANYSCALE_RAY_1_9_1_PY37, ANYSCALE_RAY_1_9_1_PY37_CU101, ANYSCALE_RAY_1_9_1_PY37_CU102, ANYSCALE_RAY_1_9_1_PY37_CU110, ANYSCALE_RAY_1_9_1_PY37_CU111, ANYSCALE_RAY_1_9_1_PY37_CU112, ANYSCALE_RAY_1_9_1_PY38, ANYSCALE_RAY_1_9_1_PY38_CU101, ANYSCALE_RAY_1_9_1_PY38_CU102, ANYSCALE_RAY_1_9_1_PY38_CU110, ANYSCALE_RAY_1_9_1_PY38_CU111, ANYSCALE_RAY_1_9_1_PY38_CU112, ANYSCALE_RAY_1_9_1_PY39, ANYSCALE_RAY_1_9_1_PY39_CU101, ANYSCALE_RAY_1_9_1_PY39_CU102, ANYSCALE_RAY_1_9_1_PY39_CU110, ANYSCALE_RAY_1_9_1_PY39_CU111, ANYSCALE_RAY_1_9_1_PY39_CU112, ANYSCALE_RAY_1_9_1RC0_PY36, ANYSCALE_RAY_1_9_1RC0_PY36_CU101, ANYSCALE_RAY_1_9_1RC0_PY36_CU102, ANYSCALE_RAY_1_9_1RC0_PY36_CU110, ANYSCALE_RAY_1_9_1RC0_PY36_CU111, ANYSCALE_RAY_1_9_1RC0_PY36_CU112, ANYSCALE_RAY_1_9_1RC0_PY37, ANYSCALE_RAY_1_9_1RC0_PY37_CU101, ANYSCALE_RAY_1_9_1RC0_PY37_CU102, ANYSCALE_RAY_1_9_1RC0_PY37_CU110, ANYSCALE_RAY_1_9_1RC0_PY37_CU111, ANYSCALE_RAY_1_9_1RC0_PY37_CU112, ANYSCALE_RAY_1_9_1RC0_PY38, ANYSCALE_RAY_1_9_1RC0_PY38_CU101, ANYSCALE_RAY_1_9_1RC0_PY38_CU102, ANYSCALE_RAY_1_9_1RC0_PY38_CU110, ANYSCALE_RAY_1_9_1RC0_PY38_CU111, ANYSCALE_RAY_1_9_1RC0_PY38_CU112, ANYSCALE_RAY_1_9_2_PY36, ANYSCALE_RAY_1_9_2_PY36_CU101, ANYSCALE_RAY_1_9_2_PY36_CU102, ANYSCALE_RAY_1_9_2_PY36_CU110, ANYSCALE_RAY_1_9_2_PY36_CU111, ANYSCALE_RAY_1_9_2_PY36_CU112, ANYSCALE_RAY_1_9_2_PY37, ANYSCALE_RAY_1_9_2_PY37_CU101, ANYSCALE_RAY_1_9_2_PY37_CU102, ANYSCALE_RAY_1_9_2_PY37_CU110, ANYSCALE_RAY_1_9_2_PY37_CU111, ANYSCALE_RAY_1_9_2_PY37_CU112, ANYSCALE_RAY_1_9_2_PY38, ANYSCALE_RAY_1_9_2_PY38_CU101, ANYSCALE_RAY_1_9_2_PY38_CU102, ANYSCALE_RAY_1_9_2_PY38_CU110, ANYSCALE_RAY_1_9_2_PY38_CU111, ANYSCALE_RAY_1_9_2_PY38_CU112, ANYSCALE_RAY_1_9_2_PY39, ANYSCALE_RAY_1_9_2_PY39_CU101, ANYSCALE_RAY_1_9_2_PY39_CU102, ANYSCALE_RAY_1_9_2_PY39_CU110, ANYSCALE_RAY_1_9_2_PY39_CU111, ANYSCALE_RAY_1_9_2_PY39_CU112, ANYSCALE_RAY_2_0_0_PY310, ANYSCALE_RAY_2_0_0_PY36, ANYSCALE_RAY_2_0_0_PY36_CU101, ANYSCALE_RAY_2_0_0_PY36_CU102, ANYSCALE_RAY_2_0_0_PY36_CU110, ANYSCALE_RAY_2_0_0_PY36_CU111, ANYSCALE_RAY_2_0_0_PY36_CU112, ANYSCALE_RAY_2_0_0_PY36_CU113, ANYSCALE_RAY_2_0_0_PY37, ANYSCALE_RAY_2_0_0_PY37_CU101, ANYSCALE_RAY_2_0_0_PY37_CU102, ANYSCALE_RAY_2_0_0_PY37_CU110, ANYSCALE_RAY_2_0_0_PY37_CU111, ANYSCALE_RAY_2_0_0_PY37_CU112, ANYSCALE_RAY_2_0_0_PY37_CU113, ANYSCALE_RAY_2_0_0_PY38, ANYSCALE_RAY_2_0_0_PY38_CU101, ANYSCALE_RAY_2_0_0_PY38_CU102, ANYSCALE_RAY_2_0_0_PY38_CU110, ANYSCALE_RAY_2_0_0_PY38_CU111, ANYSCALE_RAY_2_0_0_PY38_CU112, ANYSCALE_RAY_2_0_0_PY38_CU113, ANYSCALE_RAY_2_0_0_PY39, ANYSCALE_RAY_2_0_0_PY39_CU101, ANYSCALE_RAY_2_0_0_PY39_CU102, ANYSCALE_RAY_2_0_0_PY39_CU110, ANYSCALE_RAY_2_0_0_PY39_CU111, ANYSCALE_RAY_2_0_0_PY39_CU112, ANYSCALE_RAY_2_0_0_PY39_CU113, ANYSCALE_RAY_2_0_0RC0_PY310, ANYSCALE_RAY_2_0_0RC0_PY36, ANYSCALE_RAY_2_0_0RC0_PY36_CU101, ANYSCALE_RAY_2_0_0RC0_PY36_CU102, ANYSCALE_RAY_2_0_0RC0_PY36_CU110, ANYSCALE_RAY_2_0_0RC0_PY36_CU111, ANYSCALE_RAY_2_0_0RC0_PY36_CU112, ANYSCALE_RAY_2_0_0RC0_PY37, ANYSCALE_RAY_2_0_0RC0_PY37_CU101, ANYSCALE_RAY_2_0_0RC0_PY37_CU102, ANYSCALE_RAY_2_0_0RC0_PY37_CU110, ANYSCALE_RAY_2_0_0RC0_PY37_CU111, ANYSCALE_RAY_2_0_0RC0_PY37_CU112, ANYSCALE_RAY_2_0_0RC0_PY38, ANYSCALE_RAY_2_0_0RC0_PY38_CU101, ANYSCALE_RAY_2_0_0RC0_PY38_CU102, ANYSCALE_RAY_2_0_0RC0_PY38_CU110, ANYSCALE_RAY_2_0_0RC0_PY38_CU111, ANYSCALE_RAY_2_0_0RC0_PY38_CU112, ANYSCALE_RAY_2_0_0RC0_PY39, ANYSCALE_RAY_2_0_0RC0_PY39_CU101, ANYSCALE_RAY_2_0_0RC0_PY39_CU102, ANYSCALE_RAY_2_0_0RC0_PY39_CU110, ANYSCALE_RAY_2_0_0RC0_PY39_CU111, ANYSCALE_RAY_2_0_0RC0_PY39_CU112, ANYSCALE_RAY_2_0_0RC1_PY310, ANYSCALE_RAY_2_0_0RC1_PY36, ANYSCALE_RAY_2_0_0RC1_PY36_CU101, ANYSCALE_RAY_2_0_0RC1_PY36_CU102, ANYSCALE_RAY_2_0_0RC1_PY36_CU110, ANYSCALE_RAY_2_0_0RC1_PY36_CU111, ANYSCALE_RAY_2_0_0RC1_PY36_CU112, ANYSCALE_RAY_2_0_0RC1_PY37, ANYSCALE_RAY_2_0_0RC1_PY37_CU101, ANYSCALE_RAY_2_0_0RC1_PY37_CU102, ANYSCALE_RAY_2_0_0RC1_PY37_CU110, ANYSCALE_RAY_2_0_0RC1_PY37_CU111, ANYSCALE_RAY_2_0_0RC1_PY37_CU112, ANYSCALE_RAY_2_0_0RC1_PY38, ANYSCALE_RAY_2_0_0RC1_PY38_CU101, ANYSCALE_RAY_2_0_0RC1_PY38_CU102, ANYSCALE_RAY_2_0_0RC1_PY38_CU110, ANYSCALE_RAY_2_0_0RC1_PY38_CU111, ANYSCALE_RAY_2_0_0RC1_PY38_CU112, ANYSCALE_RAY_2_0_0RC1_PY39, ANYSCALE_RAY_2_0_0RC1_PY39_CU101, ANYSCALE_RAY_2_0_0RC1_PY39_CU102, ANYSCALE_RAY_2_0_0RC1_PY39_CU110, ANYSCALE_RAY_2_0_0RC1_PY39_CU111, ANYSCALE_RAY_2_0_0RC1_PY39_CU112, ANYSCALE_RAY_2_0_1_PY310, ANYSCALE_RAY_2_0_1_PY36, ANYSCALE_RAY_2_0_1_PY36_CU101, ANYSCALE_RAY_2_0_1_PY36_CU102, ANYSCALE_RAY_2_0_1_PY36_CU110, ANYSCALE_RAY_2_0_1_PY36_CU111, ANYSCALE_RAY_2_0_1_PY36_CU112, ANYSCALE_RAY_2_0_1_PY36_CU113, ANYSCALE_RAY_2_0_1_PY36_CU116, ANYSCALE_RAY_2_0_1_PY37, ANYSCALE_RAY_2_0_1_PY37_CU101, ANYSCALE_RAY_2_0_1_PY37_CU102, ANYSCALE_RAY_2_0_1_PY37_CU110, ANYSCALE_RAY_2_0_1_PY37_CU111, ANYSCALE_RAY_2_0_1_PY37_CU112, ANYSCALE_RAY_2_0_1_PY37_CU113, ANYSCALE_RAY_2_0_1_PY37_CU116, ANYSCALE_RAY_2_0_1_PY38, ANYSCALE_RAY_2_0_1_PY38_CU101, ANYSCALE_RAY_2_0_1_PY38_CU102, ANYSCALE_RAY_2_0_1_PY38_CU110, ANYSCALE_RAY_2_0_1_PY38_CU111, ANYSCALE_RAY_2_0_1_PY38_CU112, ANYSCALE_RAY_2_0_1_PY38_CU113, ANYSCALE_RAY_2_0_1_PY38_CU116, ANYSCALE_RAY_2_0_1_PY39, ANYSCALE_RAY_2_0_1_PY39_CU101, ANYSCALE_RAY_2_0_1_PY39_CU102, ANYSCALE_RAY_2_0_1_PY39_CU110, ANYSCALE_RAY_2_0_1_PY39_CU111, ANYSCALE_RAY_2_0_1_PY39_CU112, ANYSCALE_RAY_2_0_1_PY39_CU113, ANYSCALE_RAY_2_0_1_PY39_CU116, ANYSCALE_RAY_2_1_0_PY310, ANYSCALE_RAY_2_1_0_PY310_CU101, ANYSCALE_RAY_2_1_0_PY310_CU102, ANYSCALE_RAY_2_1_0_PY310_CU110, ANYSCALE_RAY_2_1_0_PY310_CU111, ANYSCALE_RAY_2_1_0_PY310_CU112, ANYSCALE_RAY_2_1_0_PY310_CU113, ANYSCALE_RAY_2_1_0_PY310_CU116, ANYSCALE_RAY_2_1_0_PY36, ANYSCALE_RAY_2_1_0_PY36_CU101, ANYSCALE_RAY_2_1_0_PY36_CU102, ANYSCALE_RAY_2_1_0_PY36_CU110, ANYSCALE_RAY_2_1_0_PY36_CU111, ANYSCALE_RAY_2_1_0_PY36_CU112, ANYSCALE_RAY_2_1_0_PY36_CU113, ANYSCALE_RAY_2_1_0_PY36_CU116, ANYSCALE_RAY_2_1_0_PY37, ANYSCALE_RAY_2_1_0_PY37_CU101, ANYSCALE_RAY_2_1_0_PY37_CU102, ANYSCALE_RAY_2_1_0_PY37_CU110, ANYSCALE_RAY_2_1_0_PY37_CU111, ANYSCALE_RAY_2_1_0_PY37_CU112, ANYSCALE_RAY_2_1_0_PY37_CU113, ANYSCALE_RAY_2_1_0_PY37_CU116, ANYSCALE_RAY_2_1_0_PY38, ANYSCALE_RAY_2_1_0_PY38_CU101, ANYSCALE_RAY_2_1_0_PY38_CU102, ANYSCALE_RAY_2_1_0_PY38_CU110, ANYSCALE_RAY_2_1_0_PY38_CU111, ANYSCALE_RAY_2_1_0_PY38_CU112, ANYSCALE_RAY_2_1_0_PY38_CU113, ANYSCALE_RAY_2_1_0_PY38_CU116, ANYSCALE_RAY_2_1_0_PY39, ANYSCALE_RAY_2_1_0_PY39_CU101, ANYSCALE_RAY_2_1_0_PY39_CU102, ANYSCALE_RAY_2_1_0_PY39_CU110, ANYSCALE_RAY_2_1_0_PY39_CU111, ANYSCALE_RAY_2_1_0_PY39_CU112, ANYSCALE_RAY_2_1_0_PY39_CU113, ANYSCALE_RAY_2_1_0_PY39_CU116, ANYSCALE_RAY_2_10_0_PY310, ANYSCALE_RAY_2_10_0_PY310_CU115, ANYSCALE_RAY_2_10_0_PY310_CU116, ANYSCALE_RAY_2_10_0_PY310_CU117, ANYSCALE_RAY_2_10_0_PY310_CU118, ANYSCALE_RAY_2_10_0_PY310_CU121, ANYSCALE_RAY_2_10_0_PY311, ANYSCALE_RAY_2_10_0_PY311_CU115, ANYSCALE_RAY_2_10_0_PY311_CU116, ANYSCALE_RAY_2_10_0_PY311_CU117, ANYSCALE_RAY_2_10_0_PY311_CU118, ANYSCALE_RAY_2_10_0_PY311_CU121, ANYSCALE_RAY_2_10_0_PY38, ANYSCALE_RAY_2_10_0_PY38_CU115, ANYSCALE_RAY_2_10_0_PY38_CU116, ANYSCALE_RAY_2_10_0_PY38_CU117, ANYSCALE_RAY_2_10_0_PY38_CU118, ANYSCALE_RAY_2_10_0_PY38_CU121, ANYSCALE_RAY_2_10_0_PY39, ANYSCALE_RAY_2_10_0_PY39_CU115, ANYSCALE_RAY_2_10_0_PY39_CU116, ANYSCALE_RAY_2_10_0_PY39_CU117, ANYSCALE_RAY_2_10_0_PY39_CU118, ANYSCALE_RAY_2_10_0_PY39_CU121, ANYSCALE_RAY_2_11_0_PY310, ANYSCALE_RAY_2_11_0_PY310_CU115, ANYSCALE_RAY_2_11_0_PY310_CU116, ANYSCALE_RAY_2_11_0_PY310_CU117, ANYSCALE_RAY_2_11_0_PY310_CU118, ANYSCALE_RAY_2_11_0_PY310_CU121, ANYSCALE_RAY_2_11_0_PY311, ANYSCALE_RAY_2_11_0_PY311_CU115, ANYSCALE_RAY_2_11_0_PY311_CU116, ANYSCALE_RAY_2_11_0_PY311_CU117, ANYSCALE_RAY_2_11_0_PY311_CU118, ANYSCALE_RAY_2_11_0_PY311_CU121, ANYSCALE_RAY_2_11_0_PY39, ANYSCALE_RAY_2_11_0_PY39_CU115, ANYSCALE_RAY_2_11_0_PY39_CU116, ANYSCALE_RAY_2_11_0_PY39_CU117, ANYSCALE_RAY_2_11_0_PY39_CU118, ANYSCALE_RAY_2_11_0_PY39_CU121, ANYSCALE_RAY_2_12_0_PY310, ANYSCALE_RAY_2_12_0_PY310_CU115, ANYSCALE_RAY_2_12_0_PY310_CU116, ANYSCALE_RAY_2_12_0_PY310_CU117, ANYSCALE_RAY_2_12_0_PY310_CU118, ANYSCALE_RAY_2_12_0_PY310_CU121, ANYSCALE_RAY_2_12_0_PY311, ANYSCALE_RAY_2_12_0_PY311_CU115, ANYSCALE_RAY_2_12_0_PY311_CU116, ANYSCALE_RAY_2_12_0_PY311_CU117, ANYSCALE_RAY_2_12_0_PY311_CU118, ANYSCALE_RAY_2_12_0_PY311_CU121, ANYSCALE_RAY_2_12_0_PY39, ANYSCALE_RAY_2_12_0_PY39_CU115, ANYSCALE_RAY_2_12_0_PY39_CU116, ANYSCALE_RAY_2_12_0_PY39_CU117, ANYSCALE_RAY_2_12_0_PY39_CU118, ANYSCALE_RAY_2_12_0_PY39_CU121, ANYSCALE_RAY_2_12_0_SLIM_PY310, ANYSCALE_RAY_2_12_0_SLIM_PY310_CU118, ANYSCALE_RAY_2_12_0_SLIM_PY310_CU121, ANYSCALE_RAY_2_12_0_SLIM_PY311, ANYSCALE_RAY_2_12_0_SLIM_PY311_CU118, ANYSCALE_RAY_2_12_0_SLIM_PY311_CU121, ANYSCALE_RAY_2_12_0_SLIM_PY39, ANYSCALE_RAY_2_12_0_SLIM_PY39_CU118, ANYSCALE_RAY_2_12_0_SLIM_PY39_CU121, ANYSCALE_RAY_2_2_0_PY310, ANYSCALE_RAY_2_2_0_PY310_CU101, ANYSCALE_RAY_2_2_0_PY310_CU102, ANYSCALE_RAY_2_2_0_PY310_CU110, ANYSCALE_RAY_2_2_0_PY310_CU111, ANYSCALE_RAY_2_2_0_PY310_CU112, ANYSCALE_RAY_2_2_0_PY310_CU113, ANYSCALE_RAY_2_2_0_PY310_CU116, ANYSCALE_RAY_2_2_0_PY37, ANYSCALE_RAY_2_2_0_PY37_CU101, ANYSCALE_RAY_2_2_0_PY37_CU102, ANYSCALE_RAY_2_2_0_PY37_CU110, ANYSCALE_RAY_2_2_0_PY37_CU111, ANYSCALE_RAY_2_2_0_PY37_CU112, ANYSCALE_RAY_2_2_0_PY37_CU113, ANYSCALE_RAY_2_2_0_PY37_CU116, ANYSCALE_RAY_2_2_0_PY38, ANYSCALE_RAY_2_2_0_PY38_CU101, ANYSCALE_RAY_2_2_0_PY38_CU102, ANYSCALE_RAY_2_2_0_PY38_CU110, ANYSCALE_RAY_2_2_0_PY38_CU111, ANYSCALE_RAY_2_2_0_PY38_CU112, ANYSCALE_RAY_2_2_0_PY38_CU113, ANYSCALE_RAY_2_2_0_PY38_CU116, ANYSCALE_RAY_2_2_0_PY39, ANYSCALE_RAY_2_2_0_PY39_CU101, ANYSCALE_RAY_2_2_0_PY39_CU102, ANYSCALE_RAY_2_2_0_PY39_CU110, ANYSCALE_RAY_2_2_0_PY39_CU111, ANYSCALE_RAY_2_2_0_PY39_CU112, ANYSCALE_RAY_2_2_0_PY39_CU113, ANYSCALE_RAY_2_2_0_PY39_CU116, ANYSCALE_RAY_2_20_0_PY310, ANYSCALE_RAY_2_20_0_PY310_CU115, ANYSCALE_RAY_2_20_0_PY310_CU116, ANYSCALE_RAY_2_20_0_PY310_CU117, ANYSCALE_RAY_2_20_0_PY310_CU118, ANYSCALE_RAY_2_20_0_PY310_CU121, ANYSCALE_RAY_2_20_0_PY311, ANYSCALE_RAY_2_20_0_PY311_CU115, ANYSCALE_RAY_2_20_0_PY311_CU116, ANYSCALE_RAY_2_20_0_PY311_CU117, ANYSCALE_RAY_2_20_0_PY311_CU118, ANYSCALE_RAY_2_20_0_PY311_CU121, ANYSCALE_RAY_2_20_0_PY39, ANYSCALE_RAY_2_20_0_PY39_CU115, ANYSCALE_RAY_2_20_0_PY39_CU116, ANYSCALE_RAY_2_20_0_PY39_CU117, ANYSCALE_RAY_2_20_0_PY39_CU118, ANYSCALE_RAY_2_20_0_PY39_CU121, ANYSCALE_RAY_2_20_0_SLIM_PY310, ANYSCALE_RAY_2_20_0_SLIM_PY310_CU118, ANYSCALE_RAY_2_20_0_SLIM_PY310_CU121, ANYSCALE_RAY_2_20_0_SLIM_PY311, ANYSCALE_RAY_2_20_0_SLIM_PY311_CU118, ANYSCALE_RAY_2_20_0_SLIM_PY311_CU121, ANYSCALE_RAY_2_20_0_SLIM_PY39, ANYSCALE_RAY_2_20_0_SLIM_PY39_CU118, ANYSCALE_RAY_2_20_0_SLIM_PY39_CU121, ANYSCALE_RAY_2_21_0_PY310, ANYSCALE_RAY_2_21_0_PY310_CU115, ANYSCALE_RAY_2_21_0_PY310_CU116, ANYSCALE_RAY_2_21_0_PY310_CU117, ANYSCALE_RAY_2_21_0_PY310_CU118, ANYSCALE_RAY_2_21_0_PY310_CU121, ANYSCALE_RAY_2_21_0_PY311, ANYSCALE_RAY_2_21_0_PY311_CU115, ANYSCALE_RAY_2_21_0_PY311_CU116, ANYSCALE_RAY_2_21_0_PY311_CU117, ANYSCALE_RAY_2_21_0_PY311_CU118, ANYSCALE_RAY_2_21_0_PY311_CU121, ANYSCALE_RAY_2_21_0_PY39, ANYSCALE_RAY_2_21_0_PY39_CU115, ANYSCALE_RAY_2_21_0_PY39_CU116, ANYSCALE_RAY_2_21_0_PY39_CU117, ANYSCALE_RAY_2_21_0_PY39_CU118, ANYSCALE_RAY_2_21_0_PY39_CU121, ANYSCALE_RAY_2_21_0_SLIM_PY310, ANYSCALE_RAY_2_21_0_SLIM_PY310_CU118, ANYSCALE_RAY_2_21_0_SLIM_PY310_CU121, ANYSCALE_RAY_2_21_0_SLIM_PY311, ANYSCALE_RAY_2_21_0_SLIM_PY311_CU118, ANYSCALE_RAY_2_21_0_SLIM_PY311_CU121, ANYSCALE_RAY_2_21_0_SLIM_PY39, ANYSCALE_RAY_2_21_0_SLIM_PY39_CU118, ANYSCALE_RAY_2_21_0_SLIM_PY39_CU121, ANYSCALE_RAY_2_22_0_PY310, ANYSCALE_RAY_2_22_0_PY310_CU115, ANYSCALE_RAY_2_22_0_PY310_CU116, ANYSCALE_RAY_2_22_0_PY310_CU117, ANYSCALE_RAY_2_22_0_PY310_CU118, ANYSCALE_RAY_2_22_0_PY310_CU121, ANYSCALE_RAY_2_22_0_PY311, ANYSCALE_RAY_2_22_0_PY311_CU115, ANYSCALE_RAY_2_22_0_PY311_CU116, ANYSCALE_RAY_2_22_0_PY311_CU117, ANYSCALE_RAY_2_22_0_PY311_CU118, ANYSCALE_RAY_2_22_0_PY311_CU121, ANYSCALE_RAY_2_22_0_PY39, ANYSCALE_RAY_2_22_0_PY39_CU115, ANYSCALE_RAY_2_22_0_PY39_CU116, ANYSCALE_RAY_2_22_0_PY39_CU117, ANYSCALE_RAY_2_22_0_PY39_CU118, ANYSCALE_RAY_2_22_0_PY39_CU121, ANYSCALE_RAY_2_22_0_SLIM_PY310, ANYSCALE_RAY_2_22_0_SLIM_PY310_CU118, ANYSCALE_RAY_2_22_0_SLIM_PY310_CU121, ANYSCALE_RAY_2_22_0_SLIM_PY311, ANYSCALE_RAY_2_22_0_SLIM_PY311_CU118, ANYSCALE_RAY_2_22_0_SLIM_PY311_CU121, ANYSCALE_RAY_2_22_0_SLIM_PY39, ANYSCALE_RAY_2_22_0_SLIM_PY39_CU118, ANYSCALE_RAY_2_22_0_SLIM_PY39_CU121, ANYSCALE_RAY_2_23_0_PY310, ANYSCALE_RAY_2_23_0_PY310_CU115, ANYSCALE_RAY_2_23_0_PY310_CU116, ANYSCALE_RAY_2_23_0_PY310_CU117, ANYSCALE_RAY_2_23_0_PY310_CU118, ANYSCALE_RAY_2_23_0_PY310_CU121, ANYSCALE_RAY_2_23_0_PY311, ANYSCALE_RAY_2_23_0_PY311_CU115, ANYSCALE_RAY_2_23_0_PY311_CU116, ANYSCALE_RAY_2_23_0_PY311_CU117, ANYSCALE_RAY_2_23_0_PY311_CU118, ANYSCALE_RAY_2_23_0_PY311_CU121, ANYSCALE_RAY_2_23_0_PY39, ANYSCALE_RAY_2_23_0_PY39_CU115, ANYSCALE_RAY_2_23_0_PY39_CU116, ANYSCALE_RAY_2_23_0_PY39_CU117, ANYSCALE_RAY_2_23_0_PY39_CU118, ANYSCALE_RAY_2_23_0_PY39_CU121, ANYSCALE_RAY_2_23_0_SLIM_PY310, ANYSCALE_RAY_2_23_0_SLIM_PY310_CU118, ANYSCALE_RAY_2_23_0_SLIM_PY310_CU121, ANYSCALE_RAY_2_23_0_SLIM_PY311, ANYSCALE_RAY_2_23_0_SLIM_PY311_CU118, ANYSCALE_RAY_2_23_0_SLIM_PY311_CU121, ANYSCALE_RAY_2_23_0_SLIM_PY39, ANYSCALE_RAY_2_23_0_SLIM_PY39_CU118, ANYSCALE_RAY_2_23_0_SLIM_PY39_CU121, ANYSCALE_RAY_2_24_0_PY310, ANYSCALE_RAY_2_24_0_PY310_CU115, ANYSCALE_RAY_2_24_0_PY310_CU116, ANYSCALE_RAY_2_24_0_PY310_CU117, ANYSCALE_RAY_2_24_0_PY310_CU118, ANYSCALE_RAY_2_24_0_PY310_CU121, ANYSCALE_RAY_2_24_0_PY311, ANYSCALE_RAY_2_24_0_PY311_CU115, ANYSCALE_RAY_2_24_0_PY311_CU116, ANYSCALE_RAY_2_24_0_PY311_CU117, ANYSCALE_RAY_2_24_0_PY311_CU118, ANYSCALE_RAY_2_24_0_PY311_CU121, ANYSCALE_RAY_2_24_0_PY39, ANYSCALE_RAY_2_24_0_PY39_CU115, ANYSCALE_RAY_2_24_0_PY39_CU116, ANYSCALE_RAY_2_24_0_PY39_CU117, ANYSCALE_RAY_2_24_0_PY39_CU118, ANYSCALE_RAY_2_24_0_PY39_CU121, ANYSCALE_RAY_2_24_0_SLIM_PY310, ANYSCALE_RAY_2_24_0_SLIM_PY310_CU118, ANYSCALE_RAY_2_24_0_SLIM_PY310_CU121, ANYSCALE_RAY_2_24_0_SLIM_PY311, ANYSCALE_RAY_2_24_0_SLIM_PY311_CU118, ANYSCALE_RAY_2_24_0_SLIM_PY311_CU121, ANYSCALE_RAY_2_24_0_SLIM_PY39, ANYSCALE_RAY_2_24_0_SLIM_PY39_CU118, ANYSCALE_RAY_2_24_0_SLIM_PY39_CU121, ANYSCALE_RAY_2_3_0_PY310, ANYSCALE_RAY_2_3_0_PY310_CU101, ANYSCALE_RAY_2_3_0_PY310_CU102, ANYSCALE_RAY_2_3_0_PY310_CU110, ANYSCALE_RAY_2_3_0_PY310_CU111, ANYSCALE_RAY_2_3_0_PY310_CU112, ANYSCALE_RAY_2_3_0_PY310_CU113, ANYSCALE_RAY_2_3_0_PY310_CU116, ANYSCALE_RAY_2_3_0_PY310_CU118, ANYSCALE_RAY_2_3_0_PY37, ANYSCALE_RAY_2_3_0_PY37_CU101, ANYSCALE_RAY_2_3_0_PY37_CU102, ANYSCALE_RAY_2_3_0_PY37_CU110, ANYSCALE_RAY_2_3_0_PY37_CU111, ANYSCALE_RAY_2_3_0_PY37_CU112, ANYSCALE_RAY_2_3_0_PY37_CU113, ANYSCALE_RAY_2_3_0_PY37_CU116, ANYSCALE_RAY_2_3_0_PY37_CU118, ANYSCALE_RAY_2_3_0_PY38, ANYSCALE_RAY_2_3_0_PY38_CU101, ANYSCALE_RAY_2_3_0_PY38_CU102, ANYSCALE_RAY_2_3_0_PY38_CU110, ANYSCALE_RAY_2_3_0_PY38_CU111, ANYSCALE_RAY_2_3_0_PY38_CU112, ANYSCALE_RAY_2_3_0_PY38_CU113, ANYSCALE_RAY_2_3_0_PY38_CU116, ANYSCALE_RAY_2_3_0_PY38_CU118, ANYSCALE_RAY_2_3_0_PY39, ANYSCALE_RAY_2_3_0_PY39_CU101, ANYSCALE_RAY_2_3_0_PY39_CU102, ANYSCALE_RAY_2_3_0_PY39_CU110, ANYSCALE_RAY_2_3_0_PY39_CU111, ANYSCALE_RAY_2_3_0_PY39_CU112, ANYSCALE_RAY_2_3_0_PY39_CU113, ANYSCALE_RAY_2_3_0_PY39_CU116, ANYSCALE_RAY_2_3_0_PY39_CU118, ANYSCALE_RAY_2_3_1_PY310, ANYSCALE_RAY_2_3_1_PY310_CU101, ANYSCALE_RAY_2_3_1_PY310_CU102, ANYSCALE_RAY_2_3_1_PY310_CU110, ANYSCALE_RAY_2_3_1_PY310_CU111, ANYSCALE_RAY_2_3_1_PY310_CU112, ANYSCALE_RAY_2_3_1_PY310_CU113, ANYSCALE_RAY_2_3_1_PY310_CU116, ANYSCALE_RAY_2_3_1_PY310_CU118, ANYSCALE_RAY_2_3_1_PY37, ANYSCALE_RAY_2_3_1_PY37_CU101, ANYSCALE_RAY_2_3_1_PY37_CU102, ANYSCALE_RAY_2_3_1_PY37_CU110, ANYSCALE_RAY_2_3_1_PY37_CU111, ANYSCALE_RAY_2_3_1_PY37_CU112, ANYSCALE_RAY_2_3_1_PY37_CU113, ANYSCALE_RAY_2_3_1_PY37_CU116, ANYSCALE_RAY_2_3_1_PY37_CU118, ANYSCALE_RAY_2_3_1_PY38, ANYSCALE_RAY_2_3_1_PY38_CU101, ANYSCALE_RAY_2_3_1_PY38_CU102, ANYSCALE_RAY_2_3_1_PY38_CU110, ANYSCALE_RAY_2_3_1_PY38_CU111, ANYSCALE_RAY_2_3_1_PY38_CU112, ANYSCALE_RAY_2_3_1_PY38_CU113, ANYSCALE_RAY_2_3_1_PY38_CU116, ANYSCALE_RAY_2_3_1_PY38_CU118, ANYSCALE_RAY_2_3_1_PY39, ANYSCALE_RAY_2_3_1_PY39_CU101, ANYSCALE_RAY_2_3_1_PY39_CU102, ANYSCALE_RAY_2_3_1_PY39_CU110, ANYSCALE_RAY_2_3_1_PY39_CU111, ANYSCALE_RAY_2_3_1_PY39_CU112, ANYSCALE_RAY_2_3_1_PY39_CU113, ANYSCALE_RAY_2_3_1_PY39_CU116, ANYSCALE_RAY_2_3_1_PY39_CU118, ANYSCALE_RAY_2_30_0_PY310, ANYSCALE_RAY_2_30_0_PY310_CU117, ANYSCALE_RAY_2_30_0_PY310_CU118, ANYSCALE_RAY_2_30_0_PY310_CU121, ANYSCALE_RAY_2_30_0_PY310_CU123, ANYSCALE_RAY_2_30_0_PY311, ANYSCALE_RAY_2_30_0_PY311_CU117, ANYSCALE_RAY_2_30_0_PY311_CU118, ANYSCALE_RAY_2_30_0_PY311_CU121, ANYSCALE_RAY_2_30_0_PY311_CU123, ANYSCALE_RAY_2_30_0_PY39, ANYSCALE_RAY_2_30_0_PY39_CU117, ANYSCALE_RAY_2_30_0_PY39_CU118, ANYSCALE_RAY_2_30_0_PY39_CU121, ANYSCALE_RAY_2_30_0_PY39_CU123, ANYSCALE_RAY_2_30_0_SLIM_PY310, ANYSCALE_RAY_2_30_0_SLIM_PY310_CU118, ANYSCALE_RAY_2_30_0_SLIM_PY310_CU121, ANYSCALE_RAY_2_30_0_SLIM_PY310_CU123, ANYSCALE_RAY_2_30_0_SLIM_PY311, ANYSCALE_RAY_2_30_0_SLIM_PY311_CU118, ANYSCALE_RAY_2_30_0_SLIM_PY311_CU121, ANYSCALE_RAY_2_30_0_SLIM_PY311_CU123, ANYSCALE_RAY_2_30_0_SLIM_PY39, ANYSCALE_RAY_2_30_0_SLIM_PY39_CU118, ANYSCALE_RAY_2_30_0_SLIM_PY39_CU121, ANYSCALE_RAY_2_30_0_SLIM_PY39_CU123, ANYSCALE_RAY_2_31_0_PY310, ANYSCALE_RAY_2_31_0_PY310_CU117, ANYSCALE_RAY_2_31_0_PY310_CU118, ANYSCALE_RAY_2_31_0_PY310_CU121, ANYSCALE_RAY_2_31_0_PY310_CU123, ANYSCALE_RAY_2_31_0_PY311, ANYSCALE_RAY_2_31_0_PY311_CU117, ANYSCALE_RAY_2_31_0_PY311_CU118, ANYSCALE_RAY_2_31_0_PY311_CU121, ANYSCALE_RAY_2_31_0_PY311_CU123, ANYSCALE_RAY_2_31_0_PY39, ANYSCALE_RAY_2_31_0_PY39_CU117, ANYSCALE_RAY_2_31_0_PY39_CU118, ANYSCALE_RAY_2_31_0_PY39_CU121, ANYSCALE_RAY_2_31_0_PY39_CU123, ANYSCALE_RAY_2_31_0_SLIM_PY310, ANYSCALE_RAY_2_31_0_SLIM_PY310_CU118, ANYSCALE_RAY_2_31_0_SLIM_PY310_CU121, ANYSCALE_RAY_2_31_0_SLIM_PY310_CU123, ANYSCALE_RAY_2_31_0_SLIM_PY311, ANYSCALE_RAY_2_31_0_SLIM_PY311_CU118, ANYSCALE_RAY_2_31_0_SLIM_PY311_CU121, ANYSCALE_RAY_2_31_0_SLIM_PY311_CU123, ANYSCALE_RAY_2_31_0_SLIM_PY39, ANYSCALE_RAY_2_31_0_SLIM_PY39_CU118, ANYSCALE_RAY_2_31_0_SLIM_PY39_CU121, ANYSCALE_RAY_2_31_0_SLIM_PY39_CU123, ANYSCALE_RAY_2_32_0_PY310, ANYSCALE_RAY_2_32_0_PY310_CU117, ANYSCALE_RAY_2_32_0_PY310_CU118, ANYSCALE_RAY_2_32_0_PY310_CU121, ANYSCALE_RAY_2_32_0_PY310_CU123, ANYSCALE_RAY_2_32_0_PY311, ANYSCALE_RAY_2_32_0_PY311_CU117, ANYSCALE_RAY_2_32_0_PY311_CU118, ANYSCALE_RAY_2_32_0_PY311_CU121, ANYSCALE_RAY_2_32_0_PY311_CU123, ANYSCALE_RAY_2_32_0_PY39, ANYSCALE_RAY_2_32_0_PY39_CU117, ANYSCALE_RAY_2_32_0_PY39_CU118, ANYSCALE_RAY_2_32_0_PY39_CU121, ANYSCALE_RAY_2_32_0_PY39_CU123, ANYSCALE_RAY_2_32_0_SLIM_PY310, ANYSCALE_RAY_2_32_0_SLIM_PY310_CU118, ANYSCALE_RAY_2_32_0_SLIM_PY310_CU121, ANYSCALE_RAY_2_32_0_SLIM_PY310_CU123, ANYSCALE_RAY_2_32_0_SLIM_PY311, ANYSCALE_RAY_2_32_0_SLIM_PY311_CU118, ANYSCALE_RAY_2_32_0_SLIM_PY311_CU121, ANYSCALE_RAY_2_32_0_SLIM_PY311_CU123, ANYSCALE_RAY_2_32_0_SLIM_PY39, ANYSCALE_RAY_2_32_0_SLIM_PY39_CU118, ANYSCALE_RAY_2_32_0_SLIM_PY39_CU121, ANYSCALE_RAY_2_32_0_SLIM_PY39_CU123, ANYSCALE_RAY_2_33_0_PY310, ANYSCALE_RAY_2_33_0_PY310_CU117, ANYSCALE_RAY_2_33_0_PY310_CU118, ANYSCALE_RAY_2_33_0_PY310_CU121, ANYSCALE_RAY_2_33_0_PY310_CU123, ANYSCALE_RAY_2_33_0_PY311, ANYSCALE_RAY_2_33_0_PY311_CU117, ANYSCALE_RAY_2_33_0_PY311_CU118, ANYSCALE_RAY_2_33_0_PY311_CU121, ANYSCALE_RAY_2_33_0_PY311_CU123, ANYSCALE_RAY_2_33_0_PY39, ANYSCALE_RAY_2_33_0_PY39_CU117, ANYSCALE_RAY_2_33_0_PY39_CU118, ANYSCALE_RAY_2_33_0_PY39_CU121, ANYSCALE_RAY_2_33_0_PY39_CU123, ANYSCALE_RAY_2_33_0_SLIM_PY310, ANYSCALE_RAY_2_33_0_SLIM_PY310_CU118, ANYSCALE_RAY_2_33_0_SLIM_PY310_CU121, ANYSCALE_RAY_2_33_0_SLIM_PY310_CU123, ANYSCALE_RAY_2_33_0_SLIM_PY311, ANYSCALE_RAY_2_33_0_SLIM_PY311_CU118, ANYSCALE_RAY_2_33_0_SLIM_PY311_CU121, ANYSCALE_RAY_2_33_0_SLIM_PY311_CU123, ANYSCALE_RAY_2_33_0_SLIM_PY39, ANYSCALE_RAY_2_33_0_SLIM_PY39_CU118, ANYSCALE_RAY_2_33_0_SLIM_PY39_CU121, ANYSCALE_RAY_2_33_0_SLIM_PY39_CU123, ANYSCALE_RAY_2_34_0_PY310, ANYSCALE_RAY_2_34_0_PY310_CU117, ANYSCALE_RAY_2_34_0_PY310_CU118, ANYSCALE_RAY_2_34_0_PY310_CU121, ANYSCALE_RAY_2_34_0_PY310_CU123, ANYSCALE_RAY_2_34_0_PY311, ANYSCALE_RAY_2_34_0_PY311_CU117, ANYSCALE_RAY_2_34_0_PY311_CU118, ANYSCALE_RAY_2_34_0_PY311_CU121, ANYSCALE_RAY_2_34_0_PY311_CU123, ANYSCALE_RAY_2_34_0_PY39, ANYSCALE_RAY_2_34_0_PY39_CU117, ANYSCALE_RAY_2_34_0_PY39_CU118, ANYSCALE_RAY_2_34_0_PY39_CU121, ANYSCALE_RAY_2_34_0_PY39_CU123, ANYSCALE_RAY_2_34_0_SLIM_PY310, ANYSCALE_RAY_2_34_0_SLIM_PY310_CU118, ANYSCALE_RAY_2_34_0_SLIM_PY310_CU121, ANYSCALE_RAY_2_34_0_SLIM_PY310_CU123, ANYSCALE_RAY_2_34_0_SLIM_PY311, ANYSCALE_RAY_2_34_0_SLIM_PY311_CU118, ANYSCALE_RAY_2_34_0_SLIM_PY311_CU121, ANYSCALE_RAY_2_34_0_SLIM_PY311_CU123, ANYSCALE_RAY_2_34_0_SLIM_PY39, ANYSCALE_RAY_2_34_0_SLIM_PY39_CU118, ANYSCALE_RAY_2_34_0_SLIM_PY39_CU121, ANYSCALE_RAY_2_34_0_SLIM_PY39_CU123, ANYSCALE_RAY_2_35_0_PY310, ANYSCALE_RAY_2_35_0_PY310_CU117, ANYSCALE_RAY_2_35_0_PY310_CU118, ANYSCALE_RAY_2_35_0_PY310_CU121, ANYSCALE_RAY_2_35_0_PY310_CU123, ANYSCALE_RAY_2_35_0_PY311, ANYSCALE_RAY_2_35_0_PY311_CU117, ANYSCALE_RAY_2_35_0_PY311_CU118, ANYSCALE_RAY_2_35_0_PY311_CU121, ANYSCALE_RAY_2_35_0_PY311_CU123, ANYSCALE_RAY_2_35_0_PY312, ANYSCALE_RAY_2_35_0_PY312_CU117, ANYSCALE_RAY_2_35_0_PY312_CU118, ANYSCALE_RAY_2_35_0_PY312_CU121, ANYSCALE_RAY_2_35_0_PY312_CU123, ANYSCALE_RAY_2_35_0_PY39, ANYSCALE_RAY_2_35_0_PY39_CU117, ANYSCALE_RAY_2_35_0_PY39_CU118, ANYSCALE_RAY_2_35_0_PY39_CU121, ANYSCALE_RAY_2_35_0_PY39_CU123, ANYSCALE_RAY_2_35_0_SLIM_PY310, ANYSCALE_RAY_2_35_0_SLIM_PY310_CU118, ANYSCALE_RAY_2_35_0_SLIM_PY310_CU121, ANYSCALE_RAY_2_35_0_SLIM_PY310_CU123, ANYSCALE_RAY_2_35_0_SLIM_PY311, ANYSCALE_RAY_2_35_0_SLIM_PY311_CU118, ANYSCALE_RAY_2_35_0_SLIM_PY311_CU121, ANYSCALE_RAY_2_35_0_SLIM_PY311_CU123, ANYSCALE_RAY_2_35_0_SLIM_PY312, ANYSCALE_RAY_2_35_0_SLIM_PY312_CU118, ANYSCALE_RAY_2_35_0_SLIM_PY312_CU121, ANYSCALE_RAY_2_35_0_SLIM_PY312_CU123, ANYSCALE_RAY_2_35_0_SLIM_PY39, ANYSCALE_RAY_2_35_0_SLIM_PY39_CU118, ANYSCALE_RAY_2_35_0_SLIM_PY39_CU121, ANYSCALE_RAY_2_35_0_SLIM_PY39_CU123, ANYSCALE_RAY_2_36_0_PY310, ANYSCALE_RAY_2_36_0_PY310_CU117, ANYSCALE_RAY_2_36_0_PY310_CU118, ANYSCALE_RAY_2_36_0_PY310_CU121, ANYSCALE_RAY_2_36_0_PY310_CU123, ANYSCALE_RAY_2_36_0_PY311, ANYSCALE_RAY_2_36_0_PY311_CU117, ANYSCALE_RAY_2_36_0_PY311_CU118, ANYSCALE_RAY_2_36_0_PY311_CU121, ANYSCALE_RAY_2_36_0_PY311_CU123, ANYSCALE_RAY_2_36_0_PY312, ANYSCALE_RAY_2_36_0_PY312_CU117, ANYSCALE_RAY_2_36_0_PY312_CU118, ANYSCALE_RAY_2_36_0_PY312_CU121, ANYSCALE_RAY_2_36_0_PY312_CU123, ANYSCALE_RAY_2_36_0_PY39, ANYSCALE_RAY_2_36_0_PY39_CU117, ANYSCALE_RAY_2_36_0_PY39_CU118, ANYSCALE_RAY_2_36_0_PY39_CU121, ANYSCALE_RAY_2_36_0_PY39_CU123, ANYSCALE_RAY_2_36_0_SLIM_PY310, ANYSCALE_RAY_2_36_0_SLIM_PY310_CU118, ANYSCALE_RAY_2_36_0_SLIM_PY310_CU121, ANYSCALE_RAY_2_36_0_SLIM_PY310_CU123, ANYSCALE_RAY_2_36_0_SLIM_PY311, ANYSCALE_RAY_2_36_0_SLIM_PY311_CU118, ANYSCALE_RAY_2_36_0_SLIM_PY311_CU121, ANYSCALE_RAY_2_36_0_SLIM_PY311_CU123, ANYSCALE_RAY_2_36_0_SLIM_PY312, ANYSCALE_RAY_2_36_0_SLIM_PY312_CU118, ANYSCALE_RAY_2_36_0_SLIM_PY312_CU121, ANYSCALE_RAY_2_36_0_SLIM_PY312_CU123, ANYSCALE_RAY_2_36_0_SLIM_PY39, ANYSCALE_RAY_2_36_0_SLIM_PY39_CU118, ANYSCALE_RAY_2_36_0_SLIM_PY39_CU121, ANYSCALE_RAY_2_36_0_SLIM_PY39_CU123, ANYSCALE_RAY_2_36_1_PY310, ANYSCALE_RAY_2_36_1_PY310_CU117, ANYSCALE_RAY_2_36_1_PY310_CU118, ANYSCALE_RAY_2_36_1_PY310_CU121, ANYSCALE_RAY_2_36_1_PY310_CU123, ANYSCALE_RAY_2_36_1_PY311, ANYSCALE_RAY_2_36_1_PY311_CU117, ANYSCALE_RAY_2_36_1_PY311_CU118, ANYSCALE_RAY_2_36_1_PY311_CU121, ANYSCALE_RAY_2_36_1_PY311_CU123, ANYSCALE_RAY_2_36_1_PY312, ANYSCALE_RAY_2_36_1_PY312_CU117, ANYSCALE_RAY_2_36_1_PY312_CU118, ANYSCALE_RAY_2_36_1_PY312_CU121, ANYSCALE_RAY_2_36_1_PY312_CU123, ANYSCALE_RAY_2_36_1_PY39, ANYSCALE_RAY_2_36_1_PY39_CU117, ANYSCALE_RAY_2_36_1_PY39_CU118, ANYSCALE_RAY_2_36_1_PY39_CU121, ANYSCALE_RAY_2_36_1_PY39_CU123, ANYSCALE_RAY_2_36_1_SLIM_PY310, ANYSCALE_RAY_2_36_1_SLIM_PY310_CU118, ANYSCALE_RAY_2_36_1_SLIM_PY310_CU121, ANYSCALE_RAY_2_36_1_SLIM_PY310_CU123, ANYSCALE_RAY_2_36_1_SLIM_PY311, ANYSCALE_RAY_2_36_1_SLIM_PY311_CU118, ANYSCALE_RAY_2_36_1_SLIM_PY311_CU121, ANYSCALE_RAY_2_36_1_SLIM_PY311_CU123, ANYSCALE_RAY_2_36_1_SLIM_PY312, ANYSCALE_RAY_2_36_1_SLIM_PY312_CU118, ANYSCALE_RAY_2_36_1_SLIM_PY312_CU121, ANYSCALE_RAY_2_36_1_SLIM_PY312_CU123, ANYSCALE_RAY_2_36_1_SLIM_PY39, ANYSCALE_RAY_2_36_1_SLIM_PY39_CU118, ANYSCALE_RAY_2_36_1_SLIM_PY39_CU121, ANYSCALE_RAY_2_36_1_SLIM_PY39_CU123, ANYSCALE_RAY_2_37_0_PY310, ANYSCALE_RAY_2_37_0_PY310_CU117, ANYSCALE_RAY_2_37_0_PY310_CU118, ANYSCALE_RAY_2_37_0_PY310_CU121, ANYSCALE_RAY_2_37_0_PY310_CU123, ANYSCALE_RAY_2_37_0_PY311, ANYSCALE_RAY_2_37_0_PY311_CU117, ANYSCALE_RAY_2_37_0_PY311_CU118, ANYSCALE_RAY_2_37_0_PY311_CU121, ANYSCALE_RAY_2_37_0_PY311_CU123, ANYSCALE_RAY_2_37_0_PY312, ANYSCALE_RAY_2_37_0_PY312_CU117, ANYSCALE_RAY_2_37_0_PY312_CU118, ANYSCALE_RAY_2_37_0_PY312_CU121, ANYSCALE_RAY_2_37_0_PY312_CU123, ANYSCALE_RAY_2_37_0_PY39, ANYSCALE_RAY_2_37_0_PY39_CU117, ANYSCALE_RAY_2_37_0_PY39_CU118, ANYSCALE_RAY_2_37_0_PY39_CU121, ANYSCALE_RAY_2_37_0_PY39_CU123, ANYSCALE_RAY_2_37_0_SLIM_PY310, ANYSCALE_RAY_2_37_0_SLIM_PY310_CU118, ANYSCALE_RAY_2_37_0_SLIM_PY310_CU121, ANYSCALE_RAY_2_37_0_SLIM_PY310_CU123, ANYSCALE_RAY_2_37_0_SLIM_PY311, ANYSCALE_RAY_2_37_0_SLIM_PY311_CU118, ANYSCALE_RAY_2_37_0_SLIM_PY311_CU121, ANYSCALE_RAY_2_37_0_SLIM_PY311_CU123, ANYSCALE_RAY_2_37_0_SLIM_PY312, ANYSCALE_RAY_2_37_0_SLIM_PY312_CU118, ANYSCALE_RAY_2_37_0_SLIM_PY312_CU121, ANYSCALE_RAY_2_37_0_SLIM_PY312_CU123, ANYSCALE_RAY_2_37_0_SLIM_PY39, ANYSCALE_RAY_2_37_0_SLIM_PY39_CU118, ANYSCALE_RAY_2_37_0_SLIM_PY39_CU121, ANYSCALE_RAY_2_37_0_SLIM_PY39_CU123, ANYSCALE_RAY_2_38_0_PY310, ANYSCALE_RAY_2_38_0_PY310_CU117, ANYSCALE_RAY_2_38_0_PY310_CU118, ANYSCALE_RAY_2_38_0_PY310_CU121, ANYSCALE_RAY_2_38_0_PY310_CU123, ANYSCALE_RAY_2_38_0_PY311, ANYSCALE_RAY_2_38_0_PY311_CU117, ANYSCALE_RAY_2_38_0_PY311_CU118, ANYSCALE_RAY_2_38_0_PY311_CU121, ANYSCALE_RAY_2_38_0_PY311_CU123, ANYSCALE_RAY_2_38_0_PY312, ANYSCALE_RAY_2_38_0_PY312_CU117, ANYSCALE_RAY_2_38_0_PY312_CU118, ANYSCALE_RAY_2_38_0_PY312_CU121, ANYSCALE_RAY_2_38_0_PY312_CU123, ANYSCALE_RAY_2_38_0_PY39, ANYSCALE_RAY_2_38_0_PY39_CU117, ANYSCALE_RAY_2_38_0_PY39_CU118, ANYSCALE_RAY_2_38_0_PY39_CU121, ANYSCALE_RAY_2_38_0_PY39_CU123, ANYSCALE_RAY_2_38_0_SLIM_PY310, ANYSCALE_RAY_2_38_0_SLIM_PY310_CU118, ANYSCALE_RAY_2_38_0_SLIM_PY310_CU121, ANYSCALE_RAY_2_38_0_SLIM_PY310_CU123, ANYSCALE_RAY_2_38_0_SLIM_PY311, ANYSCALE_RAY_2_38_0_SLIM_PY311_CU118, ANYSCALE_RAY_2_38_0_SLIM_PY311_CU121, ANYSCALE_RAY_2_38_0_SLIM_PY311_CU123, ANYSCALE_RAY_2_38_0_SLIM_PY312, ANYSCALE_RAY_2_38_0_SLIM_PY312_CU118, ANYSCALE_RAY_2_38_0_SLIM_PY312_CU121, ANYSCALE_RAY_2_38_0_SLIM_PY312_CU123, ANYSCALE_RAY_2_38_0_SLIM_PY39, ANYSCALE_RAY_2_38_0_SLIM_PY39_CU118, ANYSCALE_RAY_2_38_0_SLIM_PY39_CU121, ANYSCALE_RAY_2_38_0_SLIM_PY39_CU123, ANYSCALE_RAY_2_39_0_PY310, ANYSCALE_RAY_2_39_0_PY310_CU117, ANYSCALE_RAY_2_39_0_PY310_CU118, ANYSCALE_RAY_2_39_0_PY310_CU121, ANYSCALE_RAY_2_39_0_PY310_CU123, ANYSCALE_RAY_2_39_0_PY311, ANYSCALE_RAY_2_39_0_PY311_CU117, ANYSCALE_RAY_2_39_0_PY311_CU118, ANYSCALE_RAY_2_39_0_PY311_CU121, ANYSCALE_RAY_2_39_0_PY311_CU123, ANYSCALE_RAY_2_39_0_PY312, ANYSCALE_RAY_2_39_0_PY312_CU117, ANYSCALE_RAY_2_39_0_PY312_CU118, ANYSCALE_RAY_2_39_0_PY312_CU121, ANYSCALE_RAY_2_39_0_PY312_CU123, ANYSCALE_RAY_2_39_0_PY39, ANYSCALE_RAY_2_39_0_PY39_CU117, ANYSCALE_RAY_2_39_0_PY39_CU118, ANYSCALE_RAY_2_39_0_PY39_CU121, ANYSCALE_RAY_2_39_0_PY39_CU123, ANYSCALE_RAY_2_39_0_SLIM_PY310, ANYSCALE_RAY_2_39_0_SLIM_PY310_CU118, ANYSCALE_RAY_2_39_0_SLIM_PY310_CU121, ANYSCALE_RAY_2_39_0_SLIM_PY310_CU123, ANYSCALE_RAY_2_39_0_SLIM_PY311, ANYSCALE_RAY_2_39_0_SLIM_PY311_CU118, ANYSCALE_RAY_2_39_0_SLIM_PY311_CU121, ANYSCALE_RAY_2_39_0_SLIM_PY311_CU123, ANYSCALE_RAY_2_39_0_SLIM_PY312, ANYSCALE_RAY_2_39_0_SLIM_PY312_CU118, ANYSCALE_RAY_2_39_0_SLIM_PY312_CU121, ANYSCALE_RAY_2_39_0_SLIM_PY312_CU123, ANYSCALE_RAY_2_39_0_SLIM_PY39, ANYSCALE_RAY_2_39_0_SLIM_PY39_CU118, ANYSCALE_RAY_2_39_0_SLIM_PY39_CU121, ANYSCALE_RAY_2_39_0_SLIM_PY39_CU123, ANYSCALE_RAY_2_4_0_PY310, ANYSCALE_RAY_2_4_0_PY310_CU101, ANYSCALE_RAY_2_4_0_PY310_CU102, ANYSCALE_RAY_2_4_0_PY310_CU110, ANYSCALE_RAY_2_4_0_PY310_CU111, ANYSCALE_RAY_2_4_0_PY310_CU112, ANYSCALE_RAY_2_4_0_PY310_CU113, ANYSCALE_RAY_2_4_0_PY310_CU116, ANYSCALE_RAY_2_4_0_PY310_CU118, ANYSCALE_RAY_2_4_0_PY37, ANYSCALE_RAY_2_4_0_PY37_CU101, ANYSCALE_RAY_2_4_0_PY37_CU102, ANYSCALE_RAY_2_4_0_PY37_CU110, ANYSCALE_RAY_2_4_0_PY37_CU111, ANYSCALE_RAY_2_4_0_PY37_CU112, ANYSCALE_RAY_2_4_0_PY37_CU113, ANYSCALE_RAY_2_4_0_PY37_CU116, ANYSCALE_RAY_2_4_0_PY37_CU118, ANYSCALE_RAY_2_4_0_PY38, ANYSCALE_RAY_2_4_0_PY38_CU101, ANYSCALE_RAY_2_4_0_PY38_CU102, ANYSCALE_RAY_2_4_0_PY38_CU110, ANYSCALE_RAY_2_4_0_PY38_CU111, ANYSCALE_RAY_2_4_0_PY38_CU112, ANYSCALE_RAY_2_4_0_PY38_CU113, ANYSCALE_RAY_2_4_0_PY38_CU116, ANYSCALE_RAY_2_4_0_PY38_CU118, ANYSCALE_RAY_2_4_0_PY39, ANYSCALE_RAY_2_4_0_PY39_CU101, ANYSCALE_RAY_2_4_0_PY39_CU102, ANYSCALE_RAY_2_4_0_PY39_CU110, ANYSCALE_RAY_2_4_0_PY39_CU111, ANYSCALE_RAY_2_4_0_PY39_CU112, ANYSCALE_RAY_2_4_0_PY39_CU113, ANYSCALE_RAY_2_4_0_PY39_CU116, ANYSCALE_RAY_2_4_0_PY39_CU118, ANYSCALE_RAY_2_40_0_PY310, ANYSCALE_RAY_2_40_0_PY310_CU117, ANYSCALE_RAY_2_40_0_PY310_CU118, ANYSCALE_RAY_2_40_0_PY310_CU121, ANYSCALE_RAY_2_40_0_PY310_CU123, ANYSCALE_RAY_2_40_0_PY311, ANYSCALE_RAY_2_40_0_PY311_CU117, ANYSCALE_RAY_2_40_0_PY311_CU118, ANYSCALE_RAY_2_40_0_PY311_CU121, ANYSCALE_RAY_2_40_0_PY311_CU123, ANYSCALE_RAY_2_40_0_PY312, ANYSCALE_RAY_2_40_0_PY312_CU117, ANYSCALE_RAY_2_40_0_PY312_CU118, ANYSCALE_RAY_2_40_0_PY312_CU121, ANYSCALE_RAY_2_40_0_PY312_CU123, ANYSCALE_RAY_2_40_0_PY39, ANYSCALE_RAY_2_40_0_PY39_CU117, ANYSCALE_RAY_2_40_0_PY39_CU118, ANYSCALE_RAY_2_40_0_PY39_CU121, ANYSCALE_RAY_2_40_0_PY39_CU123, ANYSCALE_RAY_2_40_0_SLIM_PY310, ANYSCALE_RAY_2_40_0_SLIM_PY310_CU118, ANYSCALE_RAY_2_40_0_SLIM_PY310_CU121, ANYSCALE_RAY_2_40_0_SLIM_PY310_CU123, ANYSCALE_RAY_2_40_0_SLIM_PY311, ANYSCALE_RAY_2_40_0_SLIM_PY311_CU118, ANYSCALE_RAY_2_40_0_SLIM_PY311_CU121, ANYSCALE_RAY_2_40_0_SLIM_PY311_CU123, ANYSCALE_RAY_2_40_0_SLIM_PY312, ANYSCALE_RAY_2_40_0_SLIM_PY312_CU118, ANYSCALE_RAY_2_40_0_SLIM_PY312_CU121, ANYSCALE_RAY_2_40_0_SLIM_PY312_CU123, ANYSCALE_RAY_2_40_0_SLIM_PY39, ANYSCALE_RAY_2_40_0_SLIM_PY39_CU118, ANYSCALE_RAY_2_40_0_SLIM_PY39_CU121, ANYSCALE_RAY_2_40_0_SLIM_PY39_CU123, ANYSCALE_RAY_2_5_0_PY310, ANYSCALE_RAY_2_5_0_PY310_CU101, ANYSCALE_RAY_2_5_0_PY310_CU102, ANYSCALE_RAY_2_5_0_PY310_CU110, ANYSCALE_RAY_2_5_0_PY310_CU111, ANYSCALE_RAY_2_5_0_PY310_CU112, ANYSCALE_RAY_2_5_0_PY310_CU113, ANYSCALE_RAY_2_5_0_PY310_CU116, ANYSCALE_RAY_2_5_0_PY310_CU118, ANYSCALE_RAY_2_5_0_PY37, ANYSCALE_RAY_2_5_0_PY37_CU101, ANYSCALE_RAY_2_5_0_PY37_CU102, ANYSCALE_RAY_2_5_0_PY37_CU110, ANYSCALE_RAY_2_5_0_PY37_CU111, ANYSCALE_RAY_2_5_0_PY37_CU112, ANYSCALE_RAY_2_5_0_PY37_CU113, ANYSCALE_RAY_2_5_0_PY37_CU116, ANYSCALE_RAY_2_5_0_PY37_CU118, ANYSCALE_RAY_2_5_0_PY38, ANYSCALE_RAY_2_5_0_PY38_CU101, ANYSCALE_RAY_2_5_0_PY38_CU102, ANYSCALE_RAY_2_5_0_PY38_CU110, ANYSCALE_RAY_2_5_0_PY38_CU111, ANYSCALE_RAY_2_5_0_PY38_CU112, ANYSCALE_RAY_2_5_0_PY38_CU113, ANYSCALE_RAY_2_5_0_PY38_CU116, ANYSCALE_RAY_2_5_0_PY38_CU118, ANYSCALE_RAY_2_5_0_PY39, ANYSCALE_RAY_2_5_0_PY39_CU101, ANYSCALE_RAY_2_5_0_PY39_CU102, ANYSCALE_RAY_2_5_0_PY39_CU110, ANYSCALE_RAY_2_5_0_PY39_CU111, ANYSCALE_RAY_2_5_0_PY39_CU112, ANYSCALE_RAY_2_5_0_PY39_CU113, ANYSCALE_RAY_2_5_0_PY39_CU116, ANYSCALE_RAY_2_5_0_PY39_CU118, ANYSCALE_RAY_2_5_1_PY310, ANYSCALE_RAY_2_5_1_PY310_CU101, ANYSCALE_RAY_2_5_1_PY310_CU102, ANYSCALE_RAY_2_5_1_PY310_CU110, ANYSCALE_RAY_2_5_1_PY310_CU111, ANYSCALE_RAY_2_5_1_PY310_CU112, ANYSCALE_RAY_2_5_1_PY310_CU113, ANYSCALE_RAY_2_5_1_PY310_CU116, ANYSCALE_RAY_2_5_1_PY310_CU118, ANYSCALE_RAY_2_5_1_PY37, ANYSCALE_RAY_2_5_1_PY37_CU101, ANYSCALE_RAY_2_5_1_PY37_CU102, ANYSCALE_RAY_2_5_1_PY37_CU110, ANYSCALE_RAY_2_5_1_PY37_CU111, ANYSCALE_RAY_2_5_1_PY37_CU112, ANYSCALE_RAY_2_5_1_PY37_CU113, ANYSCALE_RAY_2_5_1_PY37_CU116, ANYSCALE_RAY_2_5_1_PY37_CU118, ANYSCALE_RAY_2_5_1_PY38, ANYSCALE_RAY_2_5_1_PY38_CU101, ANYSCALE_RAY_2_5_1_PY38_CU102, ANYSCALE_RAY_2_5_1_PY38_CU110, ANYSCALE_RAY_2_5_1_PY38_CU111, ANYSCALE_RAY_2_5_1_PY38_CU112, ANYSCALE_RAY_2_5_1_PY38_CU113, ANYSCALE_RAY_2_5_1_PY38_CU116, ANYSCALE_RAY_2_5_1_PY38_CU118, ANYSCALE_RAY_2_5_1_PY39, ANYSCALE_RAY_2_5_1_PY39_CU101, ANYSCALE_RAY_2_5_1_PY39_CU102, ANYSCALE_RAY_2_5_1_PY39_CU110, ANYSCALE_RAY_2_5_1_PY39_CU111, ANYSCALE_RAY_2_5_1_PY39_CU112, ANYSCALE_RAY_2_5_1_PY39_CU113, ANYSCALE_RAY_2_5_1_PY39_CU116, ANYSCALE_RAY_2_5_1_PY39_CU118, ANYSCALE_RAY_2_6_0_PY310, ANYSCALE_RAY_2_6_0_PY310_CU115, ANYSCALE_RAY_2_6_0_PY310_CU116, ANYSCALE_RAY_2_6_0_PY310_CU117, ANYSCALE_RAY_2_6_0_PY310_CU118, ANYSCALE_RAY_2_6_0_PY37, ANYSCALE_RAY_2_6_0_PY37_CU115, ANYSCALE_RAY_2_6_0_PY37_CU116, ANYSCALE_RAY_2_6_0_PY37_CU117, ANYSCALE_RAY_2_6_0_PY37_CU118, ANYSCALE_RAY_2_6_0_PY38, ANYSCALE_RAY_2_6_0_PY38_CU115, ANYSCALE_RAY_2_6_0_PY38_CU116, ANYSCALE_RAY_2_6_0_PY38_CU117, ANYSCALE_RAY_2_6_0_PY38_CU118, ANYSCALE_RAY_2_6_0_PY39, ANYSCALE_RAY_2_6_0_PY39_CU115, ANYSCALE_RAY_2_6_0_PY39_CU116, ANYSCALE_RAY_2_6_0_PY39_CU117, ANYSCALE_RAY_2_6_0_PY39_CU118, ANYSCALE_RAY_2_6_1_PY310, ANYSCALE_RAY_2_6_1_PY310_CU115, ANYSCALE_RAY_2_6_1_PY310_CU116, ANYSCALE_RAY_2_6_1_PY310_CU117, ANYSCALE_RAY_2_6_1_PY310_CU118, ANYSCALE_RAY_2_6_1_PY37, ANYSCALE_RAY_2_6_1_PY37_CU115, ANYSCALE_RAY_2_6_1_PY37_CU116, ANYSCALE_RAY_2_6_1_PY37_CU117, ANYSCALE_RAY_2_6_1_PY37_CU118, ANYSCALE_RAY_2_6_1_PY38, ANYSCALE_RAY_2_6_1_PY38_CU115, ANYSCALE_RAY_2_6_1_PY38_CU116, ANYSCALE_RAY_2_6_1_PY38_CU117, ANYSCALE_RAY_2_6_1_PY38_CU118, ANYSCALE_RAY_2_6_1_PY39, ANYSCALE_RAY_2_6_1_PY39_CU115, ANYSCALE_RAY_2_6_1_PY39_CU116, ANYSCALE_RAY_2_6_1_PY39_CU117, ANYSCALE_RAY_2_6_1_PY39_CU118, ANYSCALE_RAY_2_6_2_PY310, ANYSCALE_RAY_2_6_2_PY310_CU115, ANYSCALE_RAY_2_6_2_PY310_CU116, ANYSCALE_RAY_2_6_2_PY310_CU117, ANYSCALE_RAY_2_6_2_PY310_CU118, ANYSCALE_RAY_2_6_2_PY37, ANYSCALE_RAY_2_6_2_PY37_CU115, ANYSCALE_RAY_2_6_2_PY37_CU116, ANYSCALE_RAY_2_6_2_PY37_CU117, ANYSCALE_RAY_2_6_2_PY37_CU118, ANYSCALE_RAY_2_6_2_PY38, ANYSCALE_RAY_2_6_2_PY38_CU115, ANYSCALE_RAY_2_6_2_PY38_CU116, ANYSCALE_RAY_2_6_2_PY38_CU117, ANYSCALE_RAY_2_6_2_PY38_CU118, ANYSCALE_RAY_2_6_2_PY39, ANYSCALE_RAY_2_6_2_PY39_CU115, ANYSCALE_RAY_2_6_2_PY39_CU116, ANYSCALE_RAY_2_6_2_PY39_CU117, ANYSCALE_RAY_2_6_2_PY39_CU118, ANYSCALE_RAY_2_6_3_PY310, ANYSCALE_RAY_2_6_3_PY310_CU115, ANYSCALE_RAY_2_6_3_PY310_CU116, ANYSCALE_RAY_2_6_3_PY310_CU117, ANYSCALE_RAY_2_6_3_PY310_CU118, ANYSCALE_RAY_2_6_3_PY37, ANYSCALE_RAY_2_6_3_PY37_CU115, ANYSCALE_RAY_2_6_3_PY37_CU116, ANYSCALE_RAY_2_6_3_PY37_CU117, ANYSCALE_RAY_2_6_3_PY37_CU118, ANYSCALE_RAY_2_6_3_PY38, ANYSCALE_RAY_2_6_3_PY38_CU115, ANYSCALE_RAY_2_6_3_PY38_CU116, ANYSCALE_RAY_2_6_3_PY38_CU117, ANYSCALE_RAY_2_6_3_PY38_CU118, ANYSCALE_RAY_2_6_3_PY39, ANYSCALE_RAY_2_6_3_PY39_CU115, ANYSCALE_RAY_2_6_3_PY39_CU116, ANYSCALE_RAY_2_6_3_PY39_CU117, ANYSCALE_RAY_2_6_3_PY39_CU118, ANYSCALE_RAY_2_7_0OPTIMIZED_PY310, ANYSCALE_RAY_2_7_0OPTIMIZED_PY310_CU115, ANYSCALE_RAY_2_7_0OPTIMIZED_PY310_CU116, ANYSCALE_RAY_2_7_0OPTIMIZED_PY310_CU117, ANYSCALE_RAY_2_7_0OPTIMIZED_PY310_CU118, ANYSCALE_RAY_2_7_0OPTIMIZED_PY310_CU121, ANYSCALE_RAY_2_7_0OPTIMIZED_PY311, ANYSCALE_RAY_2_7_0OPTIMIZED_PY311_CU115, ANYSCALE_RAY_2_7_0OPTIMIZED_PY311_CU116, ANYSCALE_RAY_2_7_0OPTIMIZED_PY311_CU117, ANYSCALE_RAY_2_7_0OPTIMIZED_PY311_CU118, ANYSCALE_RAY_2_7_0OPTIMIZED_PY311_CU121, ANYSCALE_RAY_2_7_0OPTIMIZED_PY37, ANYSCALE_RAY_2_7_0OPTIMIZED_PY37_CU115, ANYSCALE_RAY_2_7_0OPTIMIZED_PY37_CU116, ANYSCALE_RAY_2_7_0OPTIMIZED_PY37_CU117, ANYSCALE_RAY_2_7_0OPTIMIZED_PY37_CU118, ANYSCALE_RAY_2_7_0OPTIMIZED_PY37_CU121, ANYSCALE_RAY_2_7_0OPTIMIZED_PY38, ANYSCALE_RAY_2_7_0OPTIMIZED_PY38_CU115, ANYSCALE_RAY_2_7_0OPTIMIZED_PY38_CU116, ANYSCALE_RAY_2_7_0OPTIMIZED_PY38_CU117, ANYSCALE_RAY_2_7_0OPTIMIZED_PY38_CU118, ANYSCALE_RAY_2_7_0OPTIMIZED_PY38_CU121, ANYSCALE_RAY_2_7_0OPTIMIZED_PY39, ANYSCALE_RAY_2_7_0OPTIMIZED_PY39_CU115, ANYSCALE_RAY_2_7_0OPTIMIZED_PY39_CU116, ANYSCALE_RAY_2_7_0OPTIMIZED_PY39_CU117, ANYSCALE_RAY_2_7_0OPTIMIZED_PY39_CU118, ANYSCALE_RAY_2_7_0OPTIMIZED_PY39_CU121, ANYSCALE_RAY_2_7_1OPTIMIZED_PY310, ANYSCALE_RAY_2_7_1OPTIMIZED_PY310_CU115, ANYSCALE_RAY_2_7_1OPTIMIZED_PY310_CU116, ANYSCALE_RAY_2_7_1OPTIMIZED_PY310_CU117, ANYSCALE_RAY_2_7_1OPTIMIZED_PY310_CU118, ANYSCALE_RAY_2_7_1OPTIMIZED_PY310_CU121, ANYSCALE_RAY_2_7_1OPTIMIZED_PY311, ANYSCALE_RAY_2_7_1OPTIMIZED_PY311_CU115, ANYSCALE_RAY_2_7_1OPTIMIZED_PY311_CU116, ANYSCALE_RAY_2_7_1OPTIMIZED_PY311_CU117, ANYSCALE_RAY_2_7_1OPTIMIZED_PY311_CU118, ANYSCALE_RAY_2_7_1OPTIMIZED_PY311_CU121, ANYSCALE_RAY_2_7_1OPTIMIZED_PY37, ANYSCALE_RAY_2_7_1OPTIMIZED_PY37_CU115, ANYSCALE_RAY_2_7_1OPTIMIZED_PY37_CU116, ANYSCALE_RAY_2_7_1OPTIMIZED_PY37_CU117, ANYSCALE_RAY_2_7_1OPTIMIZED_PY37_CU118, ANYSCALE_RAY_2_7_1OPTIMIZED_PY37_CU121, ANYSCALE_RAY_2_7_1OPTIMIZED_PY38, ANYSCALE_RAY_2_7_1OPTIMIZED_PY38_CU115, ANYSCALE_RAY_2_7_1OPTIMIZED_PY38_CU116, ANYSCALE_RAY_2_7_1OPTIMIZED_PY38_CU117, ANYSCALE_RAY_2_7_1OPTIMIZED_PY38_CU118, ANYSCALE_RAY_2_7_1OPTIMIZED_PY38_CU121, ANYSCALE_RAY_2_7_1OPTIMIZED_PY39, ANYSCALE_RAY_2_7_1OPTIMIZED_PY39_CU115, ANYSCALE_RAY_2_7_1OPTIMIZED_PY39_CU116, ANYSCALE_RAY_2_7_1OPTIMIZED_PY39_CU117, ANYSCALE_RAY_2_7_1OPTIMIZED_PY39_CU118, ANYSCALE_RAY_2_7_1OPTIMIZED_PY39_CU121, ANYSCALE_RAY_2_7_2OPTIMIZED_PY310, ANYSCALE_RAY_2_7_2OPTIMIZED_PY310_CU115, ANYSCALE_RAY_2_7_2OPTIMIZED_PY310_CU116, ANYSCALE_RAY_2_7_2OPTIMIZED_PY310_CU117, ANYSCALE_RAY_2_7_2OPTIMIZED_PY310_CU118, ANYSCALE_RAY_2_7_2OPTIMIZED_PY310_CU121, ANYSCALE_RAY_2_7_2OPTIMIZED_PY311, ANYSCALE_RAY_2_7_2OPTIMIZED_PY311_CU115, ANYSCALE_RAY_2_7_2OPTIMIZED_PY311_CU116, ANYSCALE_RAY_2_7_2OPTIMIZED_PY311_CU117, ANYSCALE_RAY_2_7_2OPTIMIZED_PY311_CU118, ANYSCALE_RAY_2_7_2OPTIMIZED_PY311_CU121, ANYSCALE_RAY_2_7_2OPTIMIZED_PY37, ANYSCALE_RAY_2_7_2OPTIMIZED_PY37_CU115, ANYSCALE_RAY_2_7_2OPTIMIZED_PY37_CU116, ANYSCALE_RAY_2_7_2OPTIMIZED_PY37_CU117, ANYSCALE_RAY_2_7_2OPTIMIZED_PY37_CU118, ANYSCALE_RAY_2_7_2OPTIMIZED_PY37_CU121, ANYSCALE_RAY_2_7_2OPTIMIZED_PY38, ANYSCALE_RAY_2_7_2OPTIMIZED_PY38_CU115, ANYSCALE_RAY_2_7_2OPTIMIZED_PY38_CU116, ANYSCALE_RAY_2_7_2OPTIMIZED_PY38_CU117, ANYSCALE_RAY_2_7_2OPTIMIZED_PY38_CU118, ANYSCALE_RAY_2_7_2OPTIMIZED_PY38_CU121, ANYSCALE_RAY_2_7_2OPTIMIZED_PY39, ANYSCALE_RAY_2_7_2OPTIMIZED_PY39_CU115, ANYSCALE_RAY_2_7_2OPTIMIZED_PY39_CU116, ANYSCALE_RAY_2_7_2OPTIMIZED_PY39_CU117, ANYSCALE_RAY_2_7_2OPTIMIZED_PY39_CU118, ANYSCALE_RAY_2_7_2OPTIMIZED_PY39_CU121, ANYSCALE_RAY_2_8_0_PY310, ANYSCALE_RAY_2_8_0_PY310_CU115, ANYSCALE_RAY_2_8_0_PY310_CU116, ANYSCALE_RAY_2_8_0_PY310_CU117, ANYSCALE_RAY_2_8_0_PY310_CU118, ANYSCALE_RAY_2_8_0_PY310_CU121, ANYSCALE_RAY_2_8_0_PY311, ANYSCALE_RAY_2_8_0_PY311_CU115, ANYSCALE_RAY_2_8_0_PY311_CU116, ANYSCALE_RAY_2_8_0_PY311_CU117, ANYSCALE_RAY_2_8_0_PY311_CU118, ANYSCALE_RAY_2_8_0_PY311_CU121, ANYSCALE_RAY_2_8_0_PY38, ANYSCALE_RAY_2_8_0_PY38_CU115, ANYSCALE_RAY_2_8_0_PY38_CU116, ANYSCALE_RAY_2_8_0_PY38_CU117, ANYSCALE_RAY_2_8_0_PY38_CU118, ANYSCALE_RAY_2_8_0_PY38_CU121, ANYSCALE_RAY_2_8_0_PY39, ANYSCALE_RAY_2_8_0_PY39_CU115, ANYSCALE_RAY_2_8_0_PY39_CU116, ANYSCALE_RAY_2_8_0_PY39_CU117, ANYSCALE_RAY_2_8_0_PY39_CU118, ANYSCALE_RAY_2_8_0_PY39_CU121, ANYSCALE_RAY_2_8_1_PY310, ANYSCALE_RAY_2_8_1_PY310_CU115, ANYSCALE_RAY_2_8_1_PY310_CU116, ANYSCALE_RAY_2_8_1_PY310_CU117, ANYSCALE_RAY_2_8_1_PY310_CU118, ANYSCALE_RAY_2_8_1_PY310_CU121, ANYSCALE_RAY_2_8_1_PY311, ANYSCALE_RAY_2_8_1_PY311_CU115, ANYSCALE_RAY_2_8_1_PY311_CU116, ANYSCALE_RAY_2_8_1_PY311_CU117, ANYSCALE_RAY_2_8_1_PY311_CU118, ANYSCALE_RAY_2_8_1_PY311_CU121, ANYSCALE_RAY_2_8_1_PY38, ANYSCALE_RAY_2_8_1_PY38_CU115, ANYSCALE_RAY_2_8_1_PY38_CU116, ANYSCALE_RAY_2_8_1_PY38_CU117, ANYSCALE_RAY_2_8_1_PY38_CU118, ANYSCALE_RAY_2_8_1_PY38_CU121, ANYSCALE_RAY_2_8_1_PY39, ANYSCALE_RAY_2_8_1_PY39_CU115, ANYSCALE_RAY_2_8_1_PY39_CU116, ANYSCALE_RAY_2_8_1_PY39_CU117, ANYSCALE_RAY_2_8_1_PY39_CU118, ANYSCALE_RAY_2_8_1_PY39_CU121, ANYSCALE_RAY_2_9_0_PY310, ANYSCALE_RAY_2_9_0_PY310_CU115, ANYSCALE_RAY_2_9_0_PY310_CU116, ANYSCALE_RAY_2_9_0_PY310_CU117, ANYSCALE_RAY_2_9_0_PY310_CU118, ANYSCALE_RAY_2_9_0_PY310_CU121, ANYSCALE_RAY_2_9_0_PY311, ANYSCALE_RAY_2_9_0_PY311_CU115, ANYSCALE_RAY_2_9_0_PY311_CU116, ANYSCALE_RAY_2_9_0_PY311_CU117, ANYSCALE_RAY_2_9_0_PY311_CU118, ANYSCALE_RAY_2_9_0_PY311_CU121, ANYSCALE_RAY_2_9_0_PY38, ANYSCALE_RAY_2_9_0_PY38_CU115, ANYSCALE_RAY_2_9_0_PY38_CU116, ANYSCALE_RAY_2_9_0_PY38_CU117, ANYSCALE_RAY_2_9_0_PY38_CU118, ANYSCALE_RAY_2_9_0_PY38_CU121, ANYSCALE_RAY_2_9_0_PY39, ANYSCALE_RAY_2_9_0_PY39_CU115, ANYSCALE_RAY_2_9_0_PY39_CU116, ANYSCALE_RAY_2_9_0_PY39_CU117, ANYSCALE_RAY_2_9_0_PY39_CU118, ANYSCALE_RAY_2_9_0_PY39_CU121, ANYSCALE_RAY_2_9_1_PY310, ANYSCALE_RAY_2_9_1_PY310_CU115, ANYSCALE_RAY_2_9_1_PY310_CU116, ANYSCALE_RAY_2_9_1_PY310_CU117, ANYSCALE_RAY_2_9_1_PY310_CU118, ANYSCALE_RAY_2_9_1_PY310_CU121, ANYSCALE_RAY_2_9_1_PY311, ANYSCALE_RAY_2_9_1_PY311_CU115, ANYSCALE_RAY_2_9_1_PY311_CU116, ANYSCALE_RAY_2_9_1_PY311_CU117, ANYSCALE_RAY_2_9_1_PY311_CU118, ANYSCALE_RAY_2_9_1_PY311_CU121, ANYSCALE_RAY_2_9_1_PY38, ANYSCALE_RAY_2_9_1_PY38_CU115, ANYSCALE_RAY_2_9_1_PY38_CU116, ANYSCALE_RAY_2_9_1_PY38_CU117, ANYSCALE_RAY_2_9_1_PY38_CU118, ANYSCALE_RAY_2_9_1_PY38_CU121, ANYSCALE_RAY_2_9_1_PY39, ANYSCALE_RAY_2_9_1_PY39_CU115, ANYSCALE_RAY_2_9_1_PY39_CU116, ANYSCALE_RAY_2_9_1_PY39_CU117, ANYSCALE_RAY_2_9_1_PY39_CU118, ANYSCALE_RAY_2_9_1_PY39_CU121, ANYSCALE_RAY_2_9_2_PY310, ANYSCALE_RAY_2_9_2_PY310_CU115, ANYSCALE_RAY_2_9_2_PY310_CU116, ANYSCALE_RAY_2_9_2_PY310_CU117, ANYSCALE_RAY_2_9_2_PY310_CU118, ANYSCALE_RAY_2_9_2_PY310_CU121, ANYSCALE_RAY_2_9_2_PY311, ANYSCALE_RAY_2_9_2_PY311_CU115, ANYSCALE_RAY_2_9_2_PY311_CU116, ANYSCALE_RAY_2_9_2_PY311_CU117, ANYSCALE_RAY_2_9_2_PY311_CU118, ANYSCALE_RAY_2_9_2_PY311_CU121, ANYSCALE_RAY_2_9_2_PY38, ANYSCALE_RAY_2_9_2_PY38_CU115, ANYSCALE_RAY_2_9_2_PY38_CU116, ANYSCALE_RAY_2_9_2_PY38_CU117, ANYSCALE_RAY_2_9_2_PY38_CU118, ANYSCALE_RAY_2_9_2_PY38_CU121, ANYSCALE_RAY_2_9_2_PY39, ANYSCALE_RAY_2_9_2_PY39_CU115, ANYSCALE_RAY_2_9_2_PY39_CU116, ANYSCALE_RAY_2_9_2_PY39_CU117, ANYSCALE_RAY_2_9_2_PY39_CU118, ANYSCALE_RAY_2_9_2_PY39_CU121, ANYSCALE_RAY_2_9_3_PY310, ANYSCALE_RAY_2_9_3_PY310_CU115, ANYSCALE_RAY_2_9_3_PY310_CU116, ANYSCALE_RAY_2_9_3_PY310_CU117, ANYSCALE_RAY_2_9_3_PY310_CU118, ANYSCALE_RAY_2_9_3_PY310_CU121, ANYSCALE_RAY_2_9_3_PY311, ANYSCALE_RAY_2_9_3_PY311_CU115, ANYSCALE_RAY_2_9_3_PY311_CU116, ANYSCALE_RAY_2_9_3_PY311_CU117, ANYSCALE_RAY_2_9_3_PY311_CU118, ANYSCALE_RAY_2_9_3_PY311_CU121, ANYSCALE_RAY_2_9_3_PY38, ANYSCALE_RAY_2_9_3_PY38_CU115, ANYSCALE_RAY_2_9_3_PY38_CU116, ANYSCALE_RAY_2_9_3_PY38_CU117, ANYSCALE_RAY_2_9_3_PY38_CU118, ANYSCALE_RAY_2_9_3_PY38_CU121, ANYSCALE_RAY_2_9_3_PY39, ANYSCALE_RAY_2_9_3_PY39_CU115, ANYSCALE_RAY_2_9_3_PY39_CU116, ANYSCALE_RAY_2_9_3_PY39_CU117, ANYSCALE_RAY_2_9_3_PY39_CU118, ANYSCALE_RAY_2_9_3_PY39_CU121, ANYSCALE_RAY_LATEST, ANYSCALE_RAY_NIGHTLY, ANYSCALE_RAY_NIGHTLY_GPU, ANYSCALE_RAY_NIGHTLY_PY310, ANYSCALE_RAY_NIGHTLY_PY310_CU117, ANYSCALE_RAY_NIGHTLY_PY310_CU118, ANYSCALE_RAY_NIGHTLY_PY310_CU121, ANYSCALE_RAY_NIGHTLY_PY310_CU123, ANYSCALE_RAY_NIGHTLY_PY311, ANYSCALE_RAY_NIGHTLY_PY311_CU117, ANYSCALE_RAY_NIGHTLY_PY311_CU118, ANYSCALE_RAY_NIGHTLY_PY311_CU121, ANYSCALE_RAY_NIGHTLY_PY311_CU123, ANYSCALE_RAY_NIGHTLY_PY312, ANYSCALE_RAY_NIGHTLY_PY312_CU117, ANYSCALE_RAY_NIGHTLY_PY312_CU118, ANYSCALE_RAY_NIGHTLY_PY312_CU121, ANYSCALE_RAY_NIGHTLY_PY312_CU123, ANYSCALE_RAY_NIGHTLY_PY36, ANYSCALE_RAY_NIGHTLY_PY36_CU117, ANYSCALE_RAY_NIGHTLY_PY36_CU118, ANYSCALE_RAY_NIGHTLY_PY36_CU121, ANYSCALE_RAY_NIGHTLY_PY36_CU123, ANYSCALE_RAY_NIGHTLY_PY37, ANYSCALE_RAY_NIGHTLY_PY37_CU117, ANYSCALE_RAY_NIGHTLY_PY37_CU118, ANYSCALE_RAY_NIGHTLY_PY37_CU121, ANYSCALE_RAY_NIGHTLY_PY37_CU123, ANYSCALE_RAY_NIGHTLY_PY38, ANYSCALE_RAY_NIGHTLY_PY38_CU117, ANYSCALE_RAY_NIGHTLY_PY38_CU118, ANYSCALE_RAY_NIGHTLY_PY38_CU121, ANYSCALE_RAY_NIGHTLY_PY38_CU123, ANYSCALE_RAY_NIGHTLY_PY39, ANYSCALE_RAY_NIGHTLY_PY39_CU117, ANYSCALE_RAY_NIGHTLY_PY39_CU118, ANYSCALE_RAY_NIGHTLY_PY39_CU121, ANYSCALE_RAY_NIGHTLY_PY39_CU123, UNKNOWN]  # noqa: E501

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
    }

    attribute_map = {
    }

    def __init__(self, local_vars_configuration=None):  # noqa: E501
        """BASEIMAGESENUM - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration
        self.discriminator = None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BASEIMAGESENUM):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BASEIMAGESENUM):
            return True

        return self.to_dict() != other.to_dict()
